# **BERKSHIRE HATHAWAY INC.**

#### **2024** **ANNUAL REPORT**


---

**BERKSHIRE HATHAWAY INC.**


**2024 ANNUAL REPORT**


**TABLE OF CONTENTS**


Chairman’s Letter* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 1-13


Berkshire’s Performance vs. the S&P 500 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 14-15


Shareholder Event and Meeting Information . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 16


Form 10-K –


Business Description . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-1


Risk Factors . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-24


Cybersecurity . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-27


Description of Properties . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-28


Legal Proceedings . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-31


Management’s Discussion . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-33


Management’s Report on Internal Control . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-63


Independent Auditor’s Report . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-64


Consolidated Financial Statements . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-66


Notes to Consolidated Financial Statements . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . K-71


Appendices –

Operating Companies . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . A-1

Stock Transfer Agent . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . A-2

Directors and Officers of the Company . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . Inside Back Cover


*Copyright [©] 2025 By Warren E. Buffett
All Rights Reserved


---

**BERKSHIRE HATHAWAY INC.**


To the Shareholders of Berkshire Hathaway Inc.:


This letter comes to you as part of Berkshire’s annual _report_ . As a public company, we
are required to periodically tell you many specific facts and figures.


“Report,” however, implies a greater responsibility. In addition to the mandated data, we
believe we owe you additional commentary about what you own and how we think. Our goal is
to communicate with you in a manner that we would wish you to use if our positions were
reversed – that is, if you were Berkshire’s CEO while I and my family were passive investors,
trusting _you_ with our savings.


This approach leads us to an annual recitation of both good and bad developments at the
many businesses you indirectly own through your Berkshire shares. When discussing problems
at specific subsidiaries, we do, however, try to follow the advice Tom Murphy gave to me 60
years ago: “praise by name, criticize by category.”


**Mistakes – Yes, We Make Them at Berkshire**


Sometimes I’ve made mistakes in assessing the future economics of a business I’ve
purchased for Berkshire – each a case of capital allocation gone wrong. That happens with both
judgments about marketable equities – we view these as _partial_ ownership of businesses – and
the 100% acquisitions of companies.


At other times, I’ve made mistakes when assessing the abilities or fidelity of the
managers Berkshire is hiring. The fidelity disappointments can hurt beyond their financial
impact, a pain that can approach that of a failed marriage.


A decent batting average in personnel decisions is all that can be hoped for. The cardinal
sin is delaying the correction of mistakes or what Charlie Munger called “thumb-sucking.”
Problems, he would tell me, cannot be wished away. They require action, however
uncomfortable that may be.

                    -***********
During the 2019-23 period, I have used the words “mistake” or “error” 16 times in my
letters to you. Many other huge companies have _never_ used either word over that span. Amazon,
I should acknowledge, made some brutally candid observations in its 2021 letter. Elsewhere, it
has generally been happy talk and pictures.


1


---

I have also been a director of large public companies at which “mistake” or “wrong” were
forbidden words at board meetings or analyst calls. That taboo, implying managerial perfection,
always made me nervous (though, at times, there could be legal issues that make limited
discussion advisable. We live in a very litigious society.)


                    -***********
At 94, it won’t be long before Greg Abel replaces me as CEO and will be writing the
annual letters. Greg shares the Berkshire creed that a “report” is what a Berkshire CEO annually
owes to owners. And he also understands that if you start fooling your shareholders, you will
soon believe your own baloney and be fooling yourself as well.


**Pete Liegl – One of a Kind**


Let me pause to tell you the remarkable story of Pete Liegl, a man unknown to most
Berkshire shareholders but one who contributed many billions to their aggregate wealth. Pete
died in November, still working at 80.


I first heard of Forest River – the Indiana company Pete founded and managed – on
June 21, 2005. On that day I received a letter from an intermediary detailing relevant data about
the company, a recreational vehicle (“RV”) manufacturer. The writer said that Pete, the 100%
owner of Forest River, specifically wanted to sell to Berkshire. He also told me the price that Pete
expected to receive. I liked this no-nonsense approach.


I did some checking with RV dealers, liked what I learned and arranged a June 28 [th]
meeting in Omaha. Pete brought along his wife, Sharon, and daughter, Lisa. When we met, Pete
assured me that he wanted to keep running the business but would feel more comfortable if he
could assure financial security for his family.


Pete next mentioned that he owned some real estate that was leased to Forest River and
had not been covered in the June 21 letter. Within a few minutes, we arrived at a price for those
assets as I expressed no need for appraisal by Berkshire but would simply accept his valuation.


Then we arrived at the other point that needed clarity. I asked Pete what his compensation
should be, adding that whatever he said, I would accept. (This, I should add, is _not_ an approach I
recommend for general use.)


Pete paused as his wife, daughter and I leaned forward. Then he surprised us: “Well, I
looked at Berkshire’s proxy statement and I wouldn’t want to make more than my boss, so pay
me $100,000 per year.” After I picked myself off the floor, Pete added: “But we will earn X (he
named a number) this year, and I would like an annual bonus of 10% of any earnings above what
the company is now delivering.” I replied: “OK Pete, but if Forest River makes any significant
acquisitions we will make an appropriate adjustment for the additional capital thus employed.” I
didn’t define “appropriate” or “significant,” but those vague terms never caused a problem.


2


---

The four of us then went to dinner at Omaha’s Happy Hollow Club and lived happily
ever after. During the next 19 years, Pete shot the lights out. No competitor came close to his
performance.

                    -***********
Every company doesn’t have an easy-to-understand business and there are _very_ few
owners or managers like Pete. And, of course, I expect to make my share of mistakes about the
businesses Berkshire buys and sometimes err in evaluating the sort of person with whom I’m
dealing.


But I’ve also had many pleasant surprises in both the potential of the business as well as
the ability and fidelity of the manager. And our experience is that a _single_ winning decision can
make a breathtaking difference over time. (Think GEICO as a business decision, Ajit Jain as a
managerial decision and my luck in finding Charlie Munger as a one-of-a-kind partner, personal
advisor and steadfast friend.) Mistakes fade away; winners can forever blossom.


                    -***********
One further point in our CEO selections: I never look at where a candidate has gone to
school. Never!


Of course, there are great managers who attended the most famous schools. But there are
plenty such as Pete who may have benefitted by attending a less prestigious institution or even
by not bothering to finish school. Look at my friend, Bill Gates, who decided that it was far more
important to get underway in an exploding industry that would change the world than it was to
stick around for a parchment that he could hang on the wall. (Read his new book, _Source Code_ .)


Not long ago, I met – by phone – Jessica Toonkel, whose step-grandfather, Ben Rosner,
long ago ran a business for Charlie and me. Ben was a retailing genius and, in preparing for this
report, I checked with Jessica to confirm Ben’s schooling, which I remembered as limited.
Jessica’s reply: “Ben never went past 6 [th] grade.”


I was lucky enough to get an education at three fine universities. And I avidly believe in
lifelong learning. I’ve observed, however, that a very large portion of business talent is innate
with nature swamping nurture.


Pete Liegl was a natural.


3


---

**Last Year’s Performance**


In 2024, Berkshire did better than I expected though 53% of our 189 operating
businesses reported a _decline_ in earnings. We were aided by a predictable large gain in
investment income as Treasury Bill yields improved and we substantially increased our holdings
of these highly-liquid short-term securities.


Our insurance business also delivered a major increase in earnings, led by the
performance of GEICO. In five years, Todd Combs has reshaped GEICO in a major way,
increasing efficiency and bringing underwriting practices up to date. GEICO was a long-held
gem that needed major repolishing, and Todd has worked tirelessly in getting the job done.
Though not yet complete, the 2024 improvement was spectacular.


In general, property-casualty (“P/C”) insurance pricing strengthened during 2024,
reflecting a major increase in damage from convective storms. Climate change may have been
announcing its arrival. However, no “monster” event occurred during 2024. Someday, _any_ day, a
truly staggering insurance loss will occur – and there is no guarantee that there will be only one
per annum.


The P/C business is so central to Berkshire that it warrants a further discussion that
appears later in this letter.


Berkshire’s railroad and utility operations, our two largest businesses outside of
insurance, improved their aggregate earnings. Both, however, have much left to accomplish.


Late in the year we increased our ownership of the utility operation from about 92% to
100% at a cost of roughly $3.9 billion, of which $2.9 billion was paid in cash with a balance in
Berkshire “B” shares.

                    -***********
All told, we recorded _operating earnings_ of $47.4 billion in 2024. We regularly – endlessly,
some readers may groan – emphasize this measure rather than the GAAP-mandated earnings that
are reported on page K-68.


_Our_ measure _excludes_ capital gains or losses on the stocks and bonds we own, whether
realized or unrealized. Over time, we think it highly likely that gains will prevail – why else
would we buy these securities? – though the year-by-year numbers will swing wildly and
unpredictably. Our horizon for such commitments is almost always far longer than a single year.
In many, our thinking involves decades. These long-termers are the purchases that sometimes
make the cash register ring like church bells.


4


---

Here’s a breakdown of the 2023-24 earnings as we see them. All calculations are _after_
depreciation, amortization and income tax. EBITDA, a flawed favorite of Wall Street, is not for
us.


(in $ millions)
2024 2023


Insurance-underwriting . . . . . . . . . . . . . . . . . . . . . $ 9,020 $ 5,428
Insurance-investment income . . . . . . . . . . . . . . . . 13,670 9,567
BNSF . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 5,031 5,087
Berkshire Hathaway Energy . . . . . . . . . . . . . . . . . 3,730 2,331
Other controlled businesses . . . . . . . . . . . . . . . . . 13,072 13,362
Non-controlled businesses* . . . . . . . . . . . . . . . . . 1,519 1,750
Other** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 1,395 (175)

Operating earnings . . . . . . . . . . . . . . . . . . . . . . . . $47,437 $37,350


_* Includes certain businesses in which Berkshire had between a 20% and 50% ownership_
_such as Kraft Heinz, Occidental Petroleum and Berkadia._


_** Includes foreign currency exchange gains of approximately $1.1 billion in 2024 and_
_approximately $211 million in 2023 produced by our usage of non-U.S. dollar-denominated_
_debt._


**Surprise, Surprise! An Important American Record is Smashed**


Sixty years ago, present management took control of Berkshire. That move was a
mistake – _my_ mistake – and one that plagued us for _two decades_ . Charlie, I should emphasize,
spotted my obvious error immediately: Though the price I paid for Berkshire _looked_ cheap, its
business – a large northern textile operation – was headed for extinction.


The U.S. Treasury, of all places, had already received silent warnings of Berkshire’s
destiny. In 1965, the company did not pay a dime of income tax, an embarrassment that had
generally prevailed at the company for _a decade_ . That sort of economic behavior may be
understandable for glamorous startups, but it’s a blinking yellow light when it happens at a
venerable pillar of American industry. Berkshire was headed for the ash can.


Fast forward 60 years and imagine the surprise at the Treasury when that same
company – still operating under the name of Berkshire Hathaway – paid _far_ more in corporate
income tax than the U.S. government had _ever_ received from _any_ company – even the American
tech titans that commanded market values in the _trillions_ .


To be precise, Berkshire last year made four payments to the IRS that totaled $26.8
billion. That’s about 5% of what _all_ of corporate America paid. (In addition, we paid sizable
amounts for income taxes to foreign governments and to 44 states.)


5


---

Note one crucial factor allowing this record-shattering payment: Berkshire shareholders
during the same 1965-2024 period received only one cash dividend. On January 3, 1967, we
disbursed our sole payment – $101,755 or 10¢ per A share. (I can’t remember why I suggested
this action to Berkshire’s board of directors. Now it seems like a bad dream.)


For _sixty years_, Berkshire shareholders endorsed continuous reinvestment and that
enabled the company to build its taxable income. Cash income-tax payments to the U.S.
Treasury, miniscule in the first decade, now aggregate more than $101 _billion_ . . . and counting.


                    -***********
Huge numbers can be hard to visualize. Let me recast the $26.8 billion that we paid last
year.


If Berkshire had sent the Treasury a $1 million check _every 20 minutes_ throughout all of
2024 – visualize _366 days and nights_ because 2024 was a leap year – we still would have owed
the federal government a significant sum at yearend. Indeed, it would be well into January before
the Treasury would tell us that we could take a short breather, get some sleep, and prepare for our
2025 tax payments.


**Where Your Money Is**


Berkshire’s equity activity is ambidextrous. In one hand we own control of many
businesses, holding at least 80% of the investee’s shares. Generally, we own 100%.
These 189 subsidiaries have similarities to marketable common stocks but are far from
identical. The collection is worth many hundreds of billions and includes a few rare gems,
many good-but-far-from-fabulous businesses and some laggards that have been disappointments.
We own nothing that is a major drag, but we have a number that I should not have purchased.


In the _other_ hand, we own a small percentage of a dozen or so very large and highly
profitable businesses with household names such as Apple, American Express, Coca-Cola and
Moody’s. Many of these companies earn very high returns on the net tangible equity required for
their operations. At yearend, our partial-ownership holdings were valued at $272 billion.
Understandably, really outstanding businesses are _very_ seldom offered in their entirety, but small
fractions of these gems can be purchased Monday through Friday on Wall Street and, very
occasionally, they sell at bargain prices.


We are impartial in our choice of equity vehicles, investing in either variety based upon
where we can best deploy your (and my family’s) savings. Often, nothing looks compelling; _very_
infrequently we find ourselves knee-deep in opportunities. Greg has vividly shown his ability to
act at such times as did Charlie.


6


---

With marketable equities, it is easier to change course when I make a mistake.
Berkshire’s present size, it should be underscored, _diminishe_ s this valuable option. We can’t
come and go on a dime. Sometimes a year or more is required to establish or divest an
investment. Additionally, with ownership of minority positions we can’t change management if
that action is needed or control what is done with capital flows if we are unhappy with the
decisions being made.


With controlled companies, we can dictate these decisions, _but_ we have far less flexibility
in the disposition of mistakes. In reality, Berkshire almost never sells controlled businesses
unless we face what we believe to be unending problems. An offset is that some business owners
seek out Berkshire because of our steadfast behavior. Occasionally, that can be a decided plus for
us.

                    -***********
Despite what some commentators currently view as an extraordinary cash position at
Berkshire, the great majority of your money remains in equities. That preference won’t change.
While our ownership in _marketable_ equities moved downward last year from $354 billion to
$272 billion, the value of our non-quoted controlled equities increased somewhat and remains _far_
greater than the value of the _marketable_ portfolio.


Berkshire shareholders can rest assured that we will forever deploy a substantial majority
of their money in equities – mostly American equities although many of these will have
international operations of significance. Berkshire will _never_ prefer ownership of cash-equivalent
assets over the ownership of good businesses, whether controlled or only partially owned.


Paper money can see its value evaporate if fiscal folly prevails. In some countries, this
reckless practice has become habitual, and, in our country’s short history, the U.S. has come
close to the edge. Fixed-coupon bonds provide no protection against runaway currency.


Businesses, as well as individuals with desired talents, however, will usually find a way
to cope with monetary instability as long as their goods or services are desired by the country’s
citizenry. So, too, with personal skills. Lacking such assets as athletic excellence, a wonderful
voice, medical or legal skills or, for that matter, _any_ special talents, I have had to rely on equities
throughout my life. In effect, I have depended on the success of American businesses and I will
continue to do so.

                    -***********
One way or another, the sensible – better yet imaginative – deployment of savings by
citizens is required to propel an ever-growing societal output of desired goods and services. This
system is called capitalism. It has its faults and abuses – in certain respects more egregious now
than ever – but it also can work wonders unmatched by other economic systems.


America is Exhibit A. Our country’s progress over its mere 235 years of existence could
not have been imagined by even the most optimistic colonists in 1789, when the Constitution
was adopted and the country’s energies were unleashed.


7


---

True, our country in its infancy sometimes borrowed abroad to supplement our own
savings. But, concurrently, we needed many Americans to consistently save and then needed
those savers or other Americans to wisely deploy the capital thus made available. If America had
consumed all that it produced, the country would have been spinning its wheels.


The American process has _not_ always been pretty – our country has forever had many
scoundrels and promoters who seek to take advantage of those who mistakenly trust them with
their savings. But even with such malfeasance – which remains in full force today – and also
much deployment of capital that eventually floundered because of brutal competition or
disruptive innovation, the savings of Americans has delivered a quantity and quality of output
beyond the dreams of any colonist.


From a base of only four million people – and despite a brutal internal war early on,
pitting one American against another – America changed the world in the blink of a celestial eye.


                    -***********
In a _very_ minor way, Berkshire shareholders have participated in the American miracle by
foregoing dividends, thereby electing to reinvest rather than consume. Originally, this
reinvestment was tiny, almost meaningless, but over time, it mushroomed, reflecting the mixture
of a sustained culture of savings, combined with the magic of long-term compounding.


Berkshire’s activities now impact all corners of our country. And we are not finished.
Companies die for many reasons but, unlike the fate of humans, old age itself is not lethal.
Berkshire today is far more youthful than it was in 1965.


_However_, as Charlie and I have always acknowledged, Berkshire would not have
achieved its results in any locale except America whereas America would have been every bit the
success it has been if Berkshire had never existed.


                    -***********
So thank you, Uncle Sam. Someday your nieces and nephews at Berkshire hope to send
you even larger payments than we did in 2024. Spend it wisely. Take care of the many who, for
no fault of their own, get the short straws in life. They deserve better. And never forget that we
need you to maintain a stable currency and that result _requires_ both wisdom and vigilance on
your part.


**Property-Casualty Insurance**


P/C insurance continues to be Berkshire’s core business. The industry follows a financial
model that is rare – very rare – among giant businesses.


Customarily, companies incur costs for labor, materials, inventories, plant and equipment,
etc. _before_ - or concurrently with – the sale of their products or services. Consequently, their
CEOs have a good fix on knowing the _cost_ of their product _before_ they sell it. If the selling price
is less than its cost, managers soon learn they have a problem. Hemorrhaging cash is hard to
ignore.


8


---

When writing P/C insurance, we receive payment upfront and _much later_ learn what our
product has cost us – sometimes a moment of truth that is delayed as much as 30 or more years.
(We are still making substantial payments on asbestos exposures that occurred 50 or more years
ago.)


This mode of operations has the desirable effect of giving P/C insurers cash before
they incur most expenses but carries with it the risk that the company can be losing
money – sometimes mountains of money – before the CEO and directors realize what is
happening.


Certain lines of insurance minimize this mismatch, such as crop insurance or hail damage
in which losses are quickly reported, evaluated and paid. Other lines, however, can lead to
executive and shareholder bliss as the company is going broke. Think coverages such as medical
malpractice or product liability. In “long-tail” lines, a P/C insurer may report large but fictitious
profits to its owners and regulators for many years – even decades. The accounting can be
particularly dangerous if the CEO is an optimist or a crook. These possibilities are not fanciful:
History reveals a large number of each species.


In recent decades, this “money-up-front, loss-payments-later” model has allowed
Berkshire to invest large sums (“float”) while generally delivering what we believe to be a small
underwriting profit. We make estimates for “surprises” and, so far, these estimates have been
sufficient.


We are not deterred by the dramatic and growing loss payments sustained by our
activities. (As I write this, think wildfires.) It’s our job to price to absorb these and unemotionally
take our lumps when surprises develop. It’s also our job to contest “runaway” verdicts, spurious
litigation and outright fraudulent behavior.


Under Ajit, our insurance operation has blossomed from an obscure Omaha-based
company into a world leader, renowned for both its taste for risk and its Gibraltar-like financial
strength. Moreover, Greg, our directors and I all have a _very_ large investment in Berkshire in
relation to any compensation we receive. We do _not_ use options or other one-sided forms of
compensation; if _you_ lose money, so do we. This approach encourages caution but does _not_
ensure foresight.

                    -***********
P/C insurance _growth_ is dependent on increased economic risk. No risk – no need for
insurance.


Think back only 135 years when the world had no autos, trucks or airplanes. Now there
are 300 million vehicles in the U.S. alone, a massive fleet causing huge damage daily. Property
damage arising from hurricanes, tornadoes and wildfires is massive, growing and increasingly
unpredictable in their patterns and eventual costs.


9


---

It would be foolish – make that madness – to write ten-year policies for these coverages,
but we believe one-year assumption of such risks is generally manageable. If we change our
minds, we will change the contracts we offer. During my lifetime, auto insurers have generally
abandoned one-year policies and switched to the six-month variety. This change _reduced_ float
but allowed more intelligent underwriting.


                    -***********
_No_ private insurer has the willingness to take on the amount of risk that Berkshire can
provide. At times, this advantage can be important. But we also need to _shrink_ when prices are
inadequate. We must _never_ write inadequately-priced policies in order to stay in the game. That
policy is corporate suicide.


Properly pricing P/C insurance is part art, part science and is definitely not a business for
optimists. Mike Goldberg, the Berkshire executive who recruited Ajit, said it best: “We want our
underwriters to daily come to work nervous, but not paralyzed.”


                    -***********
All things considered, we like the P/C insurance business. Berkshire can financially and
psychologically handle extreme losses without blinking. We are also not dependent on reinsurers
and that gives us a material and enduring cost advantage. Finally, we have outstanding managers
( _no_ optimists) and are particularly well-situated to utilize the substantial sums P/C insurance
delivers for investment.


Over the past two decades, our insurance business has generated $32 billion of after-tax
profits from underwriting, about 3.3 cents per dollar of sales after income tax. Meanwhile, our
float has grown from $46 billion to $171 billion. The float is likely to grow a bit over time and,
with intelligent underwriting (and some luck), has a reasonable prospect of being costless.


**Berkshire Increases its Japanese Investments**


A small but important exception to our U.S.-based focus is our growing investment in
Japan.


It’s been almost six years since Berkshire began purchasing shares in five Japanese
companies that very successfully operate in a manner somewhat similar to Berkshire itself. The
five are (alphabetically) ITOCHU, Marubeni, Mitsubishi, Mitsui and Sumitomo. Each of these
large enterprises, in turn, owns interests in a vast array of businesses, many based in Japan but
others that operate throughout the world.


10


---

Berkshire made its first purchases involving the five in July 2019. We simply looked at
their financial records and were amazed at the low prices of their stocks. As the years have
passed, our admiration for these companies has consistently grown. Greg has met many times
with them, and I regularly follow their progress. Both of us like their capital deployment, their
managements and their attitude in respect to their investors.


Each of the five companies increase dividends when appropriate, they repurchase their
shares when it is sensible to do so, and their top managers are far less aggressive in their
compensation programs than their U.S. counterparts.


Our holdings of the five are for the very long term, and we are _committed_ to supporting
their boards of directors. From the start, we also agreed to keep Berkshire’s holdings below 10%
of each company’s shares. But, as we approached this limit, the five companies agreed to
moderately relax the ceiling. _Over time_, you will likely see Berkshire’s ownership of all five
increase somewhat.


At yearend, Berkshire’s aggregate cost (in dollars) was $13.8 billion and the market value
of our holdings totaled $23.5 billion.


Meanwhile, Berkshire has consistently – but _not_ pursuant to any formula – increased its
yen-denominated borrowings. All are at fixed rates, no “floaters.” Greg and I have _no_ view on
future foreign exchange rates and therefore seek a position approximating currency-neutrality.
We are required, however, under GAAP rules to regularly recognize in our earnings a calculation
of any gains or losses in the yen we have borrowed and, at yearend, had included $2.3 billion of
after-tax gains due to dollar strength of which $850 million occurred in 2024.


I expect that Greg and his eventual successors will be holding this Japanese position for
many decades and that Berkshire will find other ways to work productively with the five
companies in the future.


We like the current math of our yen-balanced strategy as well. As I write this, the annual
dividend income expected from the Japanese investments in 2025 will total about $812 million
and the interest cost of our yen-denominated debt will be about $135 million.


**The Annual Gathering in Omaha**


I hope you will join us in Omaha on May 3 [rd] . We are following a somewhat changed
schedule this year, but the basics remain the same. Our goal is that you get many of your
questions answered, that you connect with friends, and that you leave with a good impression of
Omaha. The city looks forward to your visits.


11


---

We will have much the same group of volunteers to offer you a wide variety of Berkshire
products that will lighten your wallet and brighten your day. As usual, we will be open on Friday
from noon until 5 p.m. with lovable Squishmallows, underwear from Fruit of the Loom, Brooks
running shoes and a host of other items to tempt you.


Again, we will have only one book for sale. Last year we featured _Poor Charlie’s_
_Almanack_ and sold out – 5,000 copies disappeared before the close of business on Saturday.


This year we will offer _60 Years of Berkshire Hathaway_ . In 2015, I asked Carrie Sova,
who among her many duties managed much of the activity at the annual meeting, to try her hand
at putting together a light-hearted history of Berkshire. I gave her full reign to use her
imagination, and she quickly produced a book that blew me away with its ingenuity, contents and
design.


Subsequently, Carrie left Berkshire to raise a family and now has three children. But each
summer, the Berkshire office force gets together to watch the Omaha Storm Chasers play
baseball against a Triple A opponent. I ask a few alums to join us, and Carrie usually comes with
her family. At this year’s event, I brazenly asked her if she would do a 60 [th] Anniversary issue,
featuring Charlie’s photos, quotes and stories that have seldom been made public.


Even with three young children to manage, Carrie immediately said “yes.” Consequently,
we will have 5,000 copies of the new book available for sale on Friday afternoon and from
7 a.m. to 4 p.m. on Saturday.


Carrie refused any payment for her extensive work on the new “Charlie” edition. I
suggested she and I co-sign 20 copies to be given to any shareholder contributing $5,000 to the
Stephen Center that serves homeless adults and children in South Omaha. The Kizer family,
beginning with Bill Kizer, Sr., my long-time friend and Carrie’s grandfather, have for decades
been assisting this worthy institution. Whatever is raised through the sale of the 20 autographed
books, I will match.

                    -***********
Becky Quick will cover our somewhat re-engineered gathering on Saturday. Becky
knows Berkshire like a book and always arranges interesting interviews with managers,
investors, shareholders and an occasional celebrity. She and her CNBC crew do a great job of
both transmitting our meetings worldwide and archiving much Berkshire-related material. Give
our director, Steve Burke, credit for the archive idea.


We will not have a movie this year but rather will convene a bit earlier at 8 a.m. I will
make a few introductory remarks, and we will promptly get to the Q&A, alternating questions
between Becky and the audience.


12


---

Greg and Ajit will join me in answering questions and we will take a half-hour break at
10:30 a.m. When we reconvene at 11:00 a.m., only Greg will join me on stage. This year we will
disband at 1:00 p.m. but stay open for shopping in the exhibit area until 4:00 p.m.


You can find the full details regarding weekend activities on page 16. Note particularly
the always-popular Brooks run on Sunday morning. (I will be sleeping.)


                    -***********
My wise and good-looking sister, Bertie, of whom I wrote last year, will be attending the
meeting along with two of her daughters, both good-looking as well. Observers all agree that the
genes producing this dazzling result flow down _only_ the female side of the family. (Sob.)


Bertie is now 91 and we talk regularly on Sundays using old-fashion telephones for
communications. We cover the joys of old age and discuss such exciting topics as the relative
merits of our canes. In my case, the utility is limited to the avoidance of falling flat on my face.


But Bertie regularly one-ups me by asserting that she enjoys an additional benefit: When
a woman uses a cane, she tells me, men quit “hitting” on her. Bertie’s explanation is that the male
ego is such that little old ladies with canes simply aren’t an appropriate target. Presently, I have
no data to counter her assertion.


But I have suspicions. At the meeting I can’t see much from the stage, and I would
appreciate it if attendees would keep an eye on Bertie. Let me know if the cane is really doing its
job. My bet is that she will be _surrounded_ by males. For those of a certain age, the scene will
bring back memories of Scarlett O’Hara and her horde of male admirers in _Gone with the Wind_ .


                    -***********
The Berkshire directors and I immensely enjoy having you come to Omaha, and I predict
that you will have a good time and likely make some new friends.


February 22, 2025 Warren E. Buffett
Chairman of the Board


13


---

**Berkshire’s Performance vs. the S&P 500**


Annual Percentage Change


in S&P 500
with Dividends
Included


Year


in Per-Share
Market Value of
Berkshire


1965 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 49.5% 10.0%


1966 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (3.4) (11.7)


1967 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 13.3 30.9


1968 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 77.8 11.0


1969 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 19.4 (8.4)


1970 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (4.6) 3.9


1971 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 80.5 14.6


1972 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 8.1 18.9


1973 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (2.5) (14.8)


1974 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (48.7) (26.4)


1975 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2.5 37.2


1976 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 129.3 23.6


1977 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 46.8 (7.4)


1978 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 14.5 6.4


1979 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 102.5 18.2


1980 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 32.8 32.3


1981 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 31.8 (5.0)


1982 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 38.4 21.4


1983 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 69.0 22.4


1984 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (2.7) 6.1


1985 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 93.7 31.6


1986 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 14.2 18.6


1987 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 4.6 5.1


1988 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 59.3 16.6


1989 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 84.6 31.7


1990 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (23.1) (3.1)


1991 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 35.6 30.5


1992 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 29.8 7.6


1993 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 38.9 10.1


1994 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 25.0 1.3


**Note:** Data are for calendar years with these exceptions: 1965 and 1966, year ended 9/30; 1967, 15 months ended 12/31.


14


---

**Berkshire’s Performance vs. the S&P 500**


Annual Percentage Change


in S&P 500
with Dividends
Included


Year


in Per-Share
Market Value of
Berkshire


1995 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 57.4% 37.6%


1996 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 6.2 23.0


1997 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 34.9 33.4


1998 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 52.2 28.6


1999 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (19.9) 21.0


2000 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 26.6 (9.1)


2001 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 6.5 (11.9)


2002 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (3.8) (22.1)


2003 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 15.8 28.7


2004 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 4.3 10.9


2005 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 0.8 4.9


2006 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 24.1 15.8


2007 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 28.7 5.5


2008 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (31.8) (37.0)


2009 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2.7 26.5


2010 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 21.4 15.1


2011 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (4.7) 2.1


2012 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 16.8 16.0


2013 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 32.7 32.4


2014 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 27.0 13.7


2015 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . (12.5) 1.4


2016 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 23.4 12.0


2017 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 21.9 21.8


2018 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2.8 (4.4)


2019 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 11.0 31.5


2020 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2.4 18.4


2021 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 29.6 28.7


2022 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 4.0 (18.1)


2023 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 15.8 26.3


2024 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 25.5 25.0


Compounded Annual Gain – 1965-2024 . . . . . . . . . . . . . . . . . . . . 19.9% 10.4%


Overall Gain – 1964-2024 . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 5,502,284% 39,054%


15


---

**BERKSHIRE HATHAWAY INC.**
**SHAREHOLDER EVENT INFORMATION**


**SHAREHOLDER MEETING SCHEDULE – SATURDAY, MAY 3**

CHI Health Center
7:00am Doors Open
8:00am Q&A Session
10:30am Break
11:00am Q&A Session
1:00pm Recess
2:00pm Annual Shareholders Meeting
4:00pm Exhibit Hall Closes


Details: Becky Quick, of CNBC will review questions that shareholders have submitted by e-mail and select those she believes will
have the widest interest. Questions can be submitted to Becky at berkshirequestions@cnbc.com. We will have a drawing at 7:45am at
each of the 11 microphone locations for those shareholders wishing to ask questions themselves. At the meeting, Warren will alternate
the questions asked by Becky and the shareholders in attendance.


At the 8am session, Warren as well as Greg and Ajit will be available to answer questions. At the 11am session, Warren and Greg will
be available to answer questions.


The Berkshire Q&A Session will be broadcast on CNBC and webcast in English and Mandarin beginning at 7:30am central time. Visit
www.cnbc.com/brklive.


**OTHER SHAREHOLDER EVENTS INFORMATION**


Friday, May 2


**Shareholder Shopping Day-CHI Health Center** Noon – 5pm

Details: An extended afternoon of shopping for our shareholders.

**Borsheims Shareholder-Only Shopping Night** 6pm – 8pm

Saturday, May 3

**NFM’s Berkshire Picnic** 4pm – 8pm

Details: NFM will be hosting a Berkshire Picnic at the Omaha store with food and live entertainment.


Sunday, May 4

**Berkshire Hathaway “Invest in Yourself” 5K presented by Brooks** 8am – 11am


Details: Run, Jog, or Walk towards the best version of yourself at the Invest in Yourself 5K presented by Brooks Running. Brooks and
Berkshire Hathaway encourage you to join us for the annual 5K through the streets of Downtown Omaha. Location: Gene Leahy Mall.
Registration opens on March 1, 2025. Register by visiting www.investinyourself5k.com.


**Borsheims Shareholder-Only Shopping Day** 11am – 4pm


**NFM Shareholder Discount Period**
Wednesday, April 23 through Tuesday, May 6
(Discounts also available in Dallas/Fort Worth, Kansas City and Des Moines Stores.)
Omaha Store Hours:
Sunday – Friday: 11am – 8pm | Saturday: 10am – 8pm


**Borsheims Shareholder Discount Period**
Saturday, April 26 through Sunday, May 11
Store Hours:
Monday – Friday*: 10am – 6pm
Saturday**: 10am – 5pm | Sunday***Closed

_* Shareholder-Only Shopping Night, Friday, May 2 / 6 – 8pm_
_** Shareholder Shopping Day, Saturday, May 3 / 10am – 5pm_
_*** Shareholder-Only Shopping Day Sunday, May 4 / 11am – 4pm_


16


---

**UNITED STATES**
**SECURITIES AND EXCHANGE COMMISSION**
**Washington, D.C. 20549**
**FORM 10-K**
**☑** **ANNUAL REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934**
For the fiscal year ended December 31, 2024
OR
**☐** **[TRANSITION REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF]**
**1934**
For the transition period from _________ to ________
Commission file number 001-14905
**BERKSHIRE HATHAWAY INC.**
**(Exact name of Registrant as specified in its charter)**
Delaware 47-0813844
State or other jurisdiction of (I.R.S. Employer
incorporation or organization Identification No.)


3555 Farnam Street, Omaha, Nebraska 68131
(Address of principal executive office) (Zip Code)
Registrant’s telephone number, including area code (402) 346-1400
**Securities registered pursuant to Section 12(b) of the Act:**
**Title of each class** **Trading Symbols** **Name of each exchange on which registered**
Class A Common Stock BRK.A New York Stock Exchange
Class B Common Stock BRK.B New York Stock Exchange
0.000% Senior Notes due 2025 BRK25 New York Stock Exchange
1.125% Senior Notes due 2027 BRK27 New York Stock Exchange
2.150% Senior Notes due 2028 BRK28 New York Stock Exchange
1.500% Senior Notes due 2030 BRK30 New York Stock Exchange
2.000% Senior Notes due 2034 BRK34 New York Stock Exchange
1.625% Senior Notes due 2035 BRK35 New York Stock Exchange
2.375% Senior Notes due 2039 BRK39 New York Stock Exchange
0.500% Senior Notes due 2041 BRK41 New York Stock Exchange
2.625% Senior Notes due 2059 BRK59 New York Stock Exchange


Class A Common Stock BRK.A New York Stock Exchange
Class B Common Stock BRK.B New York Stock Exchange
0.000% Senior Notes due 2025 BRK25 New York Stock Exchange
1.125% Senior Notes due 2027 BRK27 New York Stock Exchange
2.150% Senior Notes due 2028 BRK28 New York Stock Exchange
1.500% Senior Notes due 2030 BRK30 New York Stock Exchange
2.000% Senior Notes due 2034 BRK34 New York Stock Exchange
1.625% Senior Notes due 2035 BRK35 New York Stock Exchange
2.375% Senior Notes due 2039 BRK39 New York Stock Exchange
0.500% Senior Notes due 2041 BRK41 New York Stock Exchange
2.625% Senior Notes due 2059 BRK59 New York Stock Exchange

**Securities registered pursuant to Section 12(g) of the Act: NONE**


BRK.A
BRK.B
BRK25
BRK27
BRK28
BRK30
BRK34
BRK35
BRK39
BRK41
BRK59


Indicate by check mark if the Registrant is a well-known seasoned issuer, as defined in Rule 405 of the Securities Act. Yes **☑** No **☐**


Indicate by check mark if the Registrant is not required to file reports pursuant to Section 13 or Section 15(d) of the Act. Yes **☐** No **☑**
Indicate by check mark whether the Registrant (1) has filed all reports required to be filed by Section 13 or 15(d) of the Securities Exchange
Act of 1934 during the preceding 12 months (or for such shorter period that the Registrant was required to file such reports), and (2) has been
subject to such filing requirements for the past 90 days. Yes **☑** No **☐**
Indicate by check mark whether the Registrant has submitted electronically every Interactive Data File required to be submitted pursuant to
Rule 405 of Regulation S-T (§232.405 of this chapter) during the preceding 12 months (or for such shorter period that the Registrant was
required to submit such files). Yes **☑** No **☐**
Indicate by check mark whether the Registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, a smaller reporting
company, or an emerging growth company. See the definitions of “large accelerated filer,” “accelerated filer,” “smaller reporting company,”
and “emerging growth company” in Rule 12b-2 of the Exchange Act. Large accelerated filer **☑** Accelerated filer **☐**
Non-accelerated filer **☐** Smaller reporting company **☐** Emerging growth company **☐**
If an emerging growth company, indicate by check mark if the Registrant has elected not to use the extended transition period for complying
with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. **☐**
Indicate by check mark whether the Registrant has filed a report on and attestation to its management’s assessment of the effectiveness of its
internal control over financial reporting under Section 404(b) of the Sarbanes-Oxley Act (15 U.S.C. 7262(b)) by the registered public
accounting firm that prepared or issued its audit report. **☑**
If securities are registered pursuant to Section 12(b) of the Act, indicate by check mark whether the financial statements of the Registrant
included in the filing reflect the correction of an error to previously issued financial statements. **☐**
Indicate by check mark whether any of those error corrections are restatements that required a recovery analysis of incentive-based
compensation received by any of the Registrant’s executive officers during the relevant recovery period pursuant to §240.10D-1(b). **☐**


Indicate by check mark whether the Registrant is a shell company (as defined in Rule 12b-2 of the Act). Yes **☐** No **☑**
State the aggregate market value of the voting stock held by non-affiliates of the Registrant as of June 30, 2024: $749,400,000,000
Indicate the number of shares outstanding of each of the Registrant’s classes of common stock:
February 10, 2025—Class A common stock, $5 par value 546,189 shares
February 10, 2025—Class B common stock, $0.0033 par value 1,338,051,639 shares
**DOCUMENTS INCORPORATED BY REFERENCE**
Portions of the Proxy Statement for the Registrant’s Annual Meeting to be held May 3, 2025 are incorporated in Part III.


---

**Table of Contents**


**Part I**


**Page No.**


#### Item 1. Business Description ............................................................................................ K-1 Item 1A. Risk Factors ...................................................................................................... K-24 Item 1B. Unresolved Staff Comments ................................................................................... K-27 Item 1C. Cybersecurity .................................................................................................... K-27 Item 2. Description of Properties ....................................................................................... K-28 Item 3. Legal Proceedings ............................................................................................... K-31 Item 4. Mine Safety Disclosures ........................................................................................ K-31

**Part II**


**Item 5.** **Market for Registrant’s Common Equity, Related Security Holder Matters and Issuer**

#### Purchases of Equity Securities ............................................................................. K-31 Item 6. [Reserved] ........................................................................................................ K-32 Item 7. Management’s Discussion and Analysis of Financial Condition and Results of Operations ......... K-33 Item 7A. Quantitative and Qualitative Disclosures About Market Risk ........................................... K-63 Item 8. Financial Statements and Supplementary Data ............................................................ K-64 Consolidated Balance Sheets— December 31, 2024 and December 31, 2023 ............................ K-66

Consolidated Statements of Earnings—

#### Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 .................... K-68

Consolidated Statements of Comprehensive Income—

#### Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 .................... K-69

Consolidated Statements of Changes in Shareholders’ Equity—

#### Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 .................... K-69

Consolidated Statements of Cash Flows—

#### Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 .................... K-70 Notes to Consolidated Financial Statements ................................................................. K-71 Item 9. Changes in and Disagreements with Accountants on Accounting and Financial Disclosure ........ K-117 Item 9A. Controls and Procedures ....................................................................................... K-117 Item 9B. Other Information .............................................................................................. K-117 Item 9C. Disclosure Regarding Foreign Jurisdictions that Prevent Inspection ................................... K-117


#### ............................................................................. ........................................................................................................ Management’s Discussion and Analysis of Financial Condition and Results of Operations ......... Quantitative and Qualitative Disclosures About Market Risk ........................................... ............................................................ Consolidated Balance Sheets— December 31, 2024 and December 31, 2023 ............................


#### .................... .................... ....................


#### Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 .................... ................................................................. ........ ....................................................................................... .............................................................................................. ...................................


**Part III**


#### ................................................ .......................................................................................


**Item 10.** **Directors, Executive Officers and Corporate Governance** K-117

#### Item 11. Executive Compensation ....................................................................................... K-117

**Item 12.** **Security Ownership of Certain Beneficial Owners and Management and Related**

#### Stockholder Matters ......................................................................................... K-117 Item 13. Certain Relationships and Related Transactions and Director Independence ......................... K-117 Item 14. Principal Accountant Fees and Services ..................................................................... K-117


#### ......................................................................................... ......................... .....................................................................


**Part IV**

#### Item 15. Exhibits and Financial Statement Schedules ................................................................ K-117 Exhibit Index .................................................................................................................... K-121

Signatures........................................................................................................................ K-123


---

**Part I**


**Item 1. Business Description**


Berkshire Hathaway Inc. (“Berkshire,” “Company” or “Registrant”) is a holding company owning subsidiaries engaged
in numerous diverse business activities. The most important of these are insurance businesses conducted on both a primary
basis and a reinsurance basis, a freight rail transportation business and a group of utility and energy generation and distribution
businesses. Berkshire also owns and operates numerous other businesses engaged in a variety of manufacturing, services and
retailing activities. Berkshire is domiciled in the state of Delaware, and its corporate headquarters is in Omaha, Nebraska.


Berkshire’s senior corporate management is responsible for establishing and monitoring Berkshire’s corporate
governance practices, including monitoring governance efforts, including those at the operating businesses, and participating
in the resolution of governance-related issues as needed. Berkshire’s Board of Directors is responsible for selecting an
appropriate successor to the Chief Executive Officer. The Berkshire Code of Business Conduct and Ethics emphasizes, among
other things, the commitment to ethics and compliance with government laws and regulations and provides basic standards for
ethical and legal behavior of its employees.


Human capital and resources are an integral and essential component of Berkshire’s businesses. Berkshire and its
operating subsidiaries employed approximately 392,400 people worldwide at the end of 2024, of which approximately 80%
were in the United States (“U.S.”) and 20% were represented by unions. Employees engage in a wide variety of occupations.
Consistent with Berkshire’s decentralized management philosophy, Berkshire’s operating subsidiaries each establish specific
policies and practices concerning the attraction and retention of personnel within their organizations. Given the wide variations
in the nature and size of business activities, specific policies and practices vary among Berkshire’s operating subsidiaries.
Policies and practices commonly address, among other things: maintaining a safe work environment and minimizing or
eliminating workplace injuries; offering competitive compensation, which includes various health insurance and retirement
benefits, as well as incentives to recognize and reward performance; wellness programs; training, learning and career
advancement opportunities; and hiring practices intended to identify qualified candidates. Berkshire’s combined U.S.
workforce data, based on U.S. Equal Employment Opportunity Commission guidelines, is available on its website
(https://www.berkshirehathaway.com), under sustainability.


**Insurance Businesses**


Berkshire’s insurance business activities are conducted through numerous domestic and foreign-based insurance
subsidiaries. Berkshire’s insurance subsidiaries provide insurance and reinsurance of property and casualty risks as well as life
and health risks worldwide. Berkshire’s insurance businesses employed approximately 41,500 people at the end of 2024. For
purposes of this discussion, entities that provide insurance or reinsurance are referred to as insurers.


In direct or primary insurance activities, the insurer assumes the risk of loss from people or organizations that are directly
subject to the risks. Such risks may relate to property, casualty (or liability), life, accident, health, financial or other perils that
arise from an insurable event. In reinsurance activities, the insurer assumes defined portions of risks that other direct insurers
or reinsurers assumed in their own insuring activities.


Insurance and reinsurance are generally subject to regulatory oversight throughout the world. Except for regulatory
considerations, there are virtually no barriers to entry into the insurance and reinsurance industry. Competitors may be domestic
or foreign, as well as licensed or unlicensed. The number of competitors within the industry is not known. Insurers compete on
the basis of reliability, financial strength and stability, financial ratings, underwriting consistency, service, business ethics,
price, performance, capacity, policy terms and coverage conditions.


Insurers based in the U.S. are subject to regulation by their states of domicile and by those states in which they are
licensed to write policies on an admitted basis. The primary focus of state regulation is to monitor financial solvency of insurers
and otherwise protect policyholder interests. States establish minimum capital levels for insurance companies and establish
guidelines for permissible business and investment activities and have the authority to suspend or revoke a company’s authority
to do business. States regulate the payment of shareholder dividends by insurance companies and other transactions with
affiliates.


K-1


---

Insurers that market, sell and service insurance policies in the states where they are licensed are referred to as admitted
insurers. Admitted insurers are generally required to obtain regulatory approval of their policy forms and/or premium rates.
Non-admitted insurance markets have developed to provide insurance that is otherwise unavailable through admitted insurers.
Non-admitted insurance, often referred to as “excess and surplus” lines, is procured by either state-licensed surplus lines brokers
who place risks with insurers not licensed in that state or by the insured party’s direct procurement from non-admitted insurers.
Non-admitted insurance is subject to considerably less regulation with respect to policy rates and forms. Reinsurers are
normally not required to obtain regulatory approval of premium rates or reinsurance contracts.


The insurance regulators of every state participate in the National Association of Insurance Commissioners (“NAIC”).
The NAIC adopts forms, instructions and accounting procedures for use by U.S. insurers in preparing and filing annual statutory
financial statements. In addition, the NAIC develops or adopts statutory accounting principles, model laws, regulations and
programs dealing with regulatory oversight of solvency, risk management, compliance with financial regulation standards and
risk-based capital reporting requirements. However, an insurer’s state of domicile has ultimate authority over these solvency
and soundness related matters, and the laws and regulations implemented in individual states may differ from those adopted by
the NAIC.


International insurance regulators, through the International Association of Insurance Supervisors (“IAIS”), have been
developing advisory standards and best practices focused on establishing a common set of principles (“Insurance Core
Principles”) and framework (“ComFrame”) for the regulation of large multi-national insurance groups. The Insurance Core
Principles and ComFrame cover a wide range of topics, including group-wide supervision by regulators, corporate governance,
risk management, capital adequacy and other macroprudential issues. As part of ComFrame, the IAIS adopted an international
capital standard (“ICS”) for internationally active insurance groups in December 2024.


While the IAIS standards do not have legal effect, U.S. state insurance departments and the NAIC are implementing
various group supervision regulatory tools and mandates that are responsive to certain IAIS standards. U.S. state regulators
have formed supervisory colleges intended to promote communication and cooperation amongst the various domestic and
international insurance regulators. U.S. state regulators require insurance groups to file an annual report and an Own Risk
Solvency Assessment or ORSA, with the group’s lead supervisor. The NAIC also adopted a group capital calculation (“GCC”)
tool for large insurance groups. The NAIC’s GCC is a tool designed to help the lead supervisor understand the capital adequacy
across an insurance group. The NAIC is also developing further tools, including various liquidity assessments, that will likely
be imposed on insurance groups in the future. While the ICS is based on a consolidation approach, the GCC is based on an
aggregation approach called the Aggregation Method. In December 2024, the IAIS announced that the Aggregation Method
has been deemed to be comparable to the ICS.


The Nebraska Department of Insurance (“Nebraska DOI”) acts as the lead supervisor for Berkshire’s insurance group
and chairs the Berkshire supervisory college. The Nebraska DOI adopted the GCC tool, and Berkshire’s insurance subsidiaries
are required to submit an annual GCC to it.


Berkshire’s insurance companies maintain capital strength at exceptionally high levels, which differentiates them from
their competitors. The combined statutory surplus of Berkshire’s U.S.-based insurers was approximately $310 billion at
December 31, 2024. Berkshire’s major insurance subsidiaries are rated AA+ by Standard & Poor’s and A++ (superior) by A.M.
Best with respect to their financial condition and claims paying ability.


The Terrorism Risk Insurance Act of 2002 established a Terrorism Insurance Program (“Program”) within the U.S.
Department of the Treasury to provide federal reinsurance of certified terrorism losses incurred by U.S. commercial property
and casualty insurers. The Program extends to December 31, 2027 through the Terrorism Risk Insurance Program
Reauthorization Act of 2019. Hereinafter these Acts are collectively referred to as TRIA. The Department of the Treasury is
responsible for certifying acts of terrorism under TRIA. Federal reinsurance under TRIA may apply if the industry insured loss
for certified events occurring during the calendar year exceeds $200 million.


To be eligible for reinsurance under TRIA, insurers must make insurance coverage available for acts of terrorism by
providing policyholders with clear and conspicuous notice of the amount of premium that will be charged for the coverage and
the federal share of insured losses resulting from an act of terrorism. TRIA excludes certain forms of direct insurance, such as
personal and commercial auto, burglary, theft, surety and certain professional liability lines. Reinsurers are not required to offer
terrorism coverage and are not eligible for federal reinsurance of terrorism losses.


In the event of a certified act of terrorism, the federal government will reimburse insurers (conditioned on their
satisfaction of policyholder notification requirements) for 80% of their insured losses in excess of the insurers group deductible.
Under TRIA, the deductible is 20% of the aggregate direct subject earned premium for relevant commercial lines of business
in the immediately preceding calendar year. The aggregate deductible for Berkshire’s insurance group is expected to be
approximately $2.6 billion in 2025. There is also an aggregate program limit of $100 billion on the amount of the federal
reinsurance coverage for each TRIA year.


K-2


---

The extent of insurance regulation varies widely among the countries where Berkshire’s non-U.S. operations conduct
business. Each country imposes licensing, solvency, risk management and financial reporting requirements, although the type
and extent of the requirements may differ substantially by jurisdiction.


Significant variations can also be found in the size, structure and resources of the local non-U.S. regulatory departments
that oversee insurance activities. Certain regulators maintain close relationships with subject insurers and others operate a riskbased approach.


Berkshire’s non-U.S. insurance operations are conducted through subsidiaries and branches of subsidiaries. Non-U.S.
insurance subsidiaries are primarily located in Germany, Ireland, the United Kingdom (“U.K.”), Australia and South Africa,
and branches are also maintained in several other countries. Most of these foreign jurisdictions impose local capital
requirements. Other legal requirements involve discretionary licensing procedures, risk management and governance
requirements, local retention of funds and records, and data privacy and protection programs. Berkshire’s international
insurance companies are also subject to multinational application of certain U.S. laws. There are various regulatory bodies and
initiatives that impact Berkshire in multiple international jurisdictions, and the potential for significant effect on the Berkshire
insurance group could be heightened due to industry and economic developments.


Berkshire’s insurance underwriting operations include the following groups: (1) GEICO, (2) Berkshire Hathaway
Primary Group and (3) Berkshire Hathaway Reinsurance Group. Alleghany Corporation (“Alleghany”), based in New York,
New York, was acquired by Berkshire on October 19, 2022. Alleghany’s operating subsidiaries include property and casualty
reinsurance and insurance businesses. Alleghany’s primary insurance businesses are included in the Berkshire Hathaway
Primary Group and its reinsurance businesses are included in the Berkshire Hathaway Reinsurance Group.


Except for retroactive reinsurance and periodic payment annuity products, which generate significant amounts of upfront premiums along with estimated claims expected to be paid over long time periods (creating “float,” see Investments
section), Berkshire expects to achieve an underwriting profit over time and that its managers will reject inadequately priced
risks. Underwriting profit is defined as earned premiums less incurred insurance losses and benefits, loss adjustment expenses
and policy acquisition and other underwriting expenses. Underwriting profit does not include income earned from investments.
Additional information related to each of Berkshire’s underwriting groups follows.


**GEICO** —GEICO is headquartered in Chevy Chase, Maryland. GEICO’s insurance subsidiaries include Government
Employees Insurance Company and several other insurance entities. The GEICO insurance subsidiaries’ principal business is
the sale of private passenger automobile insurance to individuals in all 50 states and the District of Columbia. GEICO
subsidiaries also sell insurance for motorcycles, all-terrain vehicles, recreational vehicles, boats and small commercial
automobile fleets. Marketing is primarily through direct response methods in which applications for insurance are submitted
directly to the companies via the Internet or by telephone, and to a lesser extent, through captive agents. GEICO also operates
an insurance agency that offers insurance written by third parties for individuals desiring insurance coverages that are not sold
by GEICO insurance subsidiaries, such as homeowners, renters, condominium, life and identity protection insurance.


GEICO competes for private passenger automobile insurance customers in the preferred, standard and non-standard risk
markets with other companies that sell directly to the customer and with companies that use agency sales forces, including
State Farm, Progressive, Allstate and USAA. According to the A.M. Best data for 2023 published in 2024, the five largest
automobile insurers had a combined market share of approximately 62.3% based on written premiums, with GEICO’s market
share being the third largest at approximately 12.3%.


Seasonal variations in GEICO’s insurance business are not significant. However, extraordinary weather conditions or
other events and factors may have a significant effect upon the frequency or severity of automobile claims.


GEICO’s insurance policies are written on an admitted basis. State insurance departments stringently regulate private
passenger auto insurance policies and rates. Competition for private passenger automobile insurance tends to focus on price
and level of customer service provided. GEICO’s cost-efficient direct response marketing methods and emphasis on customer
satisfaction enable it to offer competitive rates and value to its customers. GEICO primarily uses its own claims staff to manage
and settle claims. GEICO’s name and other trademarks are considered material assets and are protected through appropriate
registrations.


**Berkshire** **Hathaway** **Primary** **Group** —The Berkshire Hathaway Primary Group (“BH Primary”) is a collection of
independently managed insurers that provide a wide variety of insurance coverages to policyholders located principally in the
U.S. Nearly 90% of BH Primary premiums written in 2024 were in the U.S., of which approximately 60% was written on an
admitted basis, with the remainder written on a non-admitted basis. These various operations are discussed below.


K-3


---

National Indemnity Company (“NICO”), domiciled in Nebraska, and certain affiliates (“NICO Primary”) underwrite
commercial automobile and general liability insurance on an admitted basis and on an excess and surplus lines basis. Insurance
coverage is offered nationwide primarily through insurance agents and brokers.


Berkshire Hathaway Homestate Companies (“BHHC”) is a group of insurers offering workers’ compensation,
commercial automobile and commercial property coverages to a diverse client base. BHHC has a national reach, with the ability
to provide first-dollar and small-to-large deductible workers’ compensation coverage to employers nationwide. NICO Primary
and BHHC are each based in Omaha, Nebraska.


Berkshire Hathaway Specialty Insurance (“BHSI”) offers commercial property and casualty, executive and professional,
and various other insurance coverages through Berkshire Hathaway Specialty Insurance Company and several other Berkshire
subsidiaries. BHSI writes primary and excess policies on an admitted and non-admitted basis in the U.S., and on a local or
foreign non-admitted basis outside the U.S. BHSI is based in Boston, Massachusetts, and has regional offices in several other
cities within the U.S. BHSI also maintains international offices and branches in Australia, Canada, New Zealand and across
several countries in Asia and Europe. BHSI writes insurance policies through wholesale and retail insurance brokers, as well
as through managing general agents.


Alleghany’s property and casualty insurance business is conducted in the U.S. on both an admitted and non-admitted
basis through RSUI Group, Inc. and its subsidiaries (“RSUI”) and CapSpecialty, Inc. and its subsidiaries (“CapSpecialty”).
RSUI and CapSpecialty primarily write specialty insurance in the property, umbrella/excess liability, professional liability,
directors’ and officers’ liability and general liability lines of business. Insurance is written through independent wholesale
insurance brokers, retail agents and managing general agents.


MedPro Group (“MedPro”) is a leading provider of healthcare liability (“HCL”) insurance in the U.S. MedPro provides
customized HCL insurance, as well as claims, patient safety and risk solutions to physicians, surgeons, dentists and other
healthcare professionals, as well as hospitals, senior care and other healthcare facilities. Additionally, MedPro provides HCL
insurance solutions to international markets through other Berkshire insurance affiliates, offers professional liability insurance
to other non-healthcare professionals, and provides specialized accident and health insurance solutions to colleges and other
customers through its subsidiaries and other Berkshire subsidiaries. MedPro is based in Fort Wayne, Indiana. MLMIC
Insurance Company (“MLMIC”) writes medical professional liability insurance policies in New York State through brokers
and on a direct basis to medical and dental professionals, health care providers and hospitals. MLMIC is based in Albany, New
York.


U.S. Liability Insurance Company (“USLI”) includes a group of five specialty insurers that underwrite commercial,
professional and personal lines of insurance on an admitted basis, as well as on an excess and surplus lines basis. USLI markets
policies in all 50 states, the District of Columbia and Canada through wholesale and retail insurance agents. USLI also
underwrites and markets a wide variety of specialty insurance products. USLI is based in Wayne, Pennsylvania. The GUARD
Insurance Companies (“GUARD”) consist of five insurance companies that provide a comprehensive suite of commercial
insurance solutions to over 200,000 small-to-medium sized businesses. These insurance products are accessible through
independent agents and wholesale brokers. GUARD is based in Wilkes-Barre, Pennsylvania.


Berkshire Hathaway Direct Insurance Company and its affiliates (“BH Direct”) offer commercial insurance products
(including workers’ compensation, property, auto, general and professional liability) to small business customers. BH Direct’s
products are primarily sold through two internet-based distribution platforms, biBERK.com and Threeinsurance.com. BH
Direct writes policies on an admitted basis and is based in Stamford, Connecticut.


**Berkshire** **Hathaway** **Reinsurance** **Group** —Berkshire’s combined global reinsurance business, referred to as the
Berkshire Hathaway Reinsurance Group (“BHRG”), offers a wide range of coverages on property, casualty, life and health
risks to insurers and reinsurers worldwide. BHRG conducts business activities in 24 countries. Reinsurance business is written
through NICO and affiliates (“NICO Group”), General Re Corporation and its subsidiaries (“General Re Group”) and
Transatlantic Reinsurance Company and its affiliates (“TransRe Group”). U.S. underwriting operations of the NICO Group
and General Re Group are based in Stamford, Connecticut while the TransRe Group is based in New York, New York.


Reinsurance contracts are normally classified as treaty or facultative. Treaty reinsurance refers to reinsurance coverage
for all or a portion of a specified group or class of risks ceded by a direct insurer or reinsurer, while facultative reinsurance
involves coverage of specific individual underlying risks. Reinsurance contracts are further classified as quota-share or excessof-loss. Under quota-share (proportional or pro-rata) reinsurance, the reinsurer shares proportionally in the original premiums
and losses of the direct insurer or reinsurer. Excess-of-loss (or non-proportional) reinsurance provides for the indemnification
of the direct insurer or reinsurer for all or a portion of the loss in excess of an agreed upon amount or “retention.” Both quotashare and excess-of-loss reinsurance contracts may provide for aggregate limits of indemnification.


K-4


---

The type and volume of business written is dependent on market conditions, including prevailing premium rates and
coverage terms. The level of underwriting activities often fluctuates significantly from year to year depending on the perceived
level of price adequacy in specific insurance and reinsurance markets as well as from the timing of particularly large reinsurance
transactions.


_Property/casualty_


The NICO Group offers traditional property/casualty reinsurance on both an excess-of-loss and a quota-share basis,
catastrophe excess-of-loss treaty and facultative reinsurance, and primary insurance on an excess-of-loss basis for very large
or unusual risks. The type and volume of business written by the NICO Group may vary significantly from period to period
resulting from changes in perceived premium rate adequacy and from unique or large transactions. A significant portion of
NICO Group’s annual reinsurance premium derived from a 20% quota-share agreement with Insurance Australia Group
Limited (“IAG”). This quota-share agreement expires December 31, 2029. IAG is a multi-line insurer in Australia, New
Zealand and other Asia-Pacific countries.


The General Re Group is a global property and casualty reinsurance business. Reinsurance contracts are written on both
a quota-share and excess-of-loss basis for multiple lines of business. Contracts are primarily in the form of treaties, and to a
lesser degree, on a facultative basis. The General Re Group conducts business in North America, primarily marketed on a direct
basis through General Reinsurance Corporation (“GRC”), which is licensed in the District of Columbia and all states, except
Hawaii, where it is an accredited reinsurer. GRC also conducts operations in North America through numerous branch offices
in the U.S. and Canada.


In North America, the General Re Group includes General Star National Insurance Company, General Star Indemnity
Company and Genesis Insurance Company, which offer a broad array of specialty and surplus lines and property, casualty and
professional liability coverages. These companies offer solutions for the unique needs of public entity, commercial and captive
customers and their business is marketed through a select group of wholesale brokers, managing general underwriters and
program administrators.


The General Re Group’s international reinsurance business is primarily written on a direct basis through General
Reinsurance AG, based in Cologne, Germany, and subsidiaries and branches in numerous other countries, as well as through
brokers by Faraday Corporate Capital Limited, which participates in the Lloyd’s of London market through Syndicate 435.


The TransRe Group provides quota-share and excess-of-loss reinsurance across various property and casualty lines of
business. Contracts are written on both a treaty and facultative basis to insurance companies in the U.S. and in foreign markets
through subsidiaries and branches in numerous countries. Business is written primarily through brokers, and to a lesser extent
on a direct basis.


_Life/health_


The General Re Group also conducts a global life and health reinsurance business. In 2024, net premiums written were
primarily in the Asia-Pacific, U.S. and Western Europe regions. The General Re Group underwrites life, disability,
supplemental health, critical illness and long-term care risks on a direct basis.


Berkshire Hathaway Life Insurance Company of Nebraska (“BHLN”) and its affiliates write reinsurance covering
various forms of traditional life insurance exposures and reinsured certain guaranteed minimum death, income and similar risks
on closed-blocks of variable annuity risks, which are in run-off.


_Retroactive reinsurance_


Retroactive reinsurance contracts indemnify ceding companies for adverse development of claims arising from loss
events that have already occurred under property and casualty policies issued in prior years. Coverage under such contracts is
provided on an excess basis (above a stated retention) or for losses payable after the inception of the contract with no additional
ceding company retention. Contracts are normally subject to aggregate limits of indemnification, which can be exceptionally
large in amount. Significant amounts of asbestos, environmental and latent injury claims may arise under these contracts.


The concept of time-value-of-money is an important element in establishing retroactive reinsurance contract prices and
terms since loss payments may occur over decades. Normally, expected ultimate losses payable under these policies are
expected to exceed premiums, thus producing underwriting losses. Nevertheless, this business is written, in part, because of
the large amounts of policyholder funds generated for investment, the economic benefit of which is reflected through
investment results in future periods.


K-5


---

_Periodic payment annuity_


BHLN writes periodic payment annuity insurance policies and reinsures annuity-like obligations. Under these policies,
BHLN receives upfront consideration and agrees in the future to make periodic payments that often extend for decades. These
policies generally relate to the settlement of underlying personal injury or workers’ compensation claims of other insurers,
known as structured settlements. Consistent with retroactive reinsurance contracts, time-value-of-money is an important factor
in establishing annuity premiums and ultimate payments are expected to exceed premiums received, producing underwriting
losses. BHLN wrote no new policies in 2023 and 2024 in response to changing economic and market conditions.


**Investments** **of** **insurance** **businesses** —Berkshire’s insurance subsidiaries hold significant levels of invested assets.
Investment portfolios are managed by Berkshire’s Chief Executive Officer and, to a lesser extent, by two corporate investment
managers. Investments include a very large portfolio of publicly traded equity securities, which are unusually concentrated in
relatively few companies, as well as in short-term investments and fixed maturity securities. Generally, there are no target
allocations by investment type or attempts to match investment asset and insurance liability durations. However, investment
portfolios have historically included a much greater proportion of equity securities than is customary in the insurance industry.


Invested assets derive from shareholder capital as well as funds provided from policyholders through insurance and
reinsurance businesses (“float”). Float represents the approximate net policyholder funds generated through underwriting
activities that are held for investment. The major components of float are unpaid losses and loss adjustment expenses, life,
annuity and health benefit liabilities (excluding the effects of discount rate changes that are recorded in accumulated other
comprehensive income), unearned premiums and other policyholder liabilities less premium and reinsurance receivables,
deferred policy acquisition costs and deferred charges on assumed retroactive reinsurance contracts. On a consolidated basis,
float has grown from approximately $129 billion at the end of 2019 to approximately $171 billion at the end of 2024. The cost
of float can be measured as the net pre-tax underwriting earnings (or loss) as a percentage of average float.


**Burlington Northern Santa Fe**


Burlington Northern Santa Fe, LLC (“BNSF”) is based in Fort Worth, Texas, and through BNSF Railway Company
(“BNSF Railway”) operates one of the largest railroad systems in North America. BNSF Railway had approximately 36,500
employees at the end of 2024, of whom approximately 32,000 were members of a labor union.


In serving the Midwest, Pacific Northwest, Western, Southwestern and Southeastern regions and certain ports of the
U.S., BNSF Railway transports a range of products and commodities derived from manufacturing, agricultural and natural
resource industries. Freight revenues are covered by contractual agreements of varying durations or common carrier published
prices or company quotations. BNSF’s financial performance is influenced by, among other things, general and industry
economic conditions at the international, national and regional levels.


BNSF Railway’s primary routes, including trackage rights, allow it to access major cities and certain ports in the western
and southern U.S. as well as parts of Canada and Mexico. In addition to major cities and ports, BNSF Railway efficiently serves
many smaller markets by working closely with approximately 200 shortline railroads. BNSF Railway has also entered into
marketing agreements with other rail carriers, expanding the marketing reach for each railroad and their customers. Freight
revenues are classified into the following categories: consumer products, industrial products, agricultural products and coal.
The volumes shipped and rates charged are affected by competition from other freight carriers within the transportation
industry, and changes in the underlying supply and demand for such products.


_Regulatory Matters_


BNSF is subject to federal, state and local laws and regulations generally applicable to its businesses. Rail operations are
subject to the regulatory jurisdiction of the Surface Transportation Board (“STB”), the Federal Railroad Administration of the
U.S. Department of Transportation (“DOT”), the Occupational Safety and Health Administration (“OSHA”), the
Environmental Protection Agency (“EPA”), as well as other federal and state regulatory agencies and Canadian regulatory
agencies for operations in Canada. The STB has jurisdiction over disputes and complaints involving certain rates, routes and
services, the sale or abandonment of rail lines, applications for line extensions and construction, and the merger with or
acquisition of control of rail common carriers. The outcome of STB proceedings can affect the profitability of BNSF Railway’s
business.


The DOT, OSHA and EPA have jurisdiction under several federal statutes over a number of safety, health and
environmental aspects of rail operations, including the transportation of hazardous materials. BNSF Railway is required to
transport these materials to the extent of its common carrier obligation. State agencies regulate some health, safety and
environmental aspects of rail operations in areas not otherwise preempted by federal law.


K-6


---

_Environmental Matters_


BNSF’s rail operations, as well as those of its competitors, are also subject to extensive federal, state and local
environmental regulations covering discharges to the ground or waters, air emissions, toxic substances and the generation,
handling, storage, transportation and disposal of waste and hazardous materials. Such regulations effectively increase the costs
and liabilities associated with rail operations. Environmental risks are also inherent in rail operations, which frequently involve
transporting chemicals and other hazardous materials.


Many of BNSF’s land holdings are or have been used for industrial or transportation-related purposes or leased to
commercial or industrial companies whose activities may have resulted in discharges onto the property. Under federal statutes
(in particular, the Comprehensive Environmental Response, Compensation and Liability Act) and state statutes, BNSF may be
held jointly and severally liable for cleanup and enforcement costs associated with a particular site without regard to fault or
the legality of the original conduct. BNSF may also be subject to claims by third parties for investigation, cleanup, restoration
or other environmental costs under environmental statutes or common law with respect to properties they own that have been
impacted by BNSF operations.


Consumption of diesel fuel by locomotives accounted for approximately 80% of BNSF Railway’s greenhouse gas
(“GHG”) emissions in its baseline year of 2018. BNSF management has committed to a broad sustainability model, applying
science-based approaches, that is anticipated to result in a 30% reduction in BNSF Railway’s GHG emissions by 2030 from its
baseline year of 2018. BNSF Railway intends to continue improvements in fuel efficiency and increased utilization of
renewable diesel fuel. Long-term solutions, such as battery-electric and hydrogen locomotives, are also being evaluated and
field-tested.


_Competition_


The business environment in which BNSF Railway operates is highly competitive. Depending on the specific market,
deregulated motor carriers and other railroads, as well as river barges, ships and pipelines, may exert pressure on price and
service levels. The presence of advanced, high service truck lines with expedited delivery, subsidized infrastructure and
minimal empty mileage continues to affect the market for non-bulk, time-sensitive freight. The potential expansion of longer
combination vehicles could further encroach upon markets traditionally served by railroads. In order to remain competitive,
BNSF Railway and other railroads seek to develop and implement operating efficiencies to improve productivity.


As railroads streamline, rationalize and otherwise enhance their franchises, competition among rail carriers intensifies.
BNSF Railway’s primary rail competitor in the Western region of the U.S. is the Union Pacific Railroad Company. Other Class
I railroads and numerous regional railroads and motor carriers also operate in parts of the same territories served by BNSF
Railway.


**Berkshire Hathaway Energy**


Berkshire Hathaway Energy Company (“BHE”) is a holding company headquartered in Iowa with investments in a
diversified portfolio of locally managed and operated businesses, principally within the energy industry. BHE’s domestic
regulated energy interests are comprised of four regulated U.S. utility companies (collectively, “U.S. utilities”) serving
approximately 5.3 million retail customers and five U.S. interstate natural gas pipeline companies with approximately 21,000
miles of operated pipeline having a design capacity of approximately 21.5 billion cubic feet of natural gas per day. Other energy
businesses include electric transmission and distribution operations in Great Britain and Canada, a diversified portfolio of
mostly renewable independent power projects and investments, and a liquefied natural gas export, import and storage facility.
BHE also has an investment in a residential real estate brokerage firm in the U.S. and is a franchisor to a large network of
residential real estate brokerages in the U.S. BHE employs approximately 24,000 people in connection with its various
operations.


_Energy businesses_


BHE’s U.S. utilities include PacifiCorp, MidAmerican Energy Company (“MEC”) and NV Energy, Inc.’s (“NV
Energy”) two regulated utility subsidiaries, Nevada Power Company (“Nevada Power”) and Sierra Pacific Power Company
(“Sierra Pacific”).


PacifiCorp is a regulated electric utility company headquartered in Oregon, serving electric customers in portions of
Utah, Oregon, Wyoming, Washington, Idaho and California. The combined service territory’s diverse regional economy ranges
from rural, agricultural and mining areas to urban, manufacturing and government service centers. No single segment of the
economy dominates the combined service territory, which helps mitigate PacifiCorp’s exposure to economic fluctuations. In
addition to retail sales, PacifiCorp buys and sells electricity on a wholesale basis.


K-7


---

MEC is a regulated electric and natural gas utility company headquartered in Iowa, serving electric and natural gas
customers primarily in Iowa and also in portions of Illinois, South Dakota and Nebraska. MEC’s diverse retail customer base
operates in the electronic data storage, agricultural, manufacturing and government service centers industries. In addition to
retail sales and natural gas transportation, MEC sells electricity and natural gas on a wholesale basis.


Nevada Power serves retail electric customers in southern Nevada and Sierra Pacific serves retail electric and natural gas
customers in northern Nevada. The combined Nevada Power/Sierra Pacific service territory economy includes retail customers
in the gaming, mining, recreation, warehousing, manufacturing and governmental service centers sectors. In addition to retail
sales and natural gas transportation, these utilities buy and sell electricity and natural gas on a wholesale basis.


As vertically integrated utilities, BHE’s U.S. utilities collectively own approximately 31,300 net megawatts of generation
capacity in operation and under construction. The U.S. utilities’ business is subject to seasonal variations principally related to
the use of electricity for air conditioning and natural gas for heating. Typically, regulated electric revenues are higher in the
summer months, while regulated natural gas revenues are higher in the winter months.


The natural gas pipelines consist of BHE GT&S, LLC (“BHE GT&S”), Northern Natural Gas Company (“Northern
Natural”) and Kern River Gas Transmission Company (“Kern River”).


BHE GT&S, based in Virginia, operates three interstate natural gas pipeline systems that consist of approximately 5,400
miles of natural gas transmission, gathering and storage pipelines and operates seventeen underground natural gas storage fields
in the eastern region of the U.S. BHE GT&S’s large underground natural gas storage assets and pipeline systems are part of an
interconnected gas transmission network that provides transportation services to utilities and numerous other customers. BHE
GT&S is also an industry leader in liquefied natural gas solutions through its investments in and ownership of several liquefied
natural gas facilities located throughout the eastern region of the U.S.


Northern Natural, based in Nebraska, operates the largest interstate natural gas pipeline system in the U.S., as measured
by pipeline miles, reaching from west Texas to Michigan’s Upper Peninsula. Northern Natural’s pipeline system consists of
approximately 14,200 miles of natural gas pipelines. Northern Natural’s extensive pipeline system, which is interconnected
with many interstate and intrastate pipelines in the national grid system, has access to supplies from multiple major supply
basins and provides transportation services to utilities and numerous other customers. Northern Natural also operates three
underground natural gas storage facilities and two liquefied natural gas storage peaking units. Northern Natural’s pipeline
system experiences significant seasonal swings in demand and revenue, with the highest demand typically occurring during the
months of November through March.


Kern River, based in Utah, operates an interstate natural gas pipeline system that consists of approximately 1,400 miles
and extends from supply areas in the Rocky Mountains to consuming markets in Utah, Nevada and California. Kern River
transports natural gas for electric and natural gas distribution utilities, major oil and natural gas companies or affiliates of such
companies, electric generating companies, energy marketing and trading companies, and financial institutions.


Other energy businesses include Northern Powergrid (Northeast) plc and Northern Powergrid (Yorkshire) plc, which
own a substantial electricity distribution network that delivers electricity to end-users in northeast England in an area covering
approximately 10,000 square miles. These distribution companies primarily charge supply companies regulated tariffs for the
use of their distribution systems and serve about 4.0 million electricity end-users. AltaLink L.P. (“AltaLink”) is a regulated
electric transmission-only utility company headquartered in Calgary, Alberta. AltaLink’s high voltage transmission lines and
related facilities transmit electricity from generating facilities to major load centers, cities and large industrial plants throughout
its 87,000 square mile service territory. AltaLink serves approximately 85% of Alberta’s population. BHE and its subsidiaries,
also own interests in independent power projects having approximately 6,100 net megawatts of generation capacity that are in
service and under construction in California, Texas, Illinois, Nebraska, Montana, Australia, New York, Arizona, Canada, West
Virginia, Minnesota, Kansas, Iowa and Hawaii. These independent power projects sell power generated primarily from wind,
solar, geothermal and hydro sources under long-term contracts. Additionally, BHE subsidiaries have invested approximately
$7.3 billion to-date in wind projects sponsored by third parties, commonly referred to as tax equity investments.


K-8


---

_Regulatory Matters_


The U.S. utilities are subject to comprehensive regulation by various federal, state and local agencies. The Federal Energy
Regulatory Commission (“FERC”) is an independent agency with broad authority to implement provisions of the Federal
Power Act, the Energy Policy Act of 2005 and other federal statutes. The FERC regulates rates for wholesale sales of electricity;
transmission of electricity, including pricing and regional planning for the expansion of transmission systems; electric system
reliability; utility holding companies; accounting and records retention; securities issuances; construction and operation of
hydroelectric facilities; and other matters. The FERC also has the enforcement authority to assess civil penalties of up to $1.6
million per day per violation of rules, regulations and orders issued under the Federal Power Act. MEC is also subject to
regulation by the Nuclear Regulatory Commission pursuant to the Atomic Energy Act of 1954, as amended, with respect to its
25% ownership of the Quad Cities Nuclear Station.


With certain limited exceptions, the U.S. utilities have an exclusive right to serve retail customers within their service
territories and, in turn, have an obligation to provide service to those customers. In some jurisdictions, certain classes of
customers may choose to purchase all or a portion of their energy from alternative energy suppliers, and in some jurisdictions
retail customers can generate all or a portion of their own energy. Historically, state regulatory commissions have established
retail electric and natural gas rates on a cost-of-service basis, which are designed to allow a utility the opportunity to recover
what each state regulatory commission deems to be the utility’s reasonable costs of providing services, including the
opportunity to earn a fair and reasonable return on its investments based on its cost of debt and equity. The retail electric rates
of U.S. utilities are generally based on the cost of providing traditional bundled services, including generation, transmission
and distribution services; however, rates are available for transmission-only and distribution-only services.


Northern Powergrid (Northeast) plc and Northern Powergrid (Yorkshire) plc each charge fees for the use of their
distribution systems that are controlled by a formula prescribed by the Gas and Electricity Markets Authority, the British
electricity regulatory body. The current electricity distribution price control runs from April 1, 2023 through March 31, 2028.


AltaLink is regulated by the Alberta Utilities Commission (“AUC”), pursuant to the Electric Utilities Act (Alberta), the
Public Utilities Act (Alberta), the Alberta Utilities Commission Act (Alberta) and the Hydro and Electric Energy Act (Alberta).
The AUC is an independent quasi-judicial agency, which regulates and oversees Alberta’s electricity transmission sector with
broad authority that may impact many of AltaLink’s activities, including its tariffs, rates, construction, operations and
financing. Under the Electric Utilities Act, AltaLink prepares and files applications with the AUC for approval of tariffs to be
paid by the Alberta Electric System Operator (“AESO”) for the use of its transmission facilities, and the terms and conditions
governing the use of those facilities. The AESO is an independent system operator in Alberta, Canada that oversees Alberta’s
integrated electrical system (“AIES”) and wholesale electricity market. The AESO is responsible for directing the safe, reliable
and economic operation of the AIES, including long-term transmission system planning.


The natural gas pipelines are subject to regulation by various federal and state agencies. The natural gas pipeline and
storage operations of BHE GT&S, Northern Natural and Kern River are regulated by the FERC pursuant to the Natural Gas
Act and the Natural Gas Policy Act of 1978. Under this authority, the FERC regulates, among other items, (a) rates, charges,
terms and conditions of service; (b) the construction and operation of interstate pipelines, storage and related facilities, including
the extension, expansion or abandonment of such facilities; and (c) the construction and operation of liquefied natural gas
export/import facilities. Interstate natural gas pipeline companies are also subject to regulations administered by the Office of
Pipeline Safety within the Pipeline and Hazardous Materials Safety Administration, an agency of the DOT. Federal pipeline
safety regulations are issued pursuant to the Natural Gas Pipeline Safety Act of 1968, as amended, which establishes safety
requirements in the design, construction, operation and maintenance of interstate natural gas pipeline facilities.


_Environmental Matters_


BHE and its energy businesses are subject to federal, state, local and foreign laws and regulations regarding air quality,
climate change, emissions performance standards, water quality, coal ash disposal and other environmental matters that have
the potential to impact current and future operations. In addition to imposing continuing compliance obligations, these laws
and regulations, such as the Federal Clean Air Act, provide regulators with the authority to levy substantial penalties for
noncompliance, including fines, injunctive relief and other sanctions.


The Federal Clean Air Act, as well as state laws and regulations impacting air emissions, provides a framework for
protecting and improving the nation’s air quality and controlling sources of air emissions. The implementation of these laws
and regulations may impact the operation of BHE’s generating facilities, including requiring reductions in emissions at those
facilities to comply with the requirements. In addition, the potential adoption of state or federal clean energy standards, which
include low-carbon, non-carbon and renewable electricity generating resources, may also impact electricity generators and
natural gas providers.


K-9


---

In December 2015, an international agreement was negotiated by 195 nations to create a universal framework for
coordinated action on climate change in what is referred to as the Paris Agreement. The Paris Agreement reaffirms the goal of
limiting global temperature increase well below 2 degrees Celsius, while urging efforts to limit the increase to 1.5 degrees
Celsius and reaching a global peak of GHG emissions as soon as possible to achieve climate neutrality by mid-century;
establishes commitments by all parties to make nationally determined contributions and pursue domestic measures aimed at
achieving the commitments; commits all countries to submit emissions inventories and report regularly on their emissions and
progress made in implementing and achieving their nationally determined commitments; and commits all countries to submit
new commitments every five years, with the expectation that the commitments will be more aggressive in reducing GHG
emissions. In the context of the Paris Agreement, the U.S. agreed to reduce GHG emissions by 26% to 28% from 2005 levels
by 2025. The Paris Agreement formally became effective on November 4, 2016; however, the U.S. completed its withdrawal
from the Paris Agreement on November 4, 2020. President Biden accepted the terms of the climate agreement on January 20,
2021, and the U.S. completed its reentry on February 19, 2021. New commitments to the Paris Agreement were announced in
April 2021, with the U.S. pledging to cut its overall GHG emissions by 50% to 52% from 2005 levels by 2030 and to reach
100% carbon pollution-free electricity by 2035. In December 2024, President Biden released new commitments to reach a 61%
to 66% reduction in emissions by 2035 from 2005 levels, which includes a 35% reduction in methane emissions. While in
January 2025, President Trump ordered to withdraw the U.S. from the Paris Agreement, the outgoing Biden administration
highlighted that the revised targets could be met without federal action. Increasingly, states are adopting legislation and
regulations to reduce GHG emissions, and local governments and consumers are seeking increasing amounts of clean and
renewable energy.


In April 2024, the EPA finalized new rules addressing GHG emissions for the power sector. The requirements are
scheduled to take effect January 1, 2030. New natural gas-fueled combustion turbines are expected to utilize lower-emitting
fuels and operate as highly efficient generation. Additionally, new baseload combustion turbines exceeding a 40% annual
capacity factor must meet an emission limit equivalent to operating with carbon capture and sequestration beginning January
1, 2032. The EPA also identified carbon capture and sequestration as the technology basis for the emissions standards for coal
units. Coal-fueled units that will operate after December 31, 2038, must meet emission limits equivalent to operating with
carbon capture and sequestration beginning January 1, 2032. Other units are anticipated to co-fire with natural gas and retire
prior to January 1, 2039, or convert to natural gas operations and meet emission limits corresponding to capacity factors. The
EPA deferred action on standards for existing natural gas-fueled combustion turbines. The rule has been challenged in the D.C.
Circuit Court of Appeals. The incoming Trump administration is expected to ask the court to abate litigation while it reevaluates
the rule. Because the rule is final and in effect, additional rulemaking would be required to rescind and potentially replace the
emissions standards.


In November 2021, the EPA proposed rules that would reduce methane emissions from both new and existing sources
in the oil and natural gas industry. The proposals would expand and strengthen emission reduction requirements for new,
modified and reconstructed oil and natural gas sources and would require states to reduce methane emissions from existing
sources nationwide. The EPA issued a supplemental proposal in November 2022 to further strengthen emission requirements.
The rule was finalized in December 2023. Affected sources may have up to five years from the rule’s effective date to comply
with requirements identified in state implementation plans. The rule has been challenged in the D.C. Circuit Court of Appeals.
The Trump administration is expected to ask the court to abate litigation while it reevaluates the rule. Because the rule is final
and in effect, additional rulemaking would be required to rescind and potentially replace the emissions standards.


BHE and its energy subsidiaries continue to focus on delivering reliable, affordable, safe and clean energy to its
customers and on actions to mitigate its GHG emissions. BHE’s primary source of GHG emissions is the generation of
electricity from its power plants that are fueled by coal or natural gas. In managing its electricity generation, BHE’s subsidiaries
work with their regulators to protect the energy and economic needs of customers by considering costs, reliability and sources
of electric generation. Over the years, BHE has invested heavily in owned renewable generation and storage, with cumulative
investments of $35.4 billion through December 31, 2024. Additionally, BHE has ceased coal operations at 18 generation units.
As a result, as of December 31, 2024, BHE has reduced its annual GHG emissions by more than 38% as compared to 2005
levels. To the extent it is beneficial for customers and consistent with regulatory provisions, BHE plans to continue investing
in renewable and other low-carbon generation and storage in the future and to cease coal operations at additional coal generation
units in a reliable and cost-effective manner, thereby achieving a 50% reduction in GHG emissions from 2005 levels in 2030.


K-10


---

_Non-Energy Businesses_


HomeServices of America, Inc. (“HomeServices”) is a residential real estate brokerage firm in the U.S. In addition to
providing traditional residential real estate brokerage services, HomeServices offers other integrated real estate services,
including mortgage originations and mortgage banking, title and closing services, insurance, home warranties, relocation
services and other home-related services. It operates under 48 brand names with approximately 37,700 real estate agents in
nearly 820 brokerage offices in 34 states and the District of Columbia.


HomeServices’ franchise network includes approximately 270 franchisees and over 1,400 brokerage offices with
approximately 44,700 third-party real estate agents under two brand names. In exchange for franchise fees, HomeServices
provides the right to use the Berkshire Hathaway HomeServices or Real Living brand names and other related service marks,
as well as providing orientation programs, training and consultation services, advertising programs and other services.


HomeServices’ principal sources of revenue are dependent on residential real estate transaction volumes, which are
normally higher in the second and third quarters of each year. This business is highly competitive and subject to general real
estate market conditions.


**Manufacturing Businesses**


Berkshire’s numerous and diverse manufacturing subsidiaries are grouped into three categories: (1) industrial products,
(2) building products and (3) consumer products. Berkshire’s industrial products businesses manufacture components for
aerospace and power generation applications, specialty chemicals, metal cutting tools and a variety of other products primarily
for industrial use. The building products group produces prefabricated and site-built residential homes, flooring products,
insulation, roofing and engineered products, building and engineered components, paint and coatings and bricks and masonry
products. The consumer products group manufactures and/or distributes recreational vehicles, batteries, various apparel,
footwear and other products. Information concerning the major activities of these three groups follows. Berkshire’s
manufacturing businesses employed approximately 180,000 people at the end of 2024.


_Industrial products_


Precision Castparts


Precision Castparts Corp. (“PCC”), based in Lake Oswego, Oregon, manufactures complex metal components and
products and provides high-quality investment castings, forgings, fasteners/fastener systems and aerostructures for critical
aerospace and power and energy applications. PCC also manufactures (1) investment castings and forgings for general
industrial, armament, medical and other applications; (2) nickel, titanium and cobalt alloys in all standard mill forms, including
specialty alloys used to produce investment castings and forgings for the aerospace, chemical processing, oil and gas, pollution
control and other industries; (3) fasteners and engineered products for automotive and general industrial markets; and (4) other
products and services for various markets and applications.


Investment casting technology involves a multi-step process that uses ceramic molds in the manufacture of metal
components with more complex shapes, closer tolerances and finer surface finishes than parts manufactured using other
methods. PCC uses this process to manufacture products for aircraft engines, industrial gas turbine and other aeroderivative
engines, airframes, medical implants, armament, unmanned aerial vehicles and other industrial applications. PCC also
manufactures high temperature carbon and ceramic composite components, including ceramic matrix composites, for use in
next-generation aerospace engines.


PCC uses forging processes to manufacture components for the aerospace and power generation markets. PCC
manufactures high-performance, nickel-based alloys, as well as titanium alloys and products. PCC’s nickel-based alloys are
used to produce forged components and investment castings for aerospace and non-aerospace applications in such markets as
oil and gas, chemical processing and pollution control. PCC’s titanium products are used to manufacture components for the
commercial and military aerospace, power generation, energy, medical and industrial end markets.


PCC is also a leading developer and manufacturer of highly engineered fasteners, fastener systems, aerostructures and
precision components, primarily for critical aerospace applications. These products are produced for the aerospace and power
and energy markets, as well as for construction, automotive, heavy truck, farm machinery, mining and construction equipment,
shipbuilding, machine tools, appliances and recreation markets.


PCC has several significant customers, including aerospace original equipment manufacturers (“OEMs”) (Boeing and
Airbus) and aircraft engine manufacturer suppliers (GE Aerospace, Rolls Royce and Pratt & Whitney). The majority of PCC’s
sales are from customer orders or demand schedules pursuant to long-term agreements. Contractual terms may provide for
termination by the customer, subject to payment for work performed. PCC typically does not experience significant order
cancellations, although periodically it receives requests for delays in delivery schedules.


K-11


---

Long-term industry forecasts continue to show growth and strong demand for air travel and aerospace products.
Continued growth in revenues and earnings will be predicated on PCC’s ability to successfully increase production levels to
match the expected growth in aerospace products, as well as improvements in the industry supply chains, which are currently
constraining commercial aircraft production at OEMs.


PCC is subject to substantial competition in all of its markets. Components and similar products may be produced by
competitors, who use either the same types of manufacturing processes as PCC or other processes. Although PCC believes its
manufacturing processes, technology and experience provide its customers with advantages, such as high quality, competitive
prices and physical properties that often meet more stringent demands, alternative forms of manufacturing can be used to
produce many of the same components and products. Nevertheless, PCC is a leading supplier in most of its principal markets.
Several factors, including long-standing customer relationships, technical expertise, state-of-the-art facilities and dedicated
employees, aid PCC in maintaining competitive advantages.


Several raw materials used in PCC products, including certain metals such as nickel, titanium, cobalt, tantalum, hafnium
and molybdenum, are found in only a few parts of the world. These metals are required for the alloys used in manufactured
products. The availability and costs of these metals may be influenced by private or governmental cartels, changes in world
politics, labor relations between the metal producers and their workforces and inflation.


PCC is subject to various federal, state and foreign environmental laws concerning, among other things, water discharges,
air emissions, waste management, toxic materials use reduction and environmental cleanup. Environmental laws and
regulations continue to evolve, particularly related to air and water quality and climate change, including reporting of GHG
emissions. As a result, it is also reasonably likely that PCC will be regularly required to make additional expenditures, including
capital expenditures, which could be significant, relating to environmental matters.


Lubrizol


The Lubrizol Corporation (“Lubrizol”), headquartered in Wickliffe, Ohio, is a specialty chemical and performance
materials company that manufactures products and supplies technologies for the global transportation, industrial and consumer
markets. Lubrizol operates two business segments: Lubrizol Additives, which produces engine lubricant additives, driveline
lubricant additives and industrial specialties products; and Lubrizol Advanced Materials, which includes engineered materials
(engineered polymers and performance coatings) and life sciences (beauty, personal care, health and home care solutions).


Lubrizol Additives’ products are used in a broad range of applications including engine oils, transmission fluids, gear
oils, specialty driveline lubricants, fuels, metalworking fluids and compressor lubricants for transportation and industrial
applications. Lubrizol Advanced Materials’ products are used in many different types of applications including beauty, personal
care, home care, over-the-counter pharmaceuticals, medical devices, performance coatings, sporting goods, plumbing and fire
sprinkler systems. Lubrizol is an industry leader in many of the markets in which it competes. Lubrizol Additives’ principal
competitors are Infineum International Ltd., Chevron Oronite Company and Afton Chemical Corporation. Lubrizol Advanced
Materials’ businesses compete in many markets with a variety of competitors in each product line.


Lubrizol uses its technological leadership position and applies its scientific capabilities, formulation know-how and
market expertise in product development to improve the demand, quality and value of its products. Lubrizol also leverages its
scientific and applications knowledge to meet and exceed customer performance and sustainability requirements. While
Lubrizol typically has patents that expire each year, it invests resources to protect its intellectual property and to develop or
acquire innovative products for the markets it serves. Lubrizol uses many specialty and commodity chemical raw materials in
its manufacturing processes. Raw materials are primarily feedstocks derived from petroleum and petrochemicals and, generally,
are obtainable from several sources. The materials that Lubrizol chooses to purchase from a single source typically are subject
to long-term supply contracts to ensure reliability.


Lubrizol operates its business on a global basis through more than 100 offices, laboratories, production facilities and
warehouses on six continents, the most significant of which are North America, Europe, Asia and South America. Lubrizol
markets its products worldwide through direct sales, sales agents and distributors. Lubrizol’s customers principally consist of
major global and regional oil companies and industrial and consumer products companies. Some of Lubrizol’s largest
customers also may be suppliers, although no single customer represented more than 10% of Lubrizol’s consolidated revenues
in 2024. In recent years, supply chain disruptions arising from various sources and severe weather affected the availability of
raw materials and fulfillment of customer orders and otherwise disrupted Lubrizol’s operations.


Lubrizol expends significant capital to ensure the safety of its employees and the communities where it operates, as well
as delivering on its commitments to operational excellence and cybersecurity. Lubrizol also makes significant capital
investments to ensure reliable supply and compliance with regulations governing its operations, while reducing its
environmental footprint.


K-12


---

Lubrizol is subject to foreign, federal, state and local laws to protect the environment, limit manufacturing waste and
emissions, ensure product and employee safety and regulate trade. While Lubrizol’s policies, practices and procedures are
designed to limit the associated risks and consequent financial liability, the operation of chemical manufacturing plants entails
inherent environmental, safety and other risks, and significant capital expenditures, costs or liabilities could be incurred in the
future.


IMC International Metalworking Companies


IMC International Metalworking Companies and its subsidiaries (“IMC”) is one of the three largest multinational
manufacturers of consumable precision carbide metal cutting tools for applications in a broad range of industrial end markets.
IMC’s primary brand names include ISCAR®, TaeguTec®, Ingersoll®, Tungaloy® and NTK®. Other IMC brand names
include, among others, Unitac®, UOP®, It.te.di®, Qutiltec®, Tool—Flo®, PCT®, IMCO®, BSW®, RKS®, Supermill® and
Neoboss. IMC’s primary manufacturing facilities are in Israel, the U.S., South Korea, Japan, Germany, Italy, Switzerland,
India, China and Mexico.


IMC has six primary product lines: milling tools, parting and grooving tools, turning/thread tools, hole making tools,
round tools and tooling. These main product lines are split between consumable cemented tungsten carbide inserts and steel
tool holders. Inserts comprise a major portion of IMC’s sales and earnings. Metal cutting inserts are used by industrial
manufacturers to cut metals and are consumed during their use in cutting applications. Steel tool holders are used to hold the
insert against the cutting piece. IMC manufactures hundreds of types of highly engineered inserts within each product line that
are tailored to maximize productivity and meet the technical requirements of customers. IMC’s staff of scientists and engineers
continuously develop and innovate products that address end user needs and requirements.


IMC’s global sales and marketing network operates in nearly every major manufacturing center around the world, staffed
with highly skilled engineers and technical personnel. IMC’s customer base is very diverse, with its primary customers being
large, multinational businesses in the automotive, aerospace, engineering and machinery industries. IMC operates a regional
central warehouse system with locations in Israel, the U.S., Belgium, South Korea, Japan and China. Additional small quantities
of products are maintained at local IMC sales offices to provide on-time customer support and inventory management.


IMC competes in the metal cutting tools segment of the global metalworking tools market. The segment includes
hundreds of participants who range from small, private manufacturers of specialized products for niche applications and
markets to larger, global multinational businesses (such as Sandvik and Kennametal, Inc.) with a wide assortment of products
and extensive distribution networks. Other manufacturing companies such as Kyocera, Mitsubishi, Sumitomo, Ceratizit and
Korloy also play a significant role in the cutting tool market.


Cemented tungsten carbide powder is the main raw material used in manufacturing cutting tools. Most of IMC’s insert
products are made from tungsten. While supplies are currently adequate, significant disruptions or constraints in production
processing facilities could cause reduced availability and increased prices.


IMC is committed to following and complying with all government and environmental rules, regulations and
requirements and applicable laws. IMC considers environmental preservation and pollution prevention as important factors in
all operations and activities. IMC production facilities are built with the highest standards and follow all applicable regulations.


Marmon


Marmon Holdings, Inc. (“Marmon”), headquartered in Chicago, Illinois, is a global industrial organization comprising
eleven diverse business groups and more than 120 autonomous manufacturing and service businesses. Marmon’s
manufacturing and service operations are conducted at approximately 650 manufacturing, distribution and service facilities
located primarily in the U.S., as well as 17 other countries worldwide. Marmon’s business groups are as follows.


The Foodservice Technologies group manufactures beverage dispensing and cooling equipment, hot and cold food
preparation and holding equipment and related products for restaurants, global brand owners and other foodservice providers.
Operations are based in the U.S. with manufacturing facilities in the U.S., Mexico, China, the Czech Republic and Italy.
Products are sold primarily throughout the U.S., Europe and Asia.


The Water Technologies group manufactures water treatment equipment for residential, commercial and industrial
applications worldwide. Operations are based primarily in the U.S., Canada, China, Singapore, India and Poland with business
centers located in Belgium, France, Germany, the U.K. and Italy.


The Transportation Products group serves the automotive and heavy-duty highway transportation industries with
precision-molded plastic components; aluminum tubing and extrusions; replacement parts and solutions for the automotive
aftermarket; dry van, flatbed, lowbed and specialty trailers; and truck and trailer components. Operations are conducted
primarily in the U.S., Mexico, Canada, Europe and China.


K-13


---

The Retail Solutions group provides retail environment design services; in-store digital merchandising, dispensing and
display fixtures; and shopping, material handling and security carts. Operations are conducted in the U.S., the U.K. and the
Czech Republic.


The Metal Services group provides specialty metal pipe, tubing and related value-added services to customers across a
broad range of industries including aerospace, construction and agricultural. Operations are conducted in the U.S., India,
Poland, Singapore, the U.K., the Netherlands, Canada and Mexico.


The Electrical group produces electrical wire for use in residential and commercial buildings, and specialty wire and
cable for use in energy, transit, aerospace, defense, communication and other industrial applications. Operations are conducted
in the U.S., Canada, India and England.


The Plumbing & Refrigeration group manufactures copper tubing and copper, brass, aluminum and stainless-steel fittings
and components for the plumbing, heating, ventilation, air conditioning and refrigeration (HVAC-R) market; custom heat
exchange, ducting, air handling units and energy recovery solutions for the HVAC-R market; HVAC systems and structures
for data centers, pharmaceutical and industrial sites; and aluminum and brass forgings for many commercial and industrial
applications. Key raw materials, including aluminum, copper and stainless steel are widely available. Operations are conducted
primarily in the U.S., Canada and the U.K.


The Industrial Products group supplies construction fasteners; masonry and stone anchoring systems used in commercial
construction; two component polymer products for anchoring, bonding and repair applications, gloves and other protective
wear; gear drives, gearboxes, fan and pump drives for various markets; wind machines for agricultural use; wheels, axles and
gears for rail, mining and other applications; lighting products for industrial and mining; equipment for the manufacture and
assembly of lead acid batteries; and the manufacturing and installation of after life service products. Operations are primarily
based in the U.S., the U.K., Canada and China.


The Rail & Leasing group manufactures, leases and maintains railcars; leases intermodal tank containers; manufactures
mobile railcar movers; provides in-plant rail switching and loading services; performs track construction and maintenance; and
manufactures steel tank heads and cylinders.


Union Tank Car Company (“UTLX”) is the largest component of the Rail & Leasing group and is a leading designer,
builder and full-service lessor of railroad tank cars and other specialized railcars. Together, with its Canadian affiliate Procor,
UTLX owns a fleet of approximately 119,000 railcars for lease to customers in chemical, petrochemical, energy and
agricultural/food industries. UTLX manufactures tank cars in the U.S. and performs railcar maintenance services at more than
100 locations across North America.


UTLX has a diversified customer base, both geographically and across industries. UTLX, while subject to cyclicality
and significant competition in most of its markets, competes by offering a broad range of high-quality products and services
targeted at its niche markets. Railcars are typically leased for multiple-year terms and most of the leases are renewed upon
expiration. Due to selective ongoing capital investment, utilization rates (the number of railcars on lease as a percentage of the
total fleet) are generally high.


Intermodal tank containers are leased through EXSIF Worldwide (“EXSIF”). EXSIF is a leading international lessor of
intermodal tank containers with a fleet of approximately 75,000 units, primarily serving chemical producers and logistics
operators.


The Crane Services group is a provider of mobile cranes and operators in North America and Australia with a combined
fleet of approximately 1,100 cranes, primarily serving the energy, mining, petrochemical and infrastructure markets. Cranes
are leased on a fully operated and maintained service basis or on an equipment-only basis. The Crane Services group is subject
to customer seasonality, with concentration of volume typically in the warmer months.


The Medical group develops, manufactures and sells a wide range of innovative medical devices in the extremities
fixation, craniomaxillofacial surgery, neurosurgery, aesthetics and powered instruments markets. The group’s leading-edge
medical technology and products are used globally to help improve patient care and outcomes. Operations are based in the
U.S., Europe and China and business is conducted primarily in North and South America, Europe, Asia and Australia.


Certain Marmon businesses, including the Rail & Leasing and Medical groups, are subject to government regulation and
oversight. Marmon has numerous known environmental matters which are subject to on-going monitoring and/or remediation
efforts. Marmon follows all federal, state and local environmental regulations.


Other industrial products


CTB International Corp. (“CTB”), headquartered in Milford, Indiana, is a leading global designer, manufacturer and
marketer of a wide range of agricultural systems and solutions for preserving grain, producing poultry, pigs and eggs, and for
processing poultry, fish, vegetables and other foods. CTB operates from facilities located around the globe and supports
customers through a worldwide network of independent distributors and dealers.


K-14


---

CTB competes with a variety of manufacturers and suppliers, including many that offer only a limited number of the
products offered by CTB, as well as a few that offer products across several of CTB’s product lines. Competition is based on
the price, value, reputation, quality and design of the products offered and the customer service provided by distributors, dealers
and manufacturers of the products. CTB’s leading brand names, distribution network, diversified product line, product support
and high-quality products enable it to compete effectively. CTB manufactures its products primarily from galvanized steel,
steel wire, stainless steel and polymer materials. The availability of these materials in recent years has been adequate.


LiquidPower Specialty Products Inc. (“LSPI”), headquartered in Houston, Texas, is a global leader in the science of drag
reduction application (“DRA”) technology by maximizing the flow potential of pipelines, increasing operational flexibility and
throughput capacity, and efficiencies for customers. LSPI develops innovative flow improver solutions with customers in 24
countries on five continents, treating over 50 million barrels of hydrocarbon liquids per day. LSPI’s DRA offering is part of a
comprehensive, full-service solution that encompasses industry-leading technology, quality manufacturing, technical support
and consulting, a reliable supply chain, injection equipment and field service. LSPI is subject to foreign, federal, state and local
laws to protect the environment and limit manufacturing waste and emissions.


The industrial products group also includes W&W|AFCO Steel (“W&W|AFCO”), a leading structural steel fabricator
and steel construction business in North America. W&W|AFCO operates 19 steel fabrication plants located across the U.S.
W&W|AFCO’s projects include semiconductor plants, stadiums, high-rise buildings, bridges, mining facilities, aircraft
hangars, military projects, automotive assembly plants, as well as international projects. W&W|AFCO’s multiyear backlog of
projects at the end of 2024 was substantial. W&W|AFCO was acquired in connection with the Alleghany acquisition in October
2022, and its headquarters are in Oklahoma City, Oklahoma.


_Building Products_


Clayton


Clayton Homes, Inc. (“Clayton”), headquartered near Knoxville, Tennessee, is a vertically integrated housing company
offering off-site (factory) and site-built homes, including modular, manufactured, CrossMod™, town homes and tiny homes.
In 2024, Clayton completed approximately 51,000 off-site built homes, over 95% of which were built to the Department of
Energy’s Zero Energy Ready Home program requirements, as well as approximately 10,000 site-built homes. Clayton also
offers home financing and other financial services and competes on price, service, location and delivery capabilities.


All Clayton Built® off-site built homes are designed, engineered and assembled in the U.S. As of December 2024, offsite backlog was approximately $700 million. Clayton sells off-site built homes through independent and company-owned
home centers, realtors and subdivision channels. Clayton considers its ability to offer financing to retail purchasers a factor
affecting the marketplace acceptance of its off-site built homes. Clayton’s financing programs utilize proprietary loan
underwriting guidelines to evaluate loan applicants.


Clayton’s site-built division, Clayton Properties Group (“CPG”), includes nine builders across 18 states with nearly 300
subdivisions, supplementing the portfolio of housing products offered to customers. CPG owned and controlled approximately
66,000 homesites, with a home order backlog of approximately $1.46 billion as of December 2024.


Access to key housing inputs, including lumber, steel and resin products, was adequate in 2023 and 2024. Historically,
the availability and pricing of these and other inputs has been volatile resulting in input shortages.


Clayton’s off-site home building business is impacted by changes in U.S. home mortgage interest rates. While interest
rates slightly declined in the latter part of 2024, interest rates significantly increased during 2022 and 2023, slowing demand
for new home construction, which was partially mitigated by low supplies of pre-existing homes for sale.


Clayton’s home building business regularly makes capital and non-capital expenditures with respect to compliance with
federal, state and local environmental regulations, primarily related to erosion control, permitting and stormwater protection
for site-built home subdivisions. The financing business originates and services loans which are federally regulated by the
Consumer Financial Protection Bureau, various state regulatory agencies and reviewed by the U.S. Department of Housing and
Urban Development, the Government National Mortgage Association and government-sponsored enterprises.


K-15


---

Shaw


Shaw Industries Group, Inc. (“Shaw”), headquartered in Dalton, Georgia, is a leading manufacturer and distributor of
carpet, carpet tile and hard surface flooring products. Shaw designs and manufactures over 4,100 styles of tufted carpet, wood
and resilient flooring for residential and commercial use under numerous brand and trade names and under certain private
labels. Soft and hard surface products are available in a broad range of patterns, colors and textures. Shaw’s carpet
manufacturing operations are fully integrated from the processing of raw materials used to make fiber through the carpet
finishing. Shaw’s flooring business is primarily in the U.S. Shaw also manufactures carpet tile in China and the U.K. and
distributes carpet tile throughout Europe and Southeast Asia. It manufactures or distributes a variety of hardwood, wood plastic
composite, stone plastic composite, vinyl and laminate floor products (collectively, “hard surfaces”). Shaw’s Integrated
Solutions business also provides project management and installation services.


Shaw also operates Shaw Sports Turf, Shawgrass and Southwest Greens International, LLC, which provide synthetic
sports turf, golf greens and landscape turf products. Shaw’s Watershed subsidiary sells innovative and patented environmental
solutions for utility, waste management, erosion control and mining industries and provides patented renewable energy
solutions.


Shaw products are sold wholesale to over 42,000 retailers, distributors and commercial users throughout the world.
Shaw’s wholesale products are marketed domestically by over 1,800 salaried and commissioned sales personnel directly to
retailers and distributors and to large national accounts. Shaw’s distribution facilities, including seven carpet, nine hard
surfaces, one sample full-service and three sample satellite facilities and 30 redistribution centers, enable it to provide prompt
and efficient delivery of its products to both its retail customers and wholesale distributors.


Substantially all carpet manufactured by Shaw is tufted carpet made from nylon, polypropylene and polyester, as well as
recycled materials. During 2024, Shaw processed approximately 95% of its requirements for carpet yarn in its own yarn
processing facilities. The availability of raw materials is adequate, but costs are impacted by petro-chemical and natural gas
price changes. A significant portion of Shaw’s soft-flooring raw materials derive from recycled sources. Raw material cost
changes are periodically factored into selling prices to customers.


The soft floor covering industry is highly competitive with only a handful of major competitors domestically. There are
numerous manufacturers, domestically and internationally, that are engaged in the hard surfaces flooring sector. According to
industry estimates published in 2024 for 2023, carpet accounts for approximately 44% of the total U.S. consumption of all
flooring types. The principal competitive measures within the floor covering industry are quality, style, price and service.


Johns Manville


Johns Manville Corporation (“JM”), headquartered in Denver, Colorado, is a leading manufacturer and marketer of
premium-quality products for building insulation, mechanical and industrial insulation, commercial roofing and roof insulation,
as well as reinforcement fiberglass and technical nonwovens. JM serves markets that include residential and nonresidential
buildings, automotive and transportation, air handling, appliance, HVAC, pipe and equipment, air and liquid filtration,
waterproofing, flooring, interiors, aerospace and wind energy. Fiberglass is the basic material in many of JM’s products,
although JM also manufactures a significant portion of its products with other materials to satisfy the broader needs of its
customers.


JM regards its patents and licenses as valuable; however, it does not consider any of its businesses to be materially
dependent on any single patent or license. JM operates over 40 manufacturing facilities in North America and Europe and
conducts research and development at its technical center in Littleton, Colorado and at other facilities in the U.S. and Europe.


Fiberglass is made from earthen raw materials and recycled glass. JM’s products also contain materials other than
fiberglass, including chemical agents to bind many of its glass fibers and various chemical-based and petrochemical-based
materials used in roofing and other specialized products. JM uses recycled material when available and suitable to satisfy the
broader needs of its customers. The raw materials used in these various products are generally readily available in sufficient
quantities from various sources to maintain and expand current production levels although the availability of recycled glass can
fluctuate.


JM’s operations are subject to a variety of federal, state and local environmental laws and regulations, which regulate or
impose liability for the discharge of materials into the air, land and water and govern the use and disposal of hazardous
substances and use of chemical substances. The most relevant of the federal laws are the Federal Clean Air Act, the Clean
Water Act, the Toxic Substances Control Act, the Resource Conservation and Recovery Act and the Comprehensive
Environmental Response, Compensation and Liability Act, which are administered by the EPA. Canadian and European
regulatory authorities have also adopted their own environmental laws and regulations. JM continually monitors new and
pending regulations and assesses their potential impact on the business. JM’s capital projects regularly address environmental
compliance, although capital expenditures for environmental compliance are generally in conjunction with other capital project
expenditures.


K-16


---

JM sells its products through a wide variety of channels including contractors, distributors, retailers, manufacturers and
fabricators. JM operates in highly competitive markets, with competitors comprising primarily of large global and national
manufacturers and smaller regional manufacturers. JM holds leadership positions in the key markets that it serves. JM’s
products compete primarily on value, differentiation and customization, breadth of product line, quality and service. Sales of
JM’s products are moderately seasonal due to increases in construction activity that typically occur in the second and third
quarters of the calendar year.


MiTek


MiTek Industries, Inc. (“MiTek”), based in Chesterfield, Missouri, operates in two separate building markets: residential
and commercial. MiTek operates worldwide with sales in over 60 countries and with manufacturing facilities and/or
sales/engineering offices located in 16 countries.


In the residential building market, MiTek is a leading supplier of engineered connector products, construction hardware,
engineering software and services, and computer-driven manufacturing machinery to the truss component market of the
building components industry. MiTek’s primary customers are component manufacturers who manufacture prefabricated roof
and floor trusses and wall panels for the residential building market. MiTek also sells construction hardware to commercial
distributors and retail stores for do-it-yourself customers.


A significant raw material used by MiTek is hot dipped galvanized sheet steel. While supplies are adequate, variations
in supply can produce significant variations in cost and availability.


Benjamin Moore


Benjamin Moore & Co. (“Benjamin Moore”), headquartered in Montvale, New Jersey, is one of North America’s leading
manufacturers of premium quality residential, commercial and industrial maintenance coatings. Benjamin Moore is committed
to innovation and sustainable manufacturing practices. The Benjamin Moore premium portfolio includes Aura®, Regal®
Select, Ben®, Advance®, Element Guard®, Woodluxe®, Ultra Spec® and others. The Benjamin Moore diversified brands
include specialty and architectural paints from Coronado® and Insl-x®.


Benjamin Moore coatings are available through more than 8,000 independently owned and operated paint, decorating
and hardware retailers, including approximately 4,000 Ace Hardware (“Ace”) stores, throughout the U.S. and Canada as well
as 66 countries globally. Benjamin Moore is the preferred paint supplier for Ace stores through an agreement which permits
Ace stores to carry specified Benjamin Moore products. Additionally, Benjamin Moore manufactures Clark+Kensington® and
Royal® brands, as well as the balance of Ace’s private label paint brands.


Benjamin Moore also allows customers to directly order coatings or color samples online or via its customer information
center for national accounts. Orders may be delivered to the customer or a retailer near the customer.


Benjamin Moore competes with numerous manufacturers, distributors and paint, coatings and related products retailers.
Product quality, product innovation, breadth of product line, technical expertise, service and price determine the competitive
advantage. Competitors include other premium paint and decorating stores, mass merchandisers, home centers, independent
hardware stores, hardware chains and manufacturer-operated direct outlets, such as Sherwin-Williams Company, The
Pittsburgh Paints Company, The Home Depot, Inc., Lowe’s Companies, Inc and Farrow & Ball.


The most significant raw materials in Benjamin Moore products are titanium dioxide, monomers, polymers, packaging
materials and pigments. Historically, the purchased raw materials have been generally available, with pricing and availability
subject to fluctuation.


Benjamin Moore complies with applicable regulations relating to protection of the environment and workers’ safety and
Benjamin Moore products are compliant with environmental standards. Benjamin Moore has certain known past environmental
matters, which are subject to on-going monitoring and/or remediation efforts.


Acme


Acme Brick Company (“Acme”), headquartered in Fort Worth, Texas, manufactures and distributes clay bricks (Acme
Brick®) and concrete block (Featherlite). In addition, Acme distributes numerous other building products of other
manufacturers, including cladding, floor and wall tile, wood flooring and other masonry products. Products are sold primarily
in the South Central and Southeastern U.S. through company-operated sales offices. Acme distributes products primarily to
homebuilders and masonry and general contractors.


Acme operates 12 clay brick manufacturing sites located in four states and three concrete block facilities in Texas. The
demand for Acme’s products is seasonal, with higher sales in the warmer weather months, and is subject to the level of
construction activity, which is cyclical. Acme also owns and leases properties and mineral rights that supply raw materials used
in many of its manufactured products. Acme’s raw materials supply is currently adequate.


K-17


---

The brick industry is subject to the EPA Maximum Achievable Control Technology Standards (“MACT”). As required
under the 1990 Clean Air Act, the EPA developed a list of source categories that require the development of National Emission
Standards for Hazardous Air Pollutants, which are also referred to as MACT Standards (“Rule”). Key elements of the MACT
Rule include emission limits established for certain hazardous air pollutants and acidic gases. Acme’s brick plants comply with
the current Rule.


_Consumer Products_


Recreational vehicles


Forest River, Inc. (“Forest River”), headquartered in Elkhart, Indiana, is a manufacturer of recreational vehicles (“RV”),
utility cargo trailers, buses and pontoon boats with products sold in the U.S. and Canada through an independent dealer network.
Forest River has numerous manufacturing facilities located in seven states and is a leading manufacturer of RVs with numerous
brand names, including Forest River, Coachmen RV and Prime Time. Utility cargo trailers are sold under a variety of brand
names. Buses are sold under several brand names, including Starcraft Bus. Pontoon boats are sold under the Berkshire, South
Bay and Trifecta brand names.


The RV industry is highly competitive. Competition is based primarily on price, design, quality and service. The industry
has consolidated over the past several years and is concentrated in a few companies, the largest of which had a market share of
approximately 40% based on industry data as of September 2024. Forest River held a market share of approximately 35% at
that time. Forest River is subject to regulations of the National Traffic and Motor Vehicle Safety Act, the safety standards for
recreational vehicles established by the U.S. Department of Transportation and similar laws and regulations issued by the
Canadian government. Forest River is a member of the Recreational Vehicle Industry Association, a voluntary association of
RV manufacturers which promotes safety standards for RVs. Forest River believes its products comply in all material respects
with the standards that govern its products.


Apparel and footwear


Fruit of the Loom, Inc. (“FOL”), headquartered in Bowling Green, Kentucky, is primarily a manufacturer and distributor
of basic apparel, underwear, outerwear, athletic apparel and sports equipment. Products under the Fruit of the Loom® and
JERZEES® labels are primarily sold in the mass merchandise, mid-tier chains and wholesale markets. In the Vanity Fair Brands
product line, Vassarette®, Curvation® and Radiant by Vanity Fair® are sold in the mass merchandise market, while other
Vanity Fair® products are sold to mid-tier chains and department stores. FOL also markets and sells athletic apparel and sports
equipment to team dealers and to sporting goods retailers under the Russell Athletic® and Spalding® brands.


FOL generally performs its own knitting, cloth finishing, cutting, sewing and packaging for apparel. For the North
American market, which is FOL’s predominant sales region, cloth manufacturing is primarily performed in Honduras. Laborintensive cutting, sewing and packaging operations are in Central America and Asia. For the European market, products are
either sourced from third-party contractors in Europe or Asia or sewn in Morocco from textiles internally produced in Morocco.
Athletic equipment, sporting goods and other athletic apparel lines are generally sourced from third-party contractors located
primarily in Asia.


U.S.-grown cotton fiber and U.S.-manufactured polyester fiber are the main raw materials used in manufacturing FOL’s
products. Historically, fibers were purchased from a limited number of third parties, including one key supplier that provided
much of FOL’s yarn spinning/raw material conversion services. Supply chain disruptions in 2021 and 2022 caused FOL to
utilize alternative sources for these raw materials/services. FOL has since engaged an additional supplier for a portion of FOL’s
yarn spinning/raw material conversion services. FOL’s markets are highly competitive, consisting of many domestic and
foreign manufacturers and distributors. Competition is generally based upon product features, quality, customer service and
price.


Garan Incorporated (“Garan”), headquartered in New York, New York, designs, manufactures, imports and sells apparel
primarily for children, including boys, girls, toddlers and infants. Products are sold under its own trademarks Garanimals® and
365 Kids from Garanimals® and easy-peasy®, as well as customer private label brands. Garan conducts its business through
operating subsidiaries located in the U.S., Central America and Asia. Garan’s products are sold through its distribution centers
in the U.S. Fechheimer Brothers Company (“Fechheimers”) manufactures and distributes uniforms, principally for the public
service and safety markets, including police, fire, postal and military markets. Fechheimers is based in Cincinnati, Ohio.


K-18


---

The BH Shoe Holdings Group, headquartered in Greenwich, Connecticut, manufactures and distributes work, rugged
outdoor and casual shoes and western-style footwear under several brand names, including Justin®, BØRN®, Carolina®,
Söfft® and Double-H Boots®, as well as under several other brand names. Brooks Sports, Inc., headquartered in Seattle,
Washington, markets and sells performance running footwear and apparel to specialty and national retailers and directly to
consumers under the Brooks® brand. A significant volume of the shoes sold by Berkshire’s shoe businesses are manufactured
or purchased from sources located outside the U.S. Products are sold worldwide through a variety of channels including
department stores, footwear chains, specialty stores, catalogs and the Internet, as well as through company-owned retail stores.


Other consumer products


The Duracell Company (“Duracell”), headquartered in Chicago, Illinois, is a leading manufacturer of high-performance
alkaline and lithium coin batteries. Duracell manufactures batteries in the U.S., Europe and China and provides a network of
worldwide sales and distribution centers. Duracell sells its products to a diverse group of retailers and distributors across the
globe. There are several competitors in the battery manufacturing market. Duracell estimates that it had a 32% market share of
the global alkaline battery market in 2024. The availability of raw materials, which are primarily steel, zinc, manganese and
nickel-based chemistries, is currently sufficient.


The consumer products group also includes Jazwares, LLC, (“Jazwares”), acquired in October 2022 in connection with
Alleghany. Jazwares, headquartered in Plantation, Florida, is a leading global toy and consumer products manufacturer with a
robust portfolio of owned and licensed brands, such as Squishmallows™, BLDR™, Pokémon™, Hello Kitty™, Star Wars™,
Disney™, BumBumz™and Adopt Me™. In addition to toys, offerings also include virtual games, costumes and products for
pets. Jazwares sells its products in more than 100 countries.


Richline Group, Inc., headquartered in New York, New York, operates four strategic business units: Richline Jewelry,
LeachGarner, Rio Grande and Inverness. Each business unit is a manufacturer and/or distributor of precious metal, non-precious
metal, diamond and gem products to specific target markets, including large jewelry chains, department stores, shopping
networks, mass merchandisers, e-commerce retailers and artisans as well as certain global manufacturers and wholesalers in
the medical, electronics and aerospace industries. Albecca Inc. (“Albecca”), headquartered in Suwanee, Georgia, operates in
the U.S., Canada and 11 other countries, with products primarily under the Larson-Juhl® name. Albecca designs, manufactures
and distributes a complete line of high quality, branded custom framing products, including wood and metal moulding,
matboard, foamboard, glass and framing supplies. Complementary to its framing products, Albecca offers art printing and
fulfillment services.


**Pilot Travel Centers**


In 2017, Berkshire acquired a 38.6% noncontrolling interest in Pilot Travel Centers, LLC (“Pilot”). On January 31, 2023,
Berkshire acquired an additional 41.4% interest and attained control of Pilot and began consolidating Pilot for financial
reporting purposes beginning February 1, 2023. On January 16, 2024, Berkshire acquired the remaining 20% noncontrolling
interest and Pilot became an indirect wholly-owned subsidiary.


Pilot operates 677 travel center and 77 fuel-only retail locations across the U.S. and in five Canadian provinces, primarily
under the names Pilot or Flying J, through 658 company-owned locations, as well as through 96 locations held in unconsolidated
joint ventures. Pilot and subsidiaries also conduct wholesale fuel and fuel marketing businesses in the U.S. and sell diesel fuel
at over 140 locations in the U.S. and Canada through various third-party arrangements in which Pilot procures and sells diesel
fuel to consumers at locations owned by the third parties. Pilot also operates a water disposal business in the oil fields sector.


Pilot sold approximately 11.4 billion gallons of fuel (primarily diesel, gasoline and diesel exhaust fluid) in 2024 through
its various company-owned retail locations, third-party arrangements and wholesale businesses. The Pilot operated joint
ventures also sold approximately 900 million gallons of fuel in 2024. Additionally, Pilot provides charging stations for electric
vehicles at approximately 130 travel centers in connection with an agreement with General Motors to develop a nationwide
electric vehicle fast charger network of 2,000 charging stations in 500 U.S. locations by 2026. Pilot and subsidiaries had
approximately 29,200 employees at the end of 2024.


Pilot’s travel centers are generally located close to an interstate highway and offer petroleum products, merchandise,
food and other services and amenities to consumers, travelers and professional truck drivers. The travel center industry is
concentrated among a few large operators, including Love’s Travel Stops and TravelCenters of America, although there are
numerous independent operators that operate one to ten travel centers. Pilot’s top 10 customers for diesel sales accounted for
approximately 10% of total diesel gallons sold in 2024, while Pilot’s top 10 fuel suppliers accounted for approximately 54%
of gallons purchased in 2024.


K-19


---

Pilot is subject to federal, state, and local laws and regulations relating to the environment. These laws generally provide
for control of pollutants released into the environment and require responsible parties to undertake remediation of hazardous
waste disposal sites. Penalties may be imposed for non-compliance. The retirement of certain long-lived assets (such as
petroleum tanks, dispensers and disposal wells) may result in asset retirement obligations.


**McLane**


McLane Company, Inc. (“McLane”) provides wholesale distribution services in all 50 states to customers that include
convenience stores, discount retailers, wholesale clubs, drug stores, military bases, quick service restaurants and casual dining
restaurants. McLane’s major customers during 2024 included Walmart (approximately 17.3% of revenues); 7-Eleven
(approximately 13.2% of revenues); and Yum! Brands (approximately 12.5% of revenues). McLane’s business model is based
on a high volume of sales, rapid inventory turnover and stringent expense controls. Operations are divided into three business
units: retail distribution, restaurant distribution and beverage distribution.


McLane’s retail distribution unit, based in Temple, Texas, maintains a dominant market share within the convenience
store industry and serves most of the national convenience store chains and major oil company retail outlets. Retail operations
provide products to approximately 46,400 retail locations nationwide. McLane’s retail distribution unit operates 26 distribution
facilities in 20 states.


McLane’s restaurant distribution unit, based in Carrollton, Texas, focuses on serving the quick service and casual dining
restaurant industry with high quality, timely-delivered products. Operations are conducted through 45 facilities in 22 states.
The restaurant distribution unit services approximately 32,000 restaurants nationwide.


Through its subsidiaries, McLane also operates wholesale distributors of distilled spirits, wine and beer. The beverage
unit operates as Empire Distributors, with operations conducted through 14 distribution centers in Georgia, North Carolina,
Tennessee and Colorado. Empire Distributors services approximately 30,200 retail locations in the Southeastern U.S. and
Colorado. McLane had approximately 24,800 employees at the end of 2024.


**Service and Retailing Businesses**


_Service Businesses_


Berkshire’s service businesses provide professional aviation training programs, shared aircraft ownership programs and
distribution of electronic components. Additionally, service businesses include franchising and servicing of quick service
restaurants, media businesses (television and information distribution), as well as logistics services businesses. Berkshire’s
service businesses employed approximately 30,400 people at the end of 2024. Information regarding each of these operations
follows.


FlightSafety


FlightSafety International Inc. (“FlightSafety”) is an industry leading provider of professional aviation training services
and flight simulation products. FlightSafety and FlightSafety Textron Aviation Training, a joint venture with Textron, provide
high technology training to pilots, aircraft maintenance technicians, flight attendants and dispatchers who operate and support
a wide variety of business, commercial and military aircraft. The training is provided using a large fleet of advanced full flight
simulators at learning centers and training locations in the U.S., Australia, Brazil, Canada, France, Japan, Norway, Singapore,
South Africa and the U.K. Compliance with applicable environmental regulations is an inherent requirement to operate the
facilities. The vast majority of the instructors, training programs and flight simulators are qualified by the United States Federal
Aviation Administration (“FAA”) and other aviation regulatory agencies around the world.


FlightSafety is also a leader in the design and manufacturing of full flight simulators, visual systems, displays and other
advanced technology training devices. This equipment is used to support FlightSafety training programs and is offered for sale
to airlines and governments around the world. Manufacturing facilities are located in Oklahoma and Illinois. FlightSafety
strives to maintain and manufacture simulators and develop courseware using state-of-the-art technology, incorporating critical
safety standards and procedures. FlightSafety invests in research and development, further advancing the delivery of new
equipment and training programs.


NetJets


NetJets Inc. (“NetJets”) is the leader in private aviation services and operates a large, diverse private aircraft fleet and
offers a full range of personalized private aviation solutions to meet and exceed the high standards of its customers. NetJets’
global headquarters are located in Columbus, Ohio and its European operations are based in Lisbon, Portugal. The shared
ownership concept is designed to meet the travel needs of customers who require the scale, flexibility and access of a large
fleet of aircraft as opposed to reliance on whole aircraft ownership. In addition, shared ownership programs are available for
corporate flight departments seeking to outsource their general aviation needs or add capacity for peak periods and for others
that previously chartered aircraft.


K-20


---

NetJets’ programs are focused on safety and service and are designed to offer customers guaranteed availability of
aircraft, predictable operating costs and increased liquidity. NetJets’ shared aircraft ownership programs permit customers to
acquire a specific percentage of a certain aircraft type and allow customers to utilize the aircraft for a specified number of flight
hours annually. In addition, NetJets offers prepaid flight cards and other aviation solutions and services for aircraft
management, customized aircraft sales and acquisition, ground support and flight operation services under several programs,
including NetJets Shares™, NetJets Leases™and the NetJets Card Program™.


NetJets is subject to the rules and regulations of the FAA, the Portuguese Civil Aviation Authority and the European
Union Aviation Safety Agency. Regulations address aircraft registration, maintenance requirements, pilot qualifications and
airport operations, including flight planning and scheduling, as well as security issues and other matters. NetJets maintains
comprehensive training and development programs in compliance with regulatory requirements for pilots, flight attendants,
maintenance mechanics, and other flight operations specialists, many of whom are represented by unions.


TTI


TTI, Inc. (“TTI”), headquartered in Fort Worth, Texas, is a global specialty distributor of passive, interconnect,
electromechanical, discrete, and semiconductor components used by customers in the manufacturing and assembling of
electronic products. TTI’s customer base includes OEMs, electronic manufacturing services, original design manufacturers and
military and commercial customers, as well as design and system engineers. TTI’s distribution agreements with the industry’s
leading suppliers allow it to uniquely leverage its product cost and to expand its business by providing new lines and products
to its customers. TTI operates sales offices and distribution centers from more than 180 locations throughout North America,
South America, Europe and Asia.


TTI services a variety of industries including telecommunications, medical devices, computers and office equipment,
military/aerospace, automotive and industrial electronics. TTI’s core businesses serve customers in the design through
production stages in the electronic component supply chain, which supports high-volume customers. Its Mouser subsidiary
supports a broader base of customers with lower volume purchases through internet-based marketing.


Other


XTRA Corporation (“XTRA”), headquartered in St. Louis, Missouri, is a leading transportation equipment lessor
operating under the XTRA Lease® brand name. XTRA manages a diverse fleet of approximately 93,000 units located at 47
facilities throughout the U.S. The fleet includes over-the-road and storage trailers, chassis, temperature-controlled vans and
flatbed trailers. XTRA is one of the largest lessors (in terms of units available) of over-the-road trailers in North America.
Transportation equipment customers lease equipment to cover cyclical, seasonal and geographic needs and as a substitute for
purchasing equipment. By maintaining a large fleet, XTRA provides customers with a broad selection of equipment and quick
response times.


International Dairy Queen Inc. develops and services a worldwide system of approximately 7,700 franchised restaurants
operating primarily under the names DQ Grill and Chill®, Dairy Queen®, DQ® and Orange Julius® that offer various dairy
desserts, beverages, prepared foods and blended fruit drinks. Business Wire Inc. (“Business Wire”) transmits full-text news
releases, regulatory filings, photos and other multimedia content to journalists, financial professionals, investor services,
regulatory authorities and the general public. Releases are distributed globally via Business Wire’s patented NX network.
CORT Business Services Corporation (“CORT”) is a leading national provider of rental furniture and related services in the
“rent-to-rent” segment of the furniture rental industry. CORT’s primary revenue streams include furniture rental to individuals,
businesses, government agencies, the trade show and events industry and retail sales of new and used furniture. WPLG, Inc. is
an ABC affiliate television broadcast station serving the Miami/Ft. Lauderdale market. WPLG, Inc. operates WPLG-TV,
local10.com, MeTV South Florida and Heroes & Icons Network in South Florida. Charter Brokerage Holdings Corp. is a
leading non-asset based third party logistics provider to various industries.


The services group also includes IPS-Integrated Project Services, LLC (“IPS”), which was acquired in connection with
the Alleghany acquisition in 2022. IPS operates globally and provides a range of professional design, validation, construction,
project controls and consulting services for manufacturing and support facilities within the pharmaceutical, biotech and life
sciences, science and technology, data center, industrial, commercial and retail industries. IPS’s services are required to be
compliant with each jurisdiction’s regulations applicable to the engineering and architectural service providers.


_Retailing Businesses_


Berkshire’s retailing businesses include automotive, home furnishings and several other operations that sell various
consumer products and services. Berkshire’s retailing businesses employed approximately 26,000 people at the end of 2024.
Information regarding each of these operations follows.


K-21


---

Berkshire Hathaway Automotive


Berkshire Hathaway Automotive, Inc. (“BHA”) is one of the largest automotive retailers in the U.S., operating 108 new
vehicle franchises through 83 dealerships located primarily in major metropolitan markets in the U.S. The dealerships sell new
and used vehicles, vehicle maintenance and repair services, extended service contracts, vehicle protection products and other
aftermarket products. BHA also arranges financing for its customers through third-party lenders. BHA operates 31 collision
centers directly connected to the dealerships’ operations and owns and operates two auto auctions and an automotive fluid
maintenance products distributor.


Dealership operations are highly concentrated in the Arizona and Texas markets, with approximately 75% of dealershiprelated revenues derived from sales in these markets. BHA maintains franchise agreements with 27 different vehicle
manufacturers, although it derives a significant portion of its revenue from the Toyota/Lexus, General Motors, Ford/Lincoln,
Nissan/Infiniti and Honda/Acura brands. These manufacturers normally represent approximately 90% of the revenue generated
by BHA’s dealerships.


The retail automotive industry is highly competitive. BHA faces competition from other large public and private
dealership groups, as well as individual franchised dealerships and competition via the Internet. Given the retail price
transparency available via the Internet, and the fact that franchised dealers acquire vehicles from the manufacturers on the same
terms irrespective of volume, the location and quality of the dealership facility, customer service and transaction speed are key
differentiators in attracting customers.


BHA’s overall relationships with the automobile manufacturers are governed by framework agreements. The framework
agreements contain provisions relating to the management, operation, acquisition and ownership structure of BHA’s
dealerships. Failure to meet the terms of these agreements could adversely impact BHA’s ability to acquire additional
dealerships representing those manufacturers. Additionally, these agreements contain limitations on the number of dealerships
from a specific manufacturer that may be owned by BHA.


Individual dealerships operate under franchise agreements with the manufacturer, which grants the dealership entity a
non-exclusive right to sell the manufacturer’s brand of vehicles and offer related parts and service within a specified market
area, as well as the right to use the manufacturer’s trademarks. The agreements contain various requirements and restrictions
related to the management and operation of the franchised dealership and provide for termination of the agreement by the
manufacturer or non-renewal for a variety of causes. States generally have automotive dealership franchise laws that provide
substantial protection to the franchisee, and it is difficult for a manufacturer to terminate or not renew a franchise agreement
outside of bankruptcy or with “good cause” under the applicable state franchise law.


BHA also develops, underwrites and administers various vehicle protection plans sold to consumers through BHA’s
dealerships and third-party dealerships. BHA also develops proprietary training programs and materials and provides ongoing
monitoring and training of the dealership’s finance and insurance personnel.


Home furnishings retailing


The home furnishings businesses consist of Nebraska Furniture Mart Inc. (“NFM”), R.C. Willey Home Furnishings
(“R.C. Willey”), Star Furniture Company (“Star”) and Jordan’s Furniture, Inc. (“Jordan’s”). These businesses offer a wide
selection of furniture, bedding and accessories. In addition, NFM and R.C. Willey sell a full line of major household appliances,
electronics, floor coverings, and other home furnishings and offer customer financing to complement their retail operations.
An important feature of each of these businesses is their ability to control costs and to produce high business volume by offering
significant value to their customers.


NFM operates its business from four retail complexes with almost 4.5 million square feet of retail, warehouse and
administrative facilities located in Omaha, Nebraska, Clive, Iowa, Kansas City, Kansas and The Colony, Texas. NFM also
owns Homemakers Furniture located in Urbandale, Iowa, which has approximately 600,000 square feet of retail, warehouse
and administrative space. NFM is the largest home furnishings retailer in each of these markets. R.C. Willey, based in Salt
Lake City, Utah, currently operates ten full-line retail home furnishings stores and three distribution centers. These facilities
include approximately 1.3 million square feet of retail space with four stores located in Utah, one store in Meridian, Idaho,
three stores in Nevada (Las Vegas and Reno) and two stores in the Sacramento, California area.


Jordan’s operates a retail furniture business from eight locations with approximately 1 million square feet of retail space
in stores located in Massachusetts, New Hampshire, Rhode Island, Maine and Connecticut. The retail stores are supported by
an 800,000 square foot distribution center in Taunton, Massachusetts. Jordan’s is the largest furniture retailer, as measured by
sales, in Massachusetts, Maine and New Hampshire and is well known in its markets for its unique store arrangements and
advertising campaigns. Star operates home furnishings retail stores in Texas. Star’s retail facilities currently include about
700,000 square feet of retail space in 10 locations in Texas, including seven in Houston.


K-22


---

Other


Other retailing businesses include three jewelry companies. Borsheim Jewelry Company, Inc. (“Borsheims”) operates
from a single store in Omaha, Nebraska. Borsheims is a high-volume retailer of fine jewelry, watches, crystal, china, stemware,
flatware, gifts and collectibles. Helzberg’s Diamond Shops, LLC (“Helzberg”) is based in North Kansas City, Missouri, and
operates a chain of 163 retail jewelry stores in 34 states, which includes approximately 350,000 square feet of retail space.
Helzberg’s stores are located in malls, outlet malls and other retail venues, and operate under the name Helzberg Diamonds®
or Helzberg Diamonds Outlet®. Ben Bridge Jeweler (“Ben Bridge”), based in Seattle, Washington, operates retail jewelry
stores under the Ben Bridge Jeweler and five other brand names in nine western states. The Ben Bridge Jeweler locations offer
loose diamonds, finished jewelry and high-end timepieces. Ben Bridge also operates five boutiques that sell timepieces of
specific brands, including Rolex, Tudor, Grand Seiko, Omega and Breitling.


See’s Candy Shops, Incorporated (“See’s”) produces boxed chocolates and other confectionery products with an
emphasis on quality and distinctiveness in two large kitchens in Los Angeles and South San Francisco and a facility in
Burlingame, California. See’s operates approximately 250 retail and volume saving stores located mainly in California and
other Western states, as well as approximately 115 seasonal locations. See’s revenues are highly seasonal with approximately
half of its annual revenues earned in the fourth quarter.


The Pampered Chef, Ltd. (“Pampered Chef”) is a premier direct seller of distinctive high-quality kitchenware products
with sales and operations in the U.S., Canada, Germany, Austria and France and operations in China. Pampered Chef’s product
portfolio consists of over 400 Pampered Chef® branded kitchenware items in categories ranging from stoneware and cutlery
to grilling and entertaining. Pampered Chef’s products are available through its sales force of independent cooking consultants
and online.


Oriental Trading Company (“OTC”) is an online retailer for fun value-priced party supplies, seasonal products, arts and
crafts, toys and novelties, school supplies, educational games and patient giveaways. OTC, headquartered in Omaha, Nebraska,
serves a broad base of over three million customers annually, including consumers, schools, churches, non-profit organizations,
medical and dental offices and other businesses. OTC offers a unique assortment of over 70,000 fun value-priced products
emphasizing proprietary designs. OTC operates both direct-to-consumer and business-to-business brands including Oriental
Trading®, Fun Express®, MindWare®, SmileMakers®, Morris Costumes® and HalloweenExpress.com® and utilizes a multichannel marketing approach along with dedicated sales teams to promote online sales.


Detlev Louis Motorrad (“Louis”), headquartered in Hamburg, Germany, is a leading retailer of motorcycle clothing and
equipment in Europe. Louis carries over 50,000 different store and private label products, mainly covering the areas of clothing,
technical equipment and leisure. Louis has over 80 stores in Germany, Austria, Switzerland and the Netherlands as well as an
online business with online shops in various languages in Europe.


**Additional information with respect to Berkshire’s businesses**


Revenue, earnings before taxes and identifiable assets attributable to Berkshire’s reportable business segments are
included in Note 26 to Berkshire’s Consolidated Financial Statements contained in Item 8, Financial Statements and
Supplementary Data. Additional information regarding Berkshire’s investments in fixed maturity and equity securities is
included in Notes 3 and 4, respectively, to Berkshire’s Consolidated Financial Statements.


As of December 31, 2024, Berkshire or a subsidiary owned approximately 27% of the outstanding common stock of The
Kraft Heinz Company (“Kraft Heinz”) and 28% of the outstanding Occidental Petroleum Corporation (“Occidental”) common
stock. Kraft Heinz manufactures and markets food and beverage products, including condiments and sauces, cheese and dairy,
meals, meats, refreshment beverages, coffee and other grocery products. Occidental is an international energy company,
including oil and natural gas exploration, development and production, and chemicals manufacturing businesses. Occidental’s
midstream businesses purchase, market, gather, process, transport and store various oil, natural gas, carbon dioxide and other
products. Information concerning these investments is included in Note 5 to Berkshire’s Consolidated Financial Statements.


Berkshire maintains a website (http://www.berkshirehathaway.com) where its annual reports, certain corporate
governance documents, press releases, interim shareholder reports and links to its subsidiaries’ websites can be found.
Berkshire’s periodic reports filed with the SEC, which include Form 10-K, Form 10-Q, Form 8-K and amendments thereto,
may be accessed by the public free of charge from the SEC and through Berkshire. Electronic copies of these reports can be
accessed at the SEC’s website (http://www.sec.gov) and indirectly through Berkshire’s website
(http://www.berkshirehathaway.com). Copies of these reports may also be obtained, free of charge, upon written request to:
Berkshire Hathaway Inc., 3555 Farnam Street, Omaha, NE 68131, Attn: Corporate Secretary.


K-23


---

**Item 1A. Risk Factors**


Berkshire and its subsidiaries (referred to herein as “we,” “us,” “our” or similar expressions) are subject to certain risks
and uncertainties in its business operations which are described below. The risks and uncertainties described below are not the
only risks we face. Additional risks and uncertainties that are presently unknown or are currently deemed immaterial may also
impair our business operations.


**General Business Risks**


**Terrorist acts could hurt our operating businesses.**


A nuclear, biological or chemical terrorist attack or armed terrorist incursions could produce significant losses to our
worldwide operations. Our business operations could be adversely affected from such acts through the loss of human life,
destruction of production facilities and information systems or other property damage. We share these risks with all businesses.


**Cybersecurity risks could result in economic losses to our businesses and reputational damage.**


We rely on technology in virtually all aspects of our business. Like those of many large businesses, certain of our
information systems have been subject to computer viruses, malicious codes, unauthorized access, phishing efforts, denial-ofservice attacks and other cyber-attacks. We expect to be subject to similar attacks in the future as such attacks become more
sophisticated and frequent. A significant disruption or failure of our technology systems could result in service interruptions,
safety failures, security events, regulatory compliance failures, an inability to protect information and assets against
unauthorized users and other operational difficulties. Attacks perpetrated against our systems could result in loss of assets and
critical information and expose us to remediation costs and reputational damage.


Although we have taken steps intended to mitigate these risks, including business continuity planning, disaster recovery
planning and business impact analysis, a significant disruption or cyber intrusion at one or more of our significant operations
could adversely affect our results of operations, financial condition and/or liquidity. Additionally, if we are unable to acquire,
develop, implement, adopt or protect rights around new technology, we may suffer a competitive disadvantage, which could
also have an adverse effect on our results of operations, financial condition and/or liquidity.


Cyber-attacks could further adversely affect our ability to operate our facilities, information technology and business
systems or compromise confidential customer and employee information. Political, economic, social or financial market
instability or damage to or interference with our operating assets, customers or suppliers from cyber-attacks may result in
business interruptions, lost revenues, higher commodity prices, disruption in fuel supplies, lower energy consumption, unstable
markets, increased security, repair or other costs, or may materially adversely affect us in ways that cannot be predicted at this
time. Any of these risks could materially affect our consolidated financial results. Furthermore, instability in the financial
markets resulting from terrorism, sustained or significant cyber-attacks or war could also have a material adverse effect on our
ability to raise capital. We share these risks with all businesses.


**Geopolitical events could cause losses to our business and losses in the values of securities we own.**


We believe risks of adverse effects from geopolitical events are rising, through armed and diplomatic conflicts involving
governments in various parts of the world. Government policies and actions taken in the U.S. and elsewhere, including
responses of other governments to such actions may adversely affect our operating businesses through reduced sales, increased
costs, restricted supply chains, physical damage to our properties and loss of life of our employees and losses in the values of
the securities we own. In addition, international trade policies in the U.S. and elsewhere, including tariffs and other barriers,
could negatively impact our operating results. We share these risks with all businesses.


**We are dependent on a few key people for our major investment and capital allocation decisions.**


Major investment decisions and all major capital allocation decisions are made by Warren E. Buffett, Chairman of the
Board of Directors and Chief Executive Officer, age 94. Mr. Gregory Abel is Vice Chairman of Berkshire’s non-insurance
operations and Mr. Ajit Jain is Vice Chairman of Berkshire’s insurance operations. Mr. Abel and Mr. Jain each report directly
to Mr. Buffett.


If for any reason the services of our key personnel, particularly Mr. Buffett, were to become unavailable, there could be
a material adverse effect on our operations. Should a replacement for Mr. Buffett be needed currently, Berkshire’s Board of
Directors has agreed that Mr. Abel should replace Mr. Buffett. The Board continually monitors this risk and could alter its
current view regarding a replacement for Mr. Buffett in the future. We believe that the Board’s succession plan, together with
the outstanding managers running our numerous and highly diversified operating units, helps to mitigate this risk.


K-24


---

**We need qualified personnel to manage and operate our various businesses.**


In our decentralized business model, we need qualified and competent management to direct day-to-day business
activities of our operating subsidiaries and to manage changes in future business operations due to changing business or
regulatory environments. Our operating subsidiaries also need qualified and competent personnel to execute business plans and
serve their customers, suppliers and other stakeholders. Our inability to recruit, train and retain qualified and competent
managers and personnel could negatively affect the operating results, financial condition and liquidity of our subsidiaries and
Berkshire as a whole. Further, labor disruptions or strikes at our subsidiaries, our customers or within our supply chains could
reduce our sales, increase our costs and negatively impact our periodic operating results.


**Investments are unusually concentrated in equity securities and fair values are subject to loss in value.**


We concentrate a high percentage of the equity security investments of our insurance subsidiaries in a relatively small
number of issuers. A significant decline in the fair values of our larger investments in equity securities may produce a material
decline in our consolidated shareholders’ equity and our consolidated earnings.


Since a large percentage of our equity securities are held by our insurance subsidiaries, significant decreases in the fair
values of these investments will produce significant declines in the statutory surplus of our insurance subsidiaries. Our large
statutory surplus is a competitive advantage, and a long-term material decline could have an adverse effect on our claimspaying ability ratings and our ability to write new insurance business, thus potentially reducing our future underwriting profits.


**Competition and technology may erode our business franchises and result in lower earnings.**


Each of our operating businesses face intense competition within markets in which they operate. While we manage our
businesses with the objective of achieving long-term sustainable growth by developing and strengthening competitive
advantages, many factors, including technological changes, may erode or prevent the strengthening of competitive advantages.
Accordingly, our future operating results will depend to some degree on our operating units successfully protecting and
enhancing their competitive advantages. If our operating businesses are unsuccessful in these efforts, our periodic operating
results in the future may decline.


**Unfavorable** **general** **economic** **conditions** **may** **significantly** **reduce** **our** **operating** **earnings** **and** **impair** **our** **ability** **to**
**access capital markets at a reasonable cost.**


Our operating businesses are subject to normal economic cycles affecting the general economy or the specific industries
in which they operate. Significant deteriorations of economic conditions, including significant inflation over a prolonged period
could produce a material adverse effect on one or more of our significant operations. In addition, our utilities and energy
businesses and our railroad business regularly utilize debt as a component of their capital structures and depend on having
access to borrowed funds through the capital markets at reasonable rates. To the extent that access to the capital markets is
restricted or the cost of funding increases, these operations could be adversely affected.


**Epidemics, pandemics or other similar outbreaks could hurt our operating businesses.**


The outbreak of epidemics, pandemics or other similar outbreaks in the future may adversely affect our operations,
including the value of our equity securities portfolio. This may be due to closures or restrictions requested or mandated by
governmental authorities, disruption to supply chains and workforce, reduction of demand for our products and services, credit
losses when customers and other counterparties fail to satisfy their obligations to us, and volatility in global equity securities
markets, among other factors. We share most of these risks with all businesses.


**Regulatory changes may adversely impact our future operating results.**


Over time, regulatory initiatives have been adopted in the United States and elsewhere for a variety of reasons, including
as responses to financial markets crises, global economic recessions, and social and environmental issues. Such initiatives
address, for example, the regulation of banks and other major financial institutions, the regulation of products and services and
environmental and climate change matters and income tax policy. These initiatives impact all of our businesses, albeit in
varying ways. Increased regulatory compliance costs could have a significant negative impact on our operating businesses, as
well as on the businesses in which we have significant, but not controlling, economic interests. We cannot predict whether such
initiatives will have a material adverse impact on our consolidated financial position, results of operations and/or cash flows.


Data privacy regulations have recently been enacted in various jurisdictions in the U.S. and throughout the world. These
regulations address numerous aspects related to the security of personal information that is stored in our information systems,
networks and facilities. Failure to comply with these regulations could result in reputational damage and significant economic
penalties.


K-25


---

**Climate change and the regulation of greenhouse gas (“GHG”) emissions may impact our businesses.**


Climate and weather-related events and the regulation of GHG emissions could impact our businesses to varying degrees.
Climate-related events, including hurricanes, floods, wildfires, and other extreme weather events may increase the physical
risks and impacts to our operations. An increase in the frequency or intensity of extreme weather events and storms could
negatively impact the physical assets of our non-insurance operations and could produce losses affecting our businesses.
Similarly, extreme weather events may produce losses affecting our insurance operations as their primary business is to monitor,
assess and price risk, including climate-related risk, at an expected economic profit to address the risk-transfer needs of their
insurance customers.


Additional GHG and climate-related policies, including legislation, may emerge that influence the transition to a lower
GHG-emitting economy and could, in turn, influence costs for our businesses to comply with those policies, including BNSF
and BHE, which combined represent more than 90% of Berkshire’s direct emissions. The failure to comply with new or existing
regulations or reinterpretation of existing regulations relating to climate change could have a significant adverse effect on our
financial results.


**Risks unique to our regulated businesses**


**Our tolerance for underwriting risk assumed in our various insurance businesses may result in significant underwriting**
**losses.**


When properly paid for the risk assumed, we have been and will continue to be willing to assume more risk from a single
event than any other insurer has knowingly assumed. Accordingly, we could incur a significant loss from a single catastrophe
event resulting from a natural disaster or man-made catastrophes such as terrorism or cyber-attacks. We employ various
disciplined underwriting practices intended to mitigate potential losses, attempt to take into account all possible correlations
and avoid writing groups of policies from which pre-tax losses from a single catastrophe event might aggregate in excess of
$15 billion. However, despite our efforts, it is possible that losses could manifest in ways that we do not anticipate and that our
risk mitigation strategies are not designed to address. Various provisions of our policies, negotiated to limit our risk, such as
limitations or exclusions from coverage, may not be enforceable in the manner we intend, as it is possible that a court or
regulatory authority could nullify or void an exclusion or limitation, or legislation could be enacted modifying or barring the
use of these exclusions and limitations. Our tolerance for significant insurance losses may result in lower reported earnings in
a future period.


The principal cost associated with the property and casualty insurance business is claims. In writing property and casualty
insurance policies, we receive premiums today and promise to pay covered losses in the future. However, it will take decades
before all claims that have occurred as of any given balance sheet date will be settled. Although we believe that recorded
liabilities for unpaid losses are adequate, we will not know whether these liabilities or the premiums charged for the coverages
provided were sufficient until well after the balance sheet date. Estimating insurance claim costs is inherently imprecise. It is
possible that significant claims may emerge or develop in the future from the policies we have written in the past.


As industry practices and legal, social and environmental conditions evolve, unexpected and unintended issues related
to claims and coverage may emerge, including new or expanded theories of liability and increased frequency of litigation.
These or other changes could impose new financial obligations on us by extending coverage beyond our underwriting intent
and result in increased litigation costs and adverse judicial awards. In some instances, these changes may not become apparent
until sometime after we have issued insurance or reinsurance contracts that are affected by the changes. As a result, the full
extent of liability under our insurance or reinsurance contracts may not be known for many years after a contract is issued. Our
estimated unpaid losses arising under contracts covering property and casualty insurance risks are large ($147.6 billion at
December 31, 2024), and a small percentage increase to those liabilities can result in a material reduction in reported earnings.


**Changes** **in** **regulations** **and** **regulatory** **actions** **can** **adversely** **affect** **our** **operating** **results** **and** **our** **ability** **to** **allocate**
**capital.**


Our insurance businesses are subject to regulation in the jurisdictions in which we operate. Such regulations may relate
to, among other things, the types of business that can be written, the rates that can be charged for coverage, the level of capital
that must be maintained and restrictions on the types and size of investments that can be made. Regulations may also restrict
the timing and amount of dividend payments to Berkshire by these businesses. U.S. state insurance regulators and international
insurance regulators are also actively developing various regulatory mechanisms to address the regulation of large
internationally active insurance groups, including regulations concerning group capital, liquidity, governance and risk
management. Accordingly, changes in regulations related to these or other matters or regulatory actions imposing restrictions
on our insurance businesses may adversely impact our results of operations and restrict our ability to allocate capital.


K-26


---

Our railroad business conducted through BNSF is also subject to a significant number of laws and regulations with
respect to rates and practices, taxes, railroad operations and a variety of health, safety, labor, environmental and other matters.
Failure to comply with applicable laws and regulations could have a material adverse effect on BNSF’s business. Governments
may change the legislative and/or regulatory framework within which BNSF operates, without providing any recourse for any
adverse effects that the change may have on the business. Complying with legislative and regulatory changes may pose
significant operating and implementation risks and require significant capital expenditures. BNSF can be exposed to significant
litigation costs and losses arising from these matters and from ongoing business operations.


BNSF derives significant amounts of revenue from the transportation of energy-related commodities, particularly coal.
To the extent that changes in government policies limit or restrict the usage of coal as a fuel source in generating electricity or
alternate fuels, such as natural gas, or otherwise displace coal as an energy source, revenues and earnings could be adversely
affected. As a common carrier, BNSF is also required to transport toxic inhalation hazard chemicals and other hazardous
materials. A release of hazardous materials could expose BNSF to significant claims, losses, penalties and environmental
remediation obligations. Changes in the regulation of the rail industry could negatively impact BNSF’s ability to determine
prices for rail services and to make capital improvements to its rail network, resulting in an adverse effect on our results of
operations, financial condition and/or liquidity.


Our utilities and energy businesses operated under BHE are highly regulated by numerous federal, state, local and foreign
governmental authorities in the jurisdictions in which they operate. These laws and regulations are complex, dynamic and
subject to new interpretations or change. Regulations affect almost every aspect of our utilities and energy businesses.
Regulations broadly apply and may limit management’s ability to independently make and implement decisions regarding
numerous matters including: acquiring businesses; constructing, acquiring, disposing or retiring of operating assets; operating
and maintaining generating facilities and transmission and distribution system assets; complying with pipeline safety and
integrity and environmental requirements; setting rates charged to customers; establishing capital structures and issuing debt;
managing and reporting transactions between our domestic utilities and our other subsidiaries and affiliates; and paying
dividends or similar distributions. Failure to comply with or reinterpretations of existing regulations and new legislation or
regulations, such as those relating to air quality, climate change, emissions performance standards, water quality, coal ash
disposal and other environmental matters, or changes in the nature of the regulatory process may have a significant adverse
impact on our financial results. Furthermore, our regulated energy subsidiaries are exposed to losses arising from wildfires and
related litigation and judicial outcomes. The energy rates charged by our regulated energy subsidiaries to customers are based
on the costs of the business and require regulatory approval. To the extent costs are not recoverable through approved rates,
the operating results and financial condition of these businesses can be negatively impacted, perhaps materially.


Our railroad business requires significant ongoing capital investment to improve and maintain its railroad network so
that transportation services can be safely and reliably provided to customers on a timely basis. Our utilities and energy
businesses also require significant amounts of capital to construct, operate and maintain generation, transmission and
distribution systems to meet their customers’ needs and reliability criteria. System assets may need to be operational for long
periods of time to justify the financial investment. The operational or financial failure of capital projects may not be recoverable
through rates that are charged to customers. Further, a significant portion of costs of capital improvements may be funded
through debt issued by BNSF and BHE and their subsidiaries. Disruptions in debt capital markets that restrict access to funding
when needed could adversely affect the results of operations, liquidity and/or capital resources of these businesses.


**Item 1B. Unresolved Staff Comments**


None.


**Item 1C. Cybersecurity**


Berkshire recognizes that maintaining processes for identifying, assessing, and managing cybersecurity threats is
important in dealing with its significant business risks. As such, Berkshire has implemented a framework for cybersecurity and
cyber-related information management across Berkshire’s diverse groups of businesses. The framework permits each Berkshire
Business Group (“Business Group”) to tailor solutions to identify, manage, and mitigate risks based on their own assessment
of their unique cybersecurity risks in conjunction with each Business Group’s overall risk management processes. At the same
time, the framework helps enable consistent and appropriate compliance in reporting material cyber events and risks across
Berkshire.


Each Business Group’s Chief Information Security Officer (“CISO”) on at least an annual basis is to provide a report to
the Business Group’s senior management, regarding the state of their cybersecurity program and its material cyber risks. These
reports are also shared with Berkshire’s internal audit group to inform and enhance the overall company’s risk management
processes. In addition, each Business Group is required to maintain an incident reporting process to report significant
cybersecurity events to Berkshire. Berkshire and its Business Groups engage and partner with a wide range of third parties to
assess, audit, educate, implement, operate, protect, and remediate various cybersecurity related elements.


K-27


---

Berkshire and its Business Groups rely on third-party service providers for a variety of products and services to run their
information systems. This dependence exposes Berkshire and the Business Groups, along with others who use these service
providers, to the impact of a cyber-attack on their service providers. On occasion, a cyber-attack at a third party service provider
could have a significant financial, operational or reputational impact to Berkshire. Berkshire and its Business Groups
continuously monitor the risks associated with its service providers.


The Audit Committee of Berkshire’s Board of Directors has responsibility for oversight of Berkshire’s cybersecurity risk
management program. The Audit Committee receives periodic reports regarding the number of and impact from cybersecurity
incidents reported through Berkshire’s cybersecurity incident reporting process. Additionally, the Audit Committee is updated
on cybersecurity trends and related issues. Furthermore, the Audit Committee approves and receives updates on the workplan
performed by Berkshire’s internal audit group that focuses on information technology and cybersecurity risks. This includes
audit procedures related to internal and external penetration testing, attack simulations, vulnerability assessments, cybersecurity
program reviews and other audits designed to investigate specific risks. The frequency of these updates is determined by the
Audit Committee in conjunction with Berkshire’s senior management.


In addition to the Audit Committee’s oversight, the senior management of Berkshire’s Businesses Groups are responsible
for the day-to-day operations of protecting their businesses’ information systems. Each Business Group is required to report
significant cybersecurity events to Berkshire. Berkshire’s senior management reviews incident reports to determine whether a
cyber incident report should be filed with the SEC.


**Item 2. Description of Properties**


The properties used by Berkshire’s business segments are summarized in this section. Berkshire’s railroad and utilities
and energy businesses, in particular, utilize considerable physical assets in their businesses.


**Burlington Northern Santa Fe**


Through BNSF Railway, BNSF operates over 32,500 route miles of track (excluding multiple main tracks, yard tracks

yard tracks and sidings, consisted of over 50,000 operated miles of track.


BNSF operates various facilities and equipment to support its transportation system, including its infrastructure,
locomotives and freight cars. It also owns or leases other equipment to support rail operations, such as vehicles. Support
facilities for rail operations include yards and terminals throughout its rail network, system locomotive shops to perform
locomotive servicing and maintenance, a centralized network operations center for train dispatching and network operations
monitoring and management, computers, telecommunications equipment, signal systems and other support systems. Transfer
facilities are maintained for rail-to-rail as well as intermodal transfer of containers, trailers and other freight traffic and include
approximately 25 intermodal hubs located across the system. BNSF owns or holds under non-cancelable leases exceeding one
year approximately 6,800 locomotives and 71,400 freight cars, in addition to maintenance of way and other equipment.


In the ordinary course of business, BNSF incurs significant costs in repairing and maintaining its properties. In 2024,
BNSF recorded approximately $2.4 billion in repairs and maintenance expense.


K-28


---

**Berkshire Hathaway Energy**


BHE’s energy properties consist of the physical assets necessary to support its electricity and natural gas businesses.
Properties of BHE’s electricity businesses include electric generation, transmission and distribution facilities, as well as coal
mining assets that support certain of BHE’s electric generating facilities. Properties of BHE’s natural gas businesses include
natural gas distribution facilities, interstate pipelines, storage facilities, liquefied natural gas facilities, compressor stations and
meter stations. The transmission and distribution assets are primarily within each of BHE’s utility service territories. In addition
to these physical assets, BHE has rights-of-way, mineral rights and water rights that enable BHE to utilize its facilities. Pursuant
to separate financing agreements, the majority of these properties are pledged or encumbered to support or otherwise provide
the security for the related subsidiary debt. BHE or its affiliates own or have interests in the following types of operating electric
generating facilities at December 31, 2024:


_(1)_ _Facility Net Capacity in megawatts (MW) represents the lesser of nominal ratings or any limitations under applicable_
_interconnection, power purchase, or other agreements for intermittent resources and the total net dependable capability_
_available during summer conditions for all other units. An intermittent resource’s nominal rating is the manufacturer’s_
_contractually specified capability (in MW) under specified conditions. Net Owned Capacity indicates BHE’s ownership_
_of Facility Net Capacity._


As of December 31, 2024, BHE’s subsidiaries also have electric generating facilities that are under construction in
Wyoming, Nevada, West Virginia and California having total Facility Net Capacity and Net Owned Capacity of 1,085 MW.
BHE’s subsidiaries also have battery energy storage systems in Nevada, Montana, West Virginia and Oregon having total
Facility Net Capacity and Net Owned Capacity in operation of 320 MW and under construction of 527 MW.


PacifiCorp, MEC and NV Energy own electric transmission and distribution systems, including approximately 28,300
miles of transmission lines and approximately 1,660 substations, and gas distribution facilities, including approximately 28,700
miles of gas mains and service lines.


The BHE GT&S pipeline system consists of approximately 5,400 miles of natural gas transmission, gathering and storage
pipelines located in portions of Maryland, New York, Ohio, Pennsylvania, Virginia, West Virginia, South Carolina and
Georgia. Storage services are provided through the operation of 17 underground natural gas storage fields located in
Pennsylvania, West Virginia and New York. BHE GT&S also operates, as the general partner, and holds a 75% limited
partnership interest in one liquefied natural gas export, import and storage facility in Maryland and operates and has interests
in three smaller liquefied natural gas facilities in Alabama, Florida and Pennsylvania.


K-29


---

Northern Natural’s pipeline system consists of approximately 14,200 miles of natural gas pipelines, including
approximately 5,800 miles of mainline transmission pipelines and approximately 8,400 miles of branch and lateral pipelines.
Northern Natural’s end-use and distribution market area includes points in Iowa, Nebraska, Minnesota, Wisconsin, South
Dakota, Michigan and Illinois and its natural gas supply and delivery service area includes points in Kansas, Texas, Oklahoma
and New Mexico. Storage services are provided through the operation of one underground natural gas storage field in Iowa,
two underground natural gas storage facilities in Kansas and two liquefied natural gas storage peaking units, one in Iowa and
one in Minnesota.


Kern River’s system consists of approximately 1,400 miles of natural gas pipelines, which extends from the system’s
point of origination in Wyoming through the Central Rocky Mountains into California.


Northern Powergrid (Northeast) and Northern Powergrid (Yorkshire) operate an electricity distribution network that
includes approximately 17,100 miles of overhead lines, approximately 44,600 miles of underground cables and approximately
860 major substations. AltaLink’s electricity transmission system includes approximately 8,300 miles of transmission lines and
approximately 310 substations.


**Other Segments**


Significant physical properties used by Berkshire’s other business segments are summarized below:


K-30


---

**Item 3. Legal Proceedings**


Berkshire and its subsidiaries are parties in a variety of legal actions that routinely arise out of the normal course of
business, including legal actions seeking to establish liability directly through insurance contracts or indirectly through
reinsurance contracts issued by Berkshire subsidiaries. Plaintiffs occasionally seek punitive or exemplary damages. We do not
believe that such normal and routine litigation will have a material effect on our financial condition or results of operations.


Reference is made to Note 27 to the accompanying Consolidated Financial Statements for information concerning certain
litigation involving Berkshire subsidiaries. Berkshire and certain of its subsidiaries are also involved in other kinds of legal
actions, some of which assert or may assert claims or seek to impose fines and penalties. We currently believe that any liability
that may arise from other pending legal actions will not have a material effect on our consolidated financial condition or results
of operations.


**Item 4. Mine Safety Disclosures**


Information regarding the Company’s mine safety violations and other legal matters disclosed in accordance with Section
1503(a) of the Dodd-Frank Reform Act is included in Exhibit 95 to this Form 10-K.


**Executive Officers of the Registrant**


Following is a list of the Registrant’s named executive officers:


Each executive officer serves, in accordance with the by-laws of the Registrant, until the first meeting of the Board of
Directors following the next annual meeting of shareholders and until a successor is chosen and qualified or until such executive
officer sooner dies, resigns, is removed or becomes disqualified.


**FORWARD-LOOKING STATEMENTS**


Investors are cautioned that certain statements contained in this document as well as some statements in periodic press
releases and some oral statements of Berkshire officials during presentations about Berkshire or its subsidiaries are “forwardlooking” statements within the meaning of the Private Securities Litigation Reform Act of 1995 (the “Act”). Forward-looking
statements include statements which are predictive in nature, which depend upon or refer to future events or conditions, or
which include words such as “expects,” “anticipates,” “intends,” “plans,” “believes,” “estimates” or similar expressions. In
addition, any statements concerning future financial performance (including future revenues, earnings or growth rates), ongoing
business strategies or prospects and possible future Berkshire actions, which may be provided by management, are also forwardlooking statements as defined by the Act. Forward-looking statements are based on current expectations and projections about
future events and are subject to risks, uncertainties and assumptions about Berkshire and its subsidiaries, economic and market
factors and the industries in which we do business, among other things. These statements are not guarantees of future
performance and we have no specific intention to update these statements.


Actual events and results may differ materially from those expressed or forecasted in forward-looking statements due to
a number of factors. The principal risk factors that could cause our actual performance and future events and actions to differ
materially from such forward-looking statements include, but are not limited to, changes in market prices of our investments
in equity securities; the occurrence of one or more catastrophic events, such as an earthquake, hurricane, geopolitical conflict,
act of terrorism or cyber-attack that causes losses insured by our insurance subsidiaries and/or losses to our business operations;
the frequency and severity of epidemics, pandemics or other outbreaks, and other events that negatively affect our operating
results and restrict our access to borrowed funds through the capital markets at reasonable rates; changes in laws or regulations
affecting our insurance, railroad, utilities and energy and finance subsidiaries; changes in federal income tax laws; and changes
in general economic and market factors that affect the prices of securities or the industries in which we do business.


**Part II**


**Item** **5.** **Market** **for** **Registrant’s** **Common** **Equity,** **Related** **Security** **Holder** **Matters** **and** **Issuer** **Purchases** **of** **Equity**
**Securities**


**Market Information**


Berkshire’s Class A and Class B common stock are listed for trading on the New York Stock Exchange, trading symbols:
BRK.A and BRK.B, respectively.


K-31


---

**Shareholders**


Berkshire had approximately 1,100 record holders of its Class A common stock and 16,800 record holders of its Class B
common stock at February 10, 2025. Record owners included nominees holding at least 319,000 shares of Class A common
stock and 1,332,000,000 shares of Class B common stock on behalf of beneficial-but-not-of-record owners.


**Dividends**


Berkshire has not declared a cash dividend since 1967.


**Common Stock Repurchase Program**


Berkshire’s common stock repurchase program permits Berkshire to repurchase its Class A and Class B shares at any
time that Warren Buffett, Berkshire’s Chairman of the Board and Chief Executive Officer, believes that the repurchase price is
below Berkshire’s intrinsic value, conservatively determined. Repurchases may be in the open market or through privately
negotiated transactions. No Class A or Class B shares were repurchased in the fourth quarter of 2024.


_*_ _The_ _program_ _does_ _not_ _specify_ _a_ _maximum_ _number_ _of_ _shares_ _to_ _be_ _repurchased_ _or_ _obligate_ _Berkshire_ _to_ _repurchase_ _any_
_specific_ _dollar_ _amount_ _or_ _number_ _of_ _Class_ _A_ _or_ _Class_ _B_ _shares_ _and_ _there_ _is_ _no_ _expiration_ _date_ _to_ _the_ _repurchase_ _program._
_Berkshire_ _will_ _not_ _repurchase_ _its_ _common_ _stock_ _if_ _the_ _repurchases_ _reduce_ _the_ _value_ _of_ _Berkshire’s_ _consolidated_ _cash,_ _cash_
_equivalents and U.S. Treasury Bills holdings to less than $30 billion._


**Stock Performance Graph**


The following chart compares the value of $100 invested in Berkshire common stock on December 31, 2019 and
subsequent values with a similar investment in the Standard & Poor’s 500 Stock Index and in the Standard & Poor’s Property
& Casualty Insurance Index.**


240


220


200


180


160


140


120


100


80


|Berkshire Hathaway Inc.<br>S&P 500 Index*|228|
|---|---|
|**S&P 500 Property & Casualty Insurance Index***|**S&P 500 Property & Casualty Insurance Index***|


|200 S&P 500 Property & Casualty Insurance Index*|Col2|Col3|Col4|Col5|Col6|Col7|
|---|---|---|---|---|---|---|
|197|197|197|197|197|197|197|
|168|168|168|168|168|168|168|
|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|158<br>152<br>152<br>159<br>137|
|128<br>125<br>118<br>132|128<br>125<br>118<br>132|128<br>125<br>118<br>132|128<br>125<br>118<br>132|128<br>125<br>118<br>132|128<br>125<br>118<br>132|128<br>125<br>118<br>132|
|107|107|107|107|107|107|107|
|102|102|102|102|102|102|102|
||||||||


_* Cumulative return for the Standard & Poor’s indices based on reinvestment of dividends._


_** It is difficult to develop a group of companies comparable to Berkshire. Berkshire owns subsidiaries engaged in numerous_
_diverse_ _business_ _activities_ _of_ _which_ _an_ _important_ _component_ _is_ _the_ _property_ _and_ _casualty_ _insurance_ _business._ _Accordingly,_
_Berkshire uses the Standard & Poor’s Property & Casualty Insurance Index for comparative purposes._


**Item 6. [Reserved]**


K-32


---

**Item 7. Management’s Discussion and Analysis of Financial Condition and Results of Operations**


**Results of Operations**


Net earnings (loss) attributable to Berkshire shareholders for each of the past three years are disaggregated in the table
that follows. Amounts are after deducting income taxes and exclude earnings attributable to noncontrolling interests (in
millions).


——————

_* Includes certain businesses in which Berkshire had between a 20% and 50% ownership interest._


Through our subsidiaries, we engage in numerous diverse business activities. The business segment data (Note 26 to the
accompanying Consolidated Financial Statements) should be referenced in conjunction with this discussion.


Our periodic operating results may be affected in future periods due to impacts of ongoing macroeconomic and
geopolitical events, as well as changes in industry or company-specific factors or events. We cannot reliably predict the future
economic effects of these factors or events on our businesses.


Insurance underwriting generated after-tax earnings of $9.0 billion in 2024 and $5.4 billion in 2023 and losses of $30
million in 2022. Earnings in 2024 and 2023 benefited from significantly improved operating results at GEICO, which generated
a significant loss in 2022. Underwriting results in 2024 also included estimated claims from Hurricanes Helene and Milton
($1.2 billion after-tax) and accruals in connection with a bankruptcy settlement agreement related to a non-insurance affiliate.
Underwriting results in 2023 and 2022 included after-tax losses from significant catastrophe events of approximately $725
million and $2.4 billion, respectively. After-tax earnings from insurance investment income increased $4.1 billion in 2024 and
$3.1 billion in 2023 compared to corresponding prior years, driven by higher interest income from short-term investments.


After-tax earnings of BNSF declined 1.1% in 2024 compared to 2023 and 14.4% in 2023 compared to 2022. Earnings in
2024 benefited from higher unit volume, improvements in employee productivity and lower other operating costs, and were
negatively impacted by charges related to a labor agreement in the fourth quarter of 2024 and litigation charges related to an
ongoing legal case. The decrease in 2023 was primarily attributable to lower overall freight volumes and higher non-fuel
operating costs, partially offset by lower fuel costs.


After-tax earnings of our utilities and energy business increased $1.4 billion in 2024 compared to 2023 and declined $1.6
billion in 2023 compared to 2022. The earnings increase in 2024 reflected lower estimated wildfire loss accruals at PacifiCorp
and higher earnings from natural gas pipelines, primarily due to reductions in earnings attributable to noncontrolling interests,
and other energy businesses. The earnings decline in 2023 reflected increased estimated wildfire loss accruals, as well as lower
earnings from other energy and real estate brokerage businesses compared to 2022.


Earnings from our manufacturing, service and retailing businesses decreased 2.2% in 2024 compared to 2023 and
increased 6.8% in 2023 compared to 2022. The earnings decline in 2024 reflected lower earnings from our service and retailing
businesses, partially offset by earnings increases at several of our manufacturing businesses. The earnings increase in 2023
reflected increases at certain industrial products manufacturers and service businesses, the full year impact of Alleghany’s noninsurance businesses acquired in 2022 and earnings from Pilot Travel Centers for the eleven months ending December 31,
2023, partially offset by lower earnings at several of our other manufacturing businesses and at certain of our service and
retailing businesses.


K-33


---

**Management’s Discussion and Analysis**


**Results of Operations**


Investment gains (losses) predominantly derive from our investments in equity securities and include significant
unrealized gains and losses from changes in market prices and foreign currency exchange rates applicable to certain of our
investments. We believe that investment gains and losses, whether realized from dispositions or unrealized from changes in
market prices, are generally meaningless in understanding our reported periodic results or evaluating the economic performance
of our operating businesses. These gains and losses have caused and will continue to cause significant volatility in our periodic
earnings. Investment gains in 2023 also included an after-tax non-cash remeasurement gain of approximately $2.4 billion
related to our previously held 38.6% interest in Pilot through the application of the acquisition accounting method.


Other earnings included after-tax foreign currency exchange rate gains of $1.1 billion in 2024, $211 million in 2023 and
$1.3 billion in 2022 related to the non-U.S. Dollar denominated debt issued by Berkshire and Berkshire Hathaway Finance
Corporation (“BHFC”).


_**Insurance—Underwriting**_


Our periodic underwriting earnings may be subject to considerable volatility from the timing and magnitude of significant
property catastrophe loss events. Further, we generally do not retrocede the risks we assume. We currently consider
consolidated pre-tax losses exceeding $150 million from an event occurring in the current year to be significant. Significant
events in 2024 included Hurricanes Milton and Helene, while significant events in 2023 included a cyclone and floods in New
Zealand and a hailstorm in Italy. In 2022, significant events were Hurricane Ian and floods in Australia. In January 2025,
several wildfires broke out in Southern California resulting in thousands of destroyed or damaged structures. We preliminarily
estimate our insurance group could incur pre-tax losses of approximately $1.3 billion from these wildfires. Changes in estimates
for unpaid losses and loss adjustment expenses, including amounts established for occurrences in prior years, and foreign
currency transaction gains and losses arising from the changes in the valuation of non-U.S. Dollar denominated assets and
liabilities can also significantly affect our periodic underwriting results.


We write primary insurance and reinsurance policies covering property and casualty risks, as well as life and health risks.
Our insurance and reinsurance businesses are GEICO, Berkshire Hathaway Primary Group (“BH Primary”) and Berkshire
Hathaway Reinsurance Group (“BHRG”). We strive to generate pre-tax underwriting earnings (defined as premiums earned
less insurance losses/benefits incurred and underwriting expenses) over the long term in all business categories, except in our
retroactive reinsurance and periodic payment annuity businesses. Time-value-of-money is an important consideration in
establishing premiums for these policies, which we normally receive at the contract inception date. Claim and benefit payments
can extend for decades and are expected to exceed premiums, producing underwriting losses over the claim settlement periods
through changes in deferred charge assets established on retroactive reinsurance contracts and accretion of discounted annuity
liabilities, as well as changes in the estimated ultimate liabilities.


Underwriting results of our insurance businesses are summarized below (dollars in millions).


——————

_* Not meaningful._


K-34


---

**Management’s Discussion and Analysis**


_**Insurance—Underwriting**_


_GEICO_


GEICO writes property and casualty policies, primarily private passenger automobile insurance, in all 50 states and the
District of Columbia. GEICO markets its policies mainly by direct response methods where most customers apply for coverage
directly to the company via the Internet or over the telephone. GEICO also operates an insurance agency that offers primarily
homeowners and renters insurance to its auto policyholders. A summary of GEICO’s underwriting results follows (dollars in
millions).


2024 versus 2023


GEICO’s pre-tax underwriting earnings increase in 2024 compared to 2023 reflected higher average premiums per auto
policy, lower claims frequencies and improved operating efficiencies. These effects were partially offset by less favorable
development of prior accident years’ claims estimates, increases in average claims severities and losses from catastrophe events.


Premiums written increased $3.1 billion (7.7%) in 2024 compared to 2023, reflecting an increase in average written
premiums per auto policy of 7.8%, primarily attributable to rate increases, partially offset by a 0.5% decrease in policies-inforce over the past year. The rate of decline in policies-in-force slowed in the first half of 2024, with growth experienced in the
second half of the year. Premiums earned in 2024 increased $3.0 billion (7.6%) compared to 2023.


Losses and loss adjustment expenses decreased $1.5 billion (4.7%) in 2024 compared to 2023. GEICO’s loss ratio (losses
and loss adjustment expenses to premiums earned) was 71.8% in 2024 and 81.0% in 2023. The loss ratio decline reflected the
impact of higher average earned premiums per auto policy and lower claims frequencies, partially offset by increases in average
claims severities and less favorable development of prior accident years’ claims estimates.


Claims frequencies declined in 2024 versus 2023 for property damage (two to three percent range) and collision (eight
to nine percent range) coverages, with bodily injury down slightly. Average claims severities increased in 2024 for property
damage and collision (two to five percent range) and bodily injury coverages (eight to ten percent range) compared to 2023.
Losses and loss adjustment expenses incurred in 2024 from Hurricanes Helene and Milton were approximately $360 million.
Reductions in the ultimate loss estimates for prior accident years’ claims were $550 million in 2024 compared to $1.5 billion
in 2023.


Underwriting expenses increased 7.7% in 2024 compared to 2023. GEICO’s expense ratio (underwriting expense to
premiums earned) was 9.7% in 2024, unchanged from 2023, as improved operating efficiencies and increased operating
leverage were offset by increased advertising expenses. The earnings from GEICO’s insurance agency (third-party
commissions, net of operating expenses) are included as a reduction of underwriting expenses.


2023 versus 2022


GEICO’s pre-tax underwriting earnings increase in 2023 reflected higher average premiums per auto policy, lower claims
frequencies, more favorable development of prior accident years’ claims estimates and lower advertising costs. However,
average claims severities increased in 2023 due to higher auto repair parts prices, labor costs and medical inflation. GEICO
sought rate increases in numerous states in 2022 and 2023 in response to accelerating claims costs.


K-35


---

**Management’s Discussion and Analysis**


_**Insurance—Underwriting**_


_GEICO_


Premiums written increased $730 million (1.9%) in 2023 compared to 2022, reflecting higher average premiums per auto
policy (16.8%) due to rate increases, partially offset by a 9.8% decrease in policies-in-force. Premiums earned increased $280
million (0.7%) in 2023 compared to 2022. Reductions in advertising expenditures in 2022 and 2023 contributed to reductions
of policies-in-force.


Losses and loss adjustment expenses decreased $4.5 billion (12.4%) in 2023. GEICO’s loss ratio declined 12.1
percentage points compared to 2022, reflecting the impact of higher average premiums per auto policy, lower property damage
and collision claims frequencies and increased favorable development of prior accident years’ claims estimates, partially offset
by increases in average claims severities across all significant coverages. Average claim severities increased for property
damage (fourteen to sixteen percent range), collision (four to six percent range) and bodily injury (five to seven percent range).
Losses and loss adjustment expenses included reductions in the ultimate loss estimates for prior accident years’ claims of $1.5
billion in 2023 and $653 million in 2022.


Underwriting expenses decreased $752 million (16.5%) in 2023 compared to 2022. The expense ratio in 2023 was 9.7%,
a decrease of 2.0 percentage points compared to 2022, attributable to reduced advertising expenses and improved operating
leverage.


_Berkshire Hathaway Primary Group_


BH Primary consists of several independently managed businesses that provide a variety of primarily commercial
insurance solutions, including healthcare professional liability, workers’ compensation, automobile, general liability, property
and specialty coverages for small, medium and large clients. BH Primary’s insurers include Berkshire Hathaway Specialty
Insurance (“BHSI”), RSUI Group Inc. and CapSpecialty, Inc. (“RSUI and CapSpecialty,” acquired in October 2022), Berkshire
Hathaway Homestate companies (“BHHC”), MedPro Group, GUARD Insurance group of companies (“GUARD”), National
Indemnity Company (“NICO Primary”), Berkshire Hathaway Direct (“BH Direct”) and U.S. Liability Insurance companies
(“USLI”).


A summary of BH Primary’s underwriting results follows (dollars in millions).


2024 versus 2023


Premiums written increased $694 million (3.8%) in 2024 compared to 2023, primarily due to increases at NICO Primary,
BH Direct and BHHC, partially offset by a 16.3% reduction at GUARD. The increases at NICO Primary and BHHC were
primarily attributable to commercial auto coverage, while the increase at BH Direct reflected growth across several product
lines. The decline at GUARD resulted from management’s decision to exit admitted homeowners’ insurance and to tighten
underwriting guidelines in other lines of business.


Losses and loss adjustment expenses increased $1.4 billion (12.8%) and the loss ratio increased 2.1 percentage points in
2024 compared to 2023. Losses incurred included reductions of estimated ultimate losses for prior accident years’ claims of
$52 million in 2024 and $537 million in 2023. The comparative decline reflected a significant increase in loss estimates at
GUARD and lower reductions in estimated losses across several of our other businesses that write medical professional liability
and commercial liability coverages, partially offset by increased reductions of property loss estimates. During 2024, due to
deteriorating loss experience, management at GUARD performed a comprehensive review of claims and significantly increased
estimated ultimate claim liabilities. The reduction of favorable development of prior years’ liability claims estimates across our
other businesses was attributable to unfavorable social inflation trends, including the impacts of jury awards and litigation
costs. Losses incurred from significant catastrophe events were approximately $350 million in 2024 and were minimal in 2023.


K-36


---

**Management’s Discussion and Analysis**


_**Insurance—Underwriting**_


_Berkshire Hathaway Primary Group_


Underwriting expenses increased $681 million (15.0%) and the expense ratio increased 1.3 percentage points to 27.8%
in 2024 compared to 2023. The increase in the expense ratio was primarily attributable to BH Specialty from changes in
business mix and GUARD due to increased expenses and lower premiums earned.


2023 versus 2022


Premiums written increased $3.5 billion (24.1%) in 2023 compared to 2022. The increase was primarily due to the
acquisition of RSUI and CapSpecialty ($2.1 billion), as well as comparative increases from BHSI and BH Direct, and, to a
lesser extent, the other businesses. Losses and loss adjustment expenses increased $1.3 billion (13.5%) in 2023 compared to
2022, attributable to the acquisition of RSUI and CapSpecialty and changes in business mix, partially offset by a decline in
significant catastrophe losses of approximately $600 million. Net reductions in estimated ultimate liabilities for prior years’
loss events were $537 million in 2023 and $428 million in 2022.


Underwriting expenses increased $1.1 billion (30.8%) in 2023 compared to 2022. The increase was primarily attributable
to the increases in premiums earned and changes in business mix, including the full year effects in 2023 of the acquisition of
RSUI and CapSpecialty.


_Berkshire Hathaway Reinsurance Group_


The Berkshire Hathaway Reinsurance Group offers excess-of-loss and quota-share reinsurance coverages on property
and casualty risks to insurers and reinsurers worldwide through several subsidiaries, led by National Indemnity Company
(“NICO”), General Reinsurance Corporation, General Reinsurance AG and Transatlantic Reinsurance Company (“TransRe
Group,” acquired in October 2022). We also write life and health reinsurance coverages through General Re Life Corporation,
General Reinsurance AG and Berkshire Hathaway Life Insurance Company of Nebraska (“BHLN”). A summary of BHRG’s
pre-tax underwriting results follows (in millions).


_Property/casualty_


A summary of property/casualty reinsurance underwriting results follows (dollars in millions).


2024 versus 2023


Premiums written in 2024 declined $461 million (2.1%) versus 2023, attributable to lower overall property volumes,
partly offset by generally higher rates, new business and increased participations in certain casualty lines. Premiums earned in
2024 increased 1.4% compared to 2023.


K-37


---

**Management’s Discussion and Analysis**


_**Insurance—Underwriting**_


_Berkshire Hathaway Reinsurance Group_


Losses and loss adjustment expenses decreased $420 million (3.3%) and the loss ratio decreased 2.6 percentage points
in 2024 compared to 2023. Losses incurred from significant catastrophe events were approximately $800 million in 2024 and
$900 million in 2023. Estimated ultimate liabilities for losses occurring in prior accident years were reduced $1.7 billion in
2024 and $1.4 billion in 2023, mostly attributable to lower-than-expected property losses.


Underwriting expenses increased $429 million (7.4%) and the expense ratio increased 1.5 percentage points in 2024
compared to 2023. In 2024, NICO recorded a pre-tax charge in underwriting expenses of $490 million in connection with a
settlement agreement reached concerning certain non-insurance affiliates that filed voluntary petitions under Chapter 11 of the
bankruptcy code in the United States Bankruptcy Court for the District of New Jersey in 2023. See Note 27 to the accompanying
Consolidated Financial Statements. Underwriting expenses also included pre-tax foreign currency exchange gains from the
remeasurement of certain non-U.S. Dollar denominated liabilities of $121 million in 2024 and losses of $189 million in 2023.
Before these items, underwriting expenses increased $249 million (4.5%) in 2024 compared to 2023.


2023 versus 2022


Premiums written in 2023 increased 31.8% over 2022, reflecting the impact of the TransRe Group acquisition ($4.3
billion), net increases in new property business and higher rates. Losses and loss adjustment expenses increased $2.1 billion in
2023 versus 2022. The increase in 2023 reflected the TransRe Group acquisition ($2.6 billion), as well as a comparative
reduction in losses from significant catastrophe events of $1.1 billion. Estimated ultimate liabilities for prior accident years
were reduced $1.4 billion in 2023 and $1.6 billion in 2022.


Underwriting expenses increased $2.5 billion in 2023 versus 2022, reflecting the impact of the TransRe Group
acquisition. The expense ratio increased 6.0 percentage points compared to 2022. Underwriting expenses also included pre-tax
foreign currency exchange losses of $189 million in 2023 compared to gains of $371 million in 2022.


_Life/health_


A summary of our life/health reinsurance underwriting results follows (dollars in millions).


Premiums earned in 2024 declined $74 million compared to 2023, which included a reduction of $161 million attributable
to the commutations of several U.S. life contracts in the first quarter of 2023. Otherwise, premiums earned declined $235
million (4.5%) in 2024 compared to 2023, primarily attributable to reductions in non-U.S. life business, and were substantially
unchanged in 2023 versus 2022.


Pre-tax underwriting earnings decreased $131 million in 2024 compared to 2023, which increased $245 million over
2022. Earnings included gains from life contract commutations of $53 million in 2024 and $134 million in 2023. Otherwise,
underwriting earnings in 2024 decreased $50 million compared to 2023, reflecting decreased earnings from non-U.S. life
business and increased losses from the U.S. long-term care business in run-off, partly offset by increased earnings from U.S.
life business.


_Retroactive reinsurance_


Pre-tax underwriting results from retroactive reinsurance derive from changes in the ultimate claim liability estimates
and changes in the related deferred charge assets, as well as from foreign currency exchange gains and losses attributable to
non-U.S. Dollar denominated contracts. Changes in foreign currency exchange rates produced pre-tax gains of $52 million in
2024, losses of $57 million in 2023 and gains of $168 million in 2022. Pre-tax underwriting losses before foreign currency
exchange gains and losses were $898 million in 2024, $1.5 billion in 2023 and $836 million in 2022.


K-38


---

**Management’s Discussion and Analysis**


_**Insurance—Underwriting**_


_Berkshire Hathaway Reinsurance Group_


Estimated ultimate claim liabilities for prior years’ contracts increased $196 million in 2024, $1.1 billion in 2023 and
$86 million in 2022. The increase in 2023 was derived from higher estimates for asbestos, environmental and other casualty
claims, which net of changes in deferred charges, produced a pre-tax loss of $650 million in 2023. The net effects of the
increases in ultimate claim liabilities in 2024 and 2022 were relatively insignificant.


Unpaid losses and loss adjustment expenses for retroactive reinsurance contracts declined $2.2 billion in 2024 to $32.4
billion on December 31, 2024, primarily due to loss payments. Deferred charge assets on retroactive reinsurance contracts
declined $698 million in 2024 to $8.8 billion at December 31, 2024. Deferred charge balances will be charged to earnings over
the expected remaining claims settlement periods.


_Periodic payment annuity_


Periodic payment annuity business is price and demand sensitive and the supply of available business is affected by the
timing of underlying legal claim settlements. In 2023 and 2024, premium rates for new business were at unacceptable levels
and we wrote no new business in either year.


Pre-tax underwriting losses from periodic payment annuity contracts in each period included the accretion of discounted
liabilities, including liabilities for contracts without life contingencies, and foreign currency exchange gains and losses on nonU.S. Dollar denominated contracts. Changes in foreign currency exchange rates were insignificant in 2024 and produced pretax losses of $60 million in 2023 and pre-tax gains of $71 million in 2022. Pre-tax underwriting losses before foreign currency
effects were $596 million in 2024, $590 million in 2023 and $694 million in 2022. Pre-tax losses included a loss of
approximately $130 million in 2022 from the settlement of a terminated reinsurance contract. Periodic payment annuity
liabilities were $14.3 billion at December 31, 2024, including liabilities of $4.0 billion for contracts without life contingencies,
and excluding the effects of discount rate changes recorded in accumulated other comprehensive income.


_Variable annuity_


Our variable annuity guarantee reinsurance contracts produced pre-tax earnings of $157 million in 2024, $233 million in
2023 and $467 million in 2022. Earnings are affected by changes in securities markets, interest rates and foreign currency
exchange rates. These contracts have been in run-off for many years.


_**Insurance—Investment Income**_


A summary of net investment income attributable to our insurance operations follows (dollars in millions).


——————

_* Not meaningful._


Interest and other investment income increased $5.5 billion in 2024 compared to 2023, which increased $4.4 billion
compared to 2022. The increase in 2024 was primarily attributable to increases in U.S. Treasury Bill and short-term investment
balances. The increase in 2023 over 2022 was due to increased short-term investment balances and higher interest rates, as well
as the impact of income earned from Alleghany’s insurance subsidiary assets acquired in October 2022. We continue to believe
that maintaining ample liquidity is paramount and we insist on safety over yield with respect to short-term investments.


K-39


---

**Management’s Discussion and Analysis**


_**Insurance—Investment Income**_


Dividend income declined $302 million (5.5%) in 2024 compared to 2023, which declined $539 million (8.9%) compared
to 2022. The decreases reflected the impact of net reductions in our equity security holdings, partially offset by higher dividend
rates on certain of our holdings. Dividend income varies from period to period due to changes in the investment portfolio and
the frequency and timing of dividends from certain investees.


Invested assets of our insurance businesses derive from shareholder capital and net liabilities assumed under insurance
contracts or “float.” The major components of float are unpaid losses and loss adjustment expenses, including liabilities under
retroactive reinsurance contracts, life, annuity and health benefit liabilities, unearned premiums and certain other liabilities,
which are reduced by insurance premiums receivable, reinsurance receivables, deferred charges assumed under retroactive
reinsurance contracts and deferred policy acquisition costs. The effect of discount rate changes on long-duration insurance
contracts, recorded in accumulated other comprehensive income, are excluded from float, as such amounts are not included in
earnings in the Consolidated Statements of Earnings.


Float was approximately $171 billion at December 31, 2024, $169 billion at December 31, 2023 and $164 billion at
December 31, 2022. The cost of float is measured as the ratio of pre-tax underwriting earnings to float balances. Our combined
insurance operations generated pre-tax underwriting gains in 2024 and 2023, and the average cost of float was negative in each
year. The cost of float in 2022 was nominal.


A summary of cash and investments held in our insurance businesses as of December 31, 2024 and 2023 follows (in
millions).


Fixed maturity investments as of December 31, 2024 were as follows (in millions).


U.S. government obligations are rated AA+ or Aaa by the major rating agencies. Approximately 94% of our foreign
government obligations were rated AA or higher by at least one of the major rating agencies. Foreign government securities
include obligations issued or unconditionally guaranteed by national or provincial government entities.


K-40


---

**Management’s Discussion and Analysis**


_**Burlington Northern Santa Fe**_


Burlington Northern Santa Fe, LLC (“BNSF”) operates one of the largest railroad systems in North America, with over
32,500 route miles of track in 28 states. BNSF also operates in three Canadian provinces. BNSF classifies its major business
groups by type of product shipped, including consumer products, industrial products, agricultural products and coal. A summary
of BNSF’s earnings follows (dollars in millions).


A summary of BNSF’s railroad freight volumes by business group follows (cars/units in thousands).


2024 versus 2023


Railroad operating revenues declined 0.5% in 2024 compared to 2023, reflecting lower average revenue per car/unit of
6.6%, primarily attributable to lower fuel surcharge revenue and business mix changes, partially offset by a net volume increase
of 6.5%. Pre-tax earnings were $6.6 billion in 2024, a slight increase from 2023. Railroad operating earnings in 2024 increased
due to volume growth and lower operating costs from improved productivity, partially offset by a $290 million charge related
to a labor agreement that was finalized in the fourth quarter of 2024 and by increased litigation accruals.


Operating revenues from consumer products increased 7.1% in 2024 to $8.4 billion compared to 2023, reflecting a
volume increase of 16.2% and lower average revenue per car/unit. The volume increase was primarily due to higher intermodal
shipments from west coast imports and volumes from a new intermodal customer.


Operating revenues from industrial products declined 1.2% in 2024 to $5.6 billion from 2023, reflecting slight declines
in volume and average revenue per car/unit. The volume decline was primarily due to lower aggregates, taconite, minerals and
waste shipments, substantially offset by higher plastics and petroleum products volumes.


K-41


---

**Management’s Discussion and Analysis**


_**Burlington Northern Santa Fe**_


Operating revenues from agricultural products increased 4.5% to $5.8 billion in 2024 compared to 2023, attributable to
a volume increase of 7.4%, partially offset by lower average revenue per car/unit. The volume increase was primarily due to
higher grain, renewable fuels and fertilizer shipments.


Operating revenues from coal decreased 22.5% to $2.9 billion in 2024 compared to 2023. The decrease was attributable
to a volume decrease of 17.9% and lower average revenue per car/unit. The volume decline was primarily due to lower natural
gas prices.


Railroad operating expenses were $15.9 billion in 2024, a decrease of $173 million (1.1%) compared to 2023. The ratio
of railroad operating expenses to railroad operating revenues declined 0.4 percentage points to 68.0% in 2024 versus 2023.
Railroad compensation and benefits expenses increased $356 million (6.5%) in 2024 compared to 2023, primarily due to a
$290 million charge related to a one-time payment included in the agreement with the SMART-TD labor union that was
finalized in December 2024. This agreement allows BNSF the ability to redeploy brakepersons to conductors and engineers,
which will allow BNSF to meet short-term hiring demands. Fuel expenses declined $417 million (11.3%) compared to 2023,
primarily due to lower average fuel prices, partially offset by higher volumes. Railroad purchased services, equipment rents,
materials and other expenses declined $126 million (3.0%), primarily due to cost reductions across numerous spend categories
and lower property taxes, partially offset by a litigation charge in 2024 related to a judgment in an ongoing legal case with the
Swinomish Tribe, which BNSF has appealed.


2023 versus 2022


Railroad operating revenues declined 6.9% in 2023 compared to 2022, reflecting lower overall volumes (5.7%) and
average revenue per car/unit (0.6%), which was primarily attributable to lower fuel surcharge revenue, partially offset by
favorable price and mix. Pre-tax earnings were $6.6 billion in 2023, a decline of 14.2% from 2022, reflecting lower volumes
and higher non-fuel operating costs, partially offset by lower fuel costs.


Operating revenues from consumer products declined 14.7% in 2023 to $7.9 billion compared to 2022, reflecting a
volume decrease of 8.4% and lower average revenue per car/unit. The volume decrease was primarily due to lower intermodal
shipments resulting from reduced West Coast imports, the loss of an intermodal customer and competition from lower spot
rates in the domestic trucking market, which negatively impacted demand. These declines were partially offset by an increase
in automotive volume.


Operating revenues from industrial products were $5.7 billion in 2023, an increase of 1.8% from 2022, reflecting higher
average revenue per car/unit, partially offset by a volume decrease of 0.8%. The volume decline was primarily due to lower
demand for chemicals, plastics, minerals, paper and lumber, partially offset by increased shipments of steel and aggregates.


Operating revenues from agricultural products decreased 2.8% to $5.6 billion in 2023 compared to 2022, attributable to
a volume decrease of 2.9%, partially offset by slightly higher average revenue per car/unit. The volume decrease was primarily
due to lower grain exports, partially offset by higher volumes of domestic grains and feedstocks and renewable diesel.


Operating revenues from coal declined 3.4% to $3.8 billion in 2023 compared to 2022. The revenue decrease was
attributable to a volume decrease of 4.0%, partially offset by higher average revenue per car/unit. The volume decline reflected
moderating demand attributable to lower natural gas prices.


Railroad operating expenses were $16.1 billion in 2023, a decline of $541 million (3.3%) compared to 2022. The ratio
of railroad operating expenses to railroad operating revenues increased 2.5 percentage points to 68.4% in 2023 versus 2022.
Fuel expenses declined $897 million (19.6%) compared to 2022, reflecting lower average fuel prices, lower volumes and
improved efficiency. Railroad compensation and benefits expenses increased $247 million (4.7%) in 2023 compared to 2022,
primarily due to higher headcount and wage inflation. Other revenues (expenses), net increased 90% compared to 2022,
primarily due to an increase in interest income driven by higher interest rates.


K-42


---

**Management’s Discussion and Analysis**


_**Berkshire Hathaway Energy**_


Berkshire Hathaway Energy Company (“BHE”) is a holding company with subsidiaries that primarily operate within the
energy industry. BHE’s domestic regulated utility interests include PacifiCorp, MidAmerican Energy Company (“MEC”) and
NV Energy. BHE’s natural gas pipelines consist of five domestic regulated interstate natural gas pipeline systems and a 75%
interest in a liquefied natural gas export, import and storage facility (“Cove Point”). Other energy subsidiaries operate two
regulated electricity distribution businesses in Great Britain (“Northern Powergrid”), a regulated electricity transmission-only
business in Alberta, Canada, and a diversified portfolio of mostly renewable independent power projects and investments.
Another BHE subsidiary, HomeServices of America, Inc. (“HomeServices”), operates a residential real estate brokerage
business and a large network of real estate brokerage franchises in the United States.


The rates BHE’s regulated businesses charge customers for energy and services are largely based on the costs of business
operations, including income taxes and a return on capital, and are subject to regulatory approval. To the extent such costs are
not allowed in the approved rates, operating results will be adversely affected. A summary of BHE’s net earnings follows
(dollars in millions).


——————

_* Includes significant production tax credits primarily from wind-powered electricity generation._


The discussion of BHE’s operating results that follows is based on after-tax earnings, reflecting how the energy
businesses are managed and evaluated. A summary of net earnings attributable to BHE (“net earnings”) follows (dollars in
millions).


——————
_** Not meaningful._


K-43


---

**Management’s Discussion and Analysis**


_**Berkshire Hathaway Energy**_


2024 versus 2023


Our U.S. utilities operate independently in several states, including Utah, Oregon, Wyoming and other Western states
(PacifiCorp), Iowa and Illinois (MEC) and Nevada (NV Energy). Net earnings increased $1.1 billion (116.4%) in 2024
compared to 2023. Pre-tax loss accruals, net of expected insurance recoveries, for the Wildfires were $346 million in 2024 and
$1.7 billion in 2023. See Note 27 to the accompanying Consolidated Financial Statements for additional information on the
Wildfires.


Additionally, net earnings of U.S. utilities in 2024 reflected comparative increases in electric utility margin (operating
revenue less cost of sales), income tax benefits from recognized wind production tax credits ($157 million) and other income,
partially offset by increases in other energy operating expenses and interest expense.


The U.S. utilities’ electric utility margin was $7.8 billion in 2024, an increase of $274 million (3.6%) compared to 2023.
The increase reflected higher retail customer rates in certain territories and higher retail customer volumes, partially offset by
higher energy costs and lower wholesale volumes and prices. Retail customer volumes increased 3.6% overall (up 6.5% at NV
Energy, 3.1% at PacifiCorp and 1.2% at MEC) in 2024 compared to 2023, primarily due to increases in customer usage and
the average number of customers, partially offset by an overall unfavorable impact of weather. The increase in other energy
operating expenses was primarily due to higher vegetation management and other wildfire mitigation costs, insurance expenses
and general and plant maintenance costs. Interest expense increased $314 million in 2024 over 2023, largely due to increased
borrowings, including $4.4 billion of subsidiary term debt issued in January 2024 with a weighted average interest rate of 5.5%.


Net earnings of natural gas pipelines increased $153 million in 2024 compared to 2023. The increase in earnings reflected
reductions in earnings attributable to noncontrolling interests, partially offset by the impact of a higher effective income tax
rate, due to the acquisition of an additional 50% limited partner interest in Cove Point on September 1, 2023. Pre-tax earnings
of the natural gas pipelines in 2024 were unchanged from 2023.


Net earnings of other energy businesses increased $310 million in 2024 compared to 2023. The increase was primarily
due to higher earnings at Northern Powergrid, partially offset by lower earnings from the renewable energy business. The
increase at Northern Powergrid was attributable to higher distribution revenue due to higher tariffs from inflation adjustments
and lower income tax expense attributable to charges recognized in 2023 for the U.K. Energy Profits Levy and a group relief
tax benefit recognized in 2024, partially offset by unfavorable results from the upstream gas exploration and production
business and higher operating expenses. Earnings from the renewable energy business decreased mainly due to lower earnings
from wind tax equity investments in 2024 and debt extinguishment gains recognized in 2023.


Net earnings of real estate brokerage decreased $120 million 2024 compared to 2023, primarily attributable to charges
in connection with the ongoing real estate industry litigation matters. In April 2024, HomeServices agreed to terms with the
plaintiffs to settle all claims asserted against HomeServices and certain of its subsidiaries and effectuate a nationwide class
settlement. See Note 27 to the accompanying Consolidated Financial Statements for additional information. The real estate
brokerage business continues to be negatively impacted by the availability of homes for sale and high home prices.


Corporate interest and other after-tax earnings include BHE corporate interest expense and unallocated corporate and
income tax expenses. Noncontrolling interests and preferred stock dividends include earnings attributable to non-Berkshire
owners of BHE common stock and dividends on preferred stock held by other Berkshire subsidiaries. All remaining
noncontrolling interests in BHE common stock were acquired in 2024 and the preferred stock is expected to be redeemed in
2025.


2023 versus 2022


Net earnings of the U.S. utilities declined $1.4 billion in 2023 compared to 2022. The decline reflected an increase in
energy operating expenses, including an increase in pre-tax loss accruals, net of expected insurance recoveries, of $1.6 billion
for the Wildfires. The decline in earnings also reflected higher interest expense and lower electric utility margin. These items
were partially offset by increases in other income and lower depreciation and amortization expense.


The U.S. utilities’ electric utility margin was $7.5 billion in 2023, a decrease of $170 million (2.2%) versus 2022. The
decline reflected lower volumes and wholesale rates, as well as increased energy costs, partially offset by an increase in retail
customer rates in certain territories. Retail customer volumes decreased 0.8% overall (down 0.8% at PacifiCorp and 2.6% at
NV Energy and up 1.3% at MEC) in 2023 compared to 2022, primarily due to an overall unfavorable impact of weather,
partially offset by increases in customer usage and the average number of customers.


K-44


---

**Management’s Discussion and Analysis**


_**Berkshire Hathaway Energy**_


Net earnings of natural gas pipelines increased $39 million in 2023 compared to 2022. The increase reflected higher
regulated transportation and storage services revenues from certain general rate cases and decreased earnings attributable to
noncontrolling interests in Cove Point, partially offset by higher operating expenses.


Net earnings of other energy businesses decreased $332 million in 2023 compared to 2022. The decline reflected lower
earnings at Northern Powergrid due to unfavorable results from the upstream gas exploration and production business,
including the write-off of capitalized exploration costs and lower gas production volumes and prices, as well as from higher
deferred income tax expense related to the enactment of the U.K. Energy Profits Levy. The earnings decline was also
attributable to lower earnings from the renewable energy businesses, primarily due to lower income tax benefits, higher
operating expenses and lower solar and wind generation from owned projects, partially offset by debt extinguishment gains in
2023.


Net earnings of real estate brokerage decreased $87 million in 2023 compared to 2022. The decrease reflected lower
brokerage services revenues and margins, primarily due to a 19% reduction in closed brokerage transaction volumes, as well
as lower mortgage services revenues and margins from a 28% decrease in closed transaction volumes.


_**Manufacturing, Service and Retailing**_


A summary of revenues and earnings of our manufacturing, service and retailing businesses follows (dollars in millions).


——————

_* Excludes certain acquisition accounting expenses, which primarily relates to the amortization of intangible assets recorded_
_in connection with certain of our business acquisitions. The after-tax acquisition accounting expenses excluded from earnings_
_were_ _$531_ _million_ _in_ _2024,_ _$693_ _million_ _in_ _2023_ _and_ _$681_ _million_ _in_ _2022._ _These_ _expenses_ _are_ _included_ _in_ _“Other”_ _in_ _the_
_summary of earnings on page K-33 and in the “Other” earnings table on page K-54._


K-45


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


_Manufacturing_


Our manufacturing group includes a variety of industrial, building and consumer products businesses. A summary of
revenues and pre-tax earnings of our manufacturing operations follows (dollars in millions).


_Industrial products_


The industrial products group includes metal products for aerospace, power and general industrial markets (Precision
Castparts Corp. (“PCC”)), specialty chemicals (The Lubrizol Corporation (“Lubrizol”)), metal cutting tools/systems (IMC
International Metalworking Companies (“IMC”)), and Marmon, which consists of more than 100 autonomous manufacturing
and service businesses, internally aggregated into eleven groups, and includes equipment leasing for the rail, intermodal tank
container and mobile crane industries. Marmon also includes the Scott Fetzer group businesses. The industrial products group
also includes equipment and systems for the livestock and agricultural industries (CTB International), a leader in drag reducing
agents for pipelines (LiquidPower Specialty Products) and a structural steel fabrication products business (W&W|AFCO).


2024 versus 2023


Revenues of the industrial products group in 2024 increased $949 million (2.7%) and pre-tax earnings increased $331
million (5.8%) compared to 2023. Pre-tax earnings as a percentage of revenues in 2024 were 16.8%, an increase of 0.5
percentage points compared to 2023.


PCC’s revenues were $10.4 billion in 2024, an increase of 12.0% compared to 2023. The revenue increase was primarily
attributable to higher demand for aerospace products, and to a lesser degree, power generation products. Long-term industry
forecasts continue to show growth and considerable demand for air travel and aerospace products. PCC’s pre-tax earnings
increased 24.4% in 2024 compared to 2023, primarily attributable to sales increases and improved manufacturing and operating
efficiencies. Continued growth in revenues and earnings will be predicated on PCC’s ability to successfully increase production
levels to match the expected growth in aerospace products, as well as from improvements in industry supply chains and labor
relations, which have been constraining commercial aircraft production at original equipment manufacturers.


Lubrizol’s revenues were $6.4 billion in 2024, relatively unchanged compared to 2023, as higher volumes were
essentially offset by lower selling prices and unfavorable product mix. Sales volumes in 2024 increased 4% compared to 2023,
reflecting higher volumes in both the additives and advanced materials businesses. Lubrizol’s pre-tax earnings increased 30.7%
in 2024, primarily attributable to lower raw material costs, higher sales volumes and lower manufacturing costs, partially offset
by the impact of lower selling prices and higher selling, general and administrative expenses.


K-46


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


Marmon’s revenues were $12.2 billion in 2024, a decline of 1.7% compared to 2023. The largest revenue declines were
experienced by the Transportation Products group (18.2%), attributable to volume declines in the truck, trailer, and aftermarket
automotive markets, as well as the Metal Services group (13.9%) and Retail Solutions group (9.4%), primarily due to reduced
volume and changes in sales mix. Conversely, Electrical group revenues increased 6.0% due to higher copper prices and
increased volumes. The Rail & Leasing group revenues increased 10.5% due to higher average lease renewal rates and increased
railcar repair prices and volumes.


Marmon’s pre-tax earnings declined 8.7% in 2024 compared to 2023, reflecting lower earnings from the Transportation
Products, Metals Services and Retail Solutions groups due to the revenue declines, as well as lower earnings from the Crane
Services group, attributable to lower revenues and higher costs, and the Electrical group, reflecting higher materials costs and
unfavorable business mix changes. These declines were partially offset by higher earnings in the Rail & Leasing, Medical,
Water Technologies and Foodservice Technologies groups.


IMC’s revenues were approximately $3.9 billion in 2024, a decrease of 2.2% compared to 2023. The decline reflected
lower organic sales attributable to sluggish customer demand across all major regions, and unfavorable foreign currency
translation from a stronger U.S. Dollar, partially offset by the impact of business acquisitions and higher investment income.
The decline in organic sales was attributable to weaker general economic conditions and ongoing geopolitical conflicts. IMC’s
pre-tax earnings declined 7.8% in 2024 compared to 2023, primarily attributable to lower sales and gross margin rates and
increased selling, general and administrative expenses, partially offset by higher investment and other income. IMC operates
globally and a large portion of its products are manufactured in Israel. IMC’s operations in Israel have not been significantly
impacted by the conflicts in the region.


2023 versus 2022


Revenues of the industrial products group in 2023 increased $4.1 billion (13.2%) and pre-tax earnings increased $824
million (16.9%) compared to 2022. Pre-tax earnings as a percentage of revenues in 2023 increased 0.5 percentage points to
16.3%.


PCC’s revenues were $9.3 billion in 2023, an increase of $1.7 billion (22.7%) compared to 2022. The revenue increase
in 2023 was primarily attributable to higher demand for aerospace products, and, to a lesser degree, power generation products.
PCC’s pre-tax earnings were $1.5 billion in 2023, an increase of 30.0% compared to 2022 attributable to increases in sales and
manufacturing and operating efficiencies in aerospace businesses, partially offset by operating losses in energy products
businesses.


Lubrizol’s revenues were $6.4 billion in 2023, a decline of 4.0% compared to 2022. The revenue decline was primarily
due to a 7.9% decline in volumes and unfavorable foreign currency effects, partially offset by higher selling prices. Lubrizol’s
pre-tax earnings in 2023 were relatively unchanged compared to 2022. Earnings included insurance recoveries of $11 million
in 2023 and $242 million in 2022 in connection with fires at the Rockton, Illinois facility in 2021 and the Rouen, France facility
in 2019. Excluding insurance recoveries, earnings in 2023 increased due to the favorable impacts of higher selling prices,
favorable changes in product mix and lower raw material costs, partially offset by the impact of lower sales volumes,
unfavorable foreign currency translation effects and higher operating expenses.


Marmon’s revenues were $12.5 billion in 2023, an increase of $1.2 billion (11.0%) compared to 2022. Business
acquisitions represented substantially all of the comparative revenue increase. In addition, the Rail & Leasing, Water
Technologies, Medical, Metal Services and Crane Services groups generated higher revenues, primarily due to higher volumes
and pricing improvements. Revenues in 2023 of the Electrical group’s building wire business and the Metal Services and
Plumbing & Refrigeration groups were negatively impacted by lower metals prices, while revenues of the Transportation
Products group reflected declining demand, particularly in the second half of the year.


Marmon’s pre-tax earnings increased 13.1% in 2023 compared to 2022. The earnings increase in 2023 reflected the
impacts from business acquisitions ($90 million) and losses of $90 million in 2022 from the shutdown of the Rail & Leasing
group business in Russia. The Rail & Leasing, Water Technologies and Plumbing & Refrigeration groups generated higher
organic earnings in 2023, which were offset by lower earnings from the Electrical group’s building wire business and from the
Metals Services and Medical groups.


K-47


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


IMC’s revenues increased 8.0% to $4.0 billion in 2023 compared to 2022. The increase reflected the impact of business
acquisitions, organic sales growth in North America and other regions and higher interest income due to higher interest rates,
partially offset by lower revenues in the Asia-Pacific region, unfavorable foreign currency translation from a stronger U.S.
Dollar and the impact of ongoing geopolitical conflicts. IMC’s pre-tax earnings increased 6.9% in 2023 compared to 2022,
primarily attributable to higher interest income. The impact of the revenue increase was largely offset by higher raw material
costs, changes in sales mix and the adverse effects of geopolitical conflicts.


_Building products_


The building products group includes manufactured and site-built home construction and related lending and financial
services (Clayton Homes), flooring (Shaw), insulation, roofing and engineered products (Johns Manville), bricks and masonry
products (Acme Building Brands), paint and coatings (Benjamin Moore) and residential and commercial construction and
engineering products and systems (MiTek).


2024 versus 2023


Revenues of the building products group increased $560 million (2.2%) in 2024 compared to 2023. Pre-tax earnings
decreased $53 million (1.3%) in 2024 compared to 2023.


Clayton Homes’ revenues increased 8.5% in 2024 to $12.4 billion compared to 2023. Revenues from home sales
increased $565 million (6.4%) in 2024, reflecting higher new home unit sales of 11.5%, partially offset by changes in sales mix
and lower average selling prices. Also, financial services revenues increased 15.5% in 2024 compared to 2023, primarily due
to increased interest income from higher average loan balances. Loan balances, net of allowances for credit losses, were
approximately $27.2 billion as of December 31, 2024, an increase of 14.0% since December 31, 2023. Loan portfolio balances
are largely funded by borrowings from Berkshire finance affiliates.


Clayton Homes’ pre-tax earnings declined $115 million (5.6%) in 2024 compared to 2023, attributable to lower earnings
from financial services (4.4%) and manufacturing activities (9.4%). The decline in financial services earnings reflected
increased losses from homeowner property insurance claims, increased expected loan loss provisions due to higher loan
originations, higher interest expense on borrowings from Berkshire finance affiliates. Interest expense increased $203 million
(38%) in 2024 versus 2023, as borrowings from affiliates increased $6.6 billion in 2024 to $24.3 billion at December 31, 2024.
The corresponding interest income on such borrowings is included in the “Other” earnings section on page K-54. The decline
in manufacturing earnings was largely attributable to lower gross margin rates due to the increased cost of building homes to
the Department of Energy’s Zero Energy Ready Home Program requirements (such incremental costs are partially offset by
income tax credits).


Our other building products businesses generated revenues of approximately $14.1 billion in 2024, a decline of $413
million (2.8%) versus 2023. Sales volumes in 2024 increased at Johns Manville and declined at the other businesses in the
group, while average selling prices were lower at Johns Manville and MiTek and slightly higher at our other businesses.


Pre-tax earnings of our other building products businesses increased $61 million (2.9%) in 2024 compared to 2023.
Earnings as a percentage of revenues increased 0.9 percentage points in 2024 to 15.6% compared to 2023. Earnings increased
in 2024 from higher average gross margin rates arising from lower raw material costs and improved manufacturing efficiencies
at certain of the businesses, partially offset by higher selling, general and administrative expenses and the impact of lower sales.
Selling, general and administrative expenses in each year included losses from business restructuring activities and divestitures,
as well as legal settlements and accruals.


2023 versus 2022


Revenues of the building products group decreased $2.9 billion (10.1%) and pre-tax earnings decreased $602 million
(12.6%) in 2023 compared to 2022. The effects of significant increases in home mortgage interest rates in the U.S. slowed
demand for our home building businesses and our other building products businesses.


Clayton Homes’ revenues were approximately $11.4 billion in 2023, a decrease of $1.3 billion (10.3%) compared to
2022. Revenues from home sales decreased $1.6 billion (15.3%) in 2023 to approximately $8.8 billion, primarily due to lower
unit sales and changes in product mix. New home unit sales declined 13.7% in 2023, reflecting lower factory-built and sitebuilt homes. Financial services revenues increased 12.2% in 2023 compared to 2022, primarily due to increased interest income
on higher average loan balances.


K-48


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


Pre-tax earnings of Clayton Homes were approximately $2.0 billion in 2023, a decrease of $326 million (13.8%)
compared to 2022. Earnings in 2023 reflected lower earnings from the home building businesses, partially offset by increased
earnings from financial services. The decline in earnings from the home building businesses reflected the reduction in sales, a
lower overall gross sales margin rate and higher operating expenses relative to sales. The increase in earnings from financial
services was primarily attributable to increased net interest income, partially offset by increased expected loan loss provisions
and higher insurance claims.


Aggregate revenues of our other building products businesses were approximately $14.5 billion in 2023, a decrease of
10.0% versus 2022. The decline in revenues reflected overall lower sales volumes and changes in product mix, partly offset by
higher average selling prices. Pre-tax earnings of the other building products businesses were approximately $2.1 billion in
2023, a decrease of 11.4% compared to 2022. Pre-tax earnings as a percentage of revenues were 14.7% in 2023, a 0.3 percentage
point decrease compared to 2022. The earnings decline in 2023 was driven by lower sales volumes, reduced manufacturing
efficiencies and losses from restructurings, plant closures and divestitures in 2023, partially offset by lower raw material costs
and energy costs as well as reduced freight, shipping and utilities expenses.


_Consumer products_


The consumer products group includes leisure vehicles (Forest River), several apparel and footwear operations (including
Fruit of the Loom, Garan, H.H. Brown Shoe Group and Brooks Sports) and a manufacturer of high-performance alkaline
batteries (Duracell). This group also includes a global toy company (Jazwares), jewelry products (Richline) and custom picture
framing products (Larson-Juhl).


2024 versus 2023


Consumer products group revenues were $14.9 billion in 2024, an increase of 2.2% compared to 2023. The increase was
primarily attributable to higher revenues from Forest River, Brooks Sports and Duracell, partially offset by lower revenues
from Fruit of the Loom, Garan and Richline. Forest River revenues increased 6.4% in 2024, reflecting a 7.9% increase in unit
sales, which included the impact of business acquisitions in 2024 and 2023. Average selling prices for recreational vehicles
declined and increased for bus and commercial vehicles, primarily attributable to changes in product mix. Brooks Sports and
Duracell revenues increased 9.1% and 2.5%, respectively, in 2024 versus 2023. The revenue reductions at Fruit of the Loom
and Richline were attributable to lower sales volumes, whereas the decline at Garan was attributable to lower average selling
prices.


Consumer products group pre-tax earnings increased $172 million (10.9%) in 2024 versus 2023. The increase was
primarily attributable to higher earnings from our apparel and footwear businesses and Duracell, partially offset by lower
earnings from Jazwares. Apparel and footwear earnings increased 37.0% in 2024 from 2023, primarily due to gross sales margin
rate increases from lower sales markdowns, lower manufacturing costs and increased gains on asset sales, as well as from the
favorable effects of past restructuring and cost management efforts. The earnings increase at Duracell was attributable to
increased gross sales margins and lower selling, general and administrative expenses, including lower restructuring costs. The
decline in earnings from Jazwares in 2024 was primarily due to increased amortization expense, as well as reduced orders from
retailers during the fourth quarter.


2023 versus 2022


Consumer products group revenues declined $1.5 billion (9.4%) in 2023 versus 2022. The decline reflected lower
revenues at Forest River and our apparel and footwear operations, partially offset by the impact of the Jazwares acquisition,
which contributed revenues of $1.3 billion in 2023 and $240 million in 2022.


Forest River revenues declined 26.2% in 2023 compared to 2022, reflecting a 29.3% decline in unit sales and changes in
sales mix. Forest River experienced strong recreational vehicle unit sales through the first half of 2022. Through most of 2023,
sales of recreational vehicles declined significantly, attributable in part to the impact of rising interest rates, inflation and other
macroeconomic conditions. The decline in recreational vehicle sales was partially offset by increased sales of bus and
commercial vehicles.


Revenues of our apparel and footwear businesses declined $452 million (9.4%) in 2023 compared to 2022. The decline
was primarily due to reduced apparel revenues, attributable to lower unit volumes, partially offset by higher average selling
prices. Duracell’s revenues in 2023 were relatively flat versus 2022.


K-49


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


Pre-tax earnings of the consumer products group increased $46 million (3.0%) in 2023 compared to 2022. Pre-tax
earnings in 2023 reflected the impact of the Jazwares acquisition and higher earnings from the apparel and footwear businesses,
partially offset by lower earnings from Forest River and Duracell. Certain of our apparel and footwear businesses took actions
in 2023 to reduce inventories and right-size operations. The Forest River earnings decline in 2023 was primarily due to the
impact of lower sales volumes, while the decline at Duracell was primarily attributable to higher restructuring costs.


_Service and retailing_


A summary of revenues and pre-tax earnings of our service and retailing businesses follows (dollars in millions).


_Service_


Our service group consists of several businesses. The largest of these businesses are NetJets and FlightSafety (aviation
services), which offer shared ownership programs for general aviation aircraft and high technology training products and
services to operators of aircraft, and TTI, a distributor of electronics components. Our other service businesses franchise and
service a network of quick service restaurants (Dairy Queen), lease transportation equipment (XTRA) and furniture (CORT),
provide third party logistics services that primarily serve the petroleum and chemical industries (Charter Brokerage), distribute
electronic news, multimedia and regulatory filings (Business Wire), provide various facilities construction management
services (IPS-Integrated Project Services, LLC (IPS)) and operate a television station in Miami, Florida (WPLG). McLane,
which we view as a service business, is addressed separately since it is deemed a separate segment for financial reporting
purposes.


2024 versus 2023


Service group revenues were $20.7 billion in 2024, a slight increase compared to 2023, reflecting revenue increases from
aviation services businesses and IPS, partially offset by lower revenues from TTI and XTRA. Aviation services revenues
increased 9.1% in 2024, while IPS revenues increased 14.4%. The aviation services increase was primarily due to an increase
in the number of aircraft in shared aircraft ownership programs and increases in flight hours across NetJets’ various programs.
The increase at IPS was primarily due to increased project volume.


K-50


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


TTI revenues declined 10.0% in 2024 compared to 2023. Sales in 2024 declined across most regions, markets and product
lines, attributable to excess inventory levels within supply chains, which contributed to lower sales volumes and pricing
pressures. The decline at XTRA was due to fewer units on lease.


Service group pre-tax earnings declined 23.0% in 2024 compared to 2023, primarily attributable to TTI, the aviation
services businesses and XTRA. Pre-tax earnings as a percentage of revenues fell 3.4 percentage points in 2024 to 11.1%
compared to 2023. Earnings from TTI declined 51.0% in 2024 compared to 2023, reflecting the impact of lower sales and price
competition, which contributed to reduced gross sales margin rates, and higher selling, general and administrative expenses.
Earnings from aviation services declined 10.9% in 2024 versus 2023, primarily attributable to increased costs of services and
leasing, driven by higher flight crew, maintenance, fuel costs and depreciation expense, as well as increased impairment
charges. The decline at XTRA was primarily due to lower revenues and increased costs.


2023 versus 2022


Revenues of the service group increased $1.6 billion (8.3%) in 2023 compared to 2022. IPS produced revenues of $1.3
billion in 2023 and $358 million for the post-acquisition period in 2022. Revenues from aviation services increased 11.5% in
2023 compared to 2022, primarily due to increases in the number of aircraft in shared aircraft ownership programs and in flight
hours across NetJets’ various programs, as well as higher average rates.


Revenues from TTI declined 2.7% in 2023 compared to 2022. Excluding the effects of business acquisitions in 2022 and
2023 and favorable foreign currency translation effects, revenues declined 5.2% in 2023 versus 2022. Customer orders slowed
throughout 2023 in several regions, particularly in the Asia-Pacific region, attributable to elevated customer inventory levels
and increasing price competition.


Pre-tax earnings of the service group decreased $52 million (1.7%) in 2023 to $3.0 billion. Pre-tax earnings as a
percentage of revenues declined 1.5 percentage points in 2023 compared to 2022. The earnings decline reflected lower earnings
from TTI and certain of our other service businesses, partially offset by increased earnings from aviation services and the
impact of the IPS acquisition. Earnings from TTI declined 17.3% in 2023, attributable to reduced sales and gross margin rates
and higher operating expenses, partly offset by the impact of foreign currency exchange gains in 2023. The increase in earnings
from aviation services was primarily attributable to a 14.4% increase in average aircraft within NetJets’ programs and higher
rates.


_Retailing_


Our largest retailing business is Berkshire Hathaway Automotive, Inc. (“BHA”), which represented 69% of our retailing
group revenue in 2024. BHA consists of over 80 auto dealerships that sell new and pre-owned automobiles and offer repair
services and related products. BHA also offers and insures vehicle service contracts and related insurance products. Our
retailing businesses also include four home furnishings businesses (Nebraska Furniture Mart, R.C. Willey, Star Furniture and
Jordan’s), which sell furniture, appliances, flooring and electronics. The home furnishings group represented 17% of the
retailing group revenues in 2024.


Other retailing businesses include three jewelry businesses (Borsheims, Helzberg and Ben Bridge), See’s Candies
(confectionery products), Pampered Chef (high quality kitchen tools), Oriental Trading Company (party supplies, school
supplies and toys and novelties) and Detlev Louis Motorrad (“Louis”), a retailer of motorcycle accessories based in Germany.
Pilot, which is primarily a retail business, is addressed separately since it is deemed a segment for financial reporting purposes.


2024 versus 2023


Retailing group revenues declined 1.2% to $19.2 billion in 2024 compared to 2023. Except for BHA and Louis, each of
our other retailing businesses experienced revenue declines in 2024 compared to 2023. BHA vehicle sales revenues increased
0.5% in 2024 versus 2023. New vehicle unit sales increased 7.9% and pre-owned unit sales declined 2.0% in 2024 versus 2023.
Further, average vehicle selling prices were lower in 2024 versus 2023, attributable to increased inventory availability and
product mix changes. Revenues of the home furnishings businesses declined 6.4% in 2024 versus 2023, primarily attributable
to lower sales volumes and price competition. Also, combined revenues of our other retail businesses declined 5.8% in 2024
compared to 2023, attributable to increased competition and sluggish consumer demand.


K-51


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


Retailing group pre-tax earnings declined $331 million (19.2%) in 2024 compared to 2023. BHA’s pre-tax earnings
declined 7.9% in 2024 compared to 2023, primarily due to lower vehicle gross profit margins, partially offset by higher earnings
from finance/service contract and parts/service/repair operations, as well as lower selling, general and administrative expenses.
Aggregate pre-tax earnings for the remainder of our retailing group declined $242 million (40.2%) in 2024 compared to 2023.
Most of these other retailers generated significantly lower earnings in 2024 compared to 2023, reflecting lower sales and gross
sales margin rates and higher selling, general and administrative expenses as percentages of sales.


2023 versus 2022


Retailing group revenues increased $111 million (0.6%) in 2023 compared to 2022, reflecting an increase at BHA,
partially offset by lower revenues from our other retailers. BHA’s revenues increased 3.9% in 2023 compared to 2022.
Revenues from new vehicle sales increased 12.6% in 2023 compared to 2022, while revenues from pre-owned retail vehicle
sales declined 9.4%. Retail unit sales increased 2.7%, reflecting an 11.7% increase in new vehicles sold and a 4.7% decrease
in pre-owned vehicles sold. Revenues from BHA’s parts/service/repair operations increased 6.6% in 2023 versus 2022.
Revenues of our other retailing businesses declined 5.6% in the aggregate versus 2022, due primarily to an 8.6% decline at our
home furnishings businesses.


Retailing group pre-tax earnings were $1.7 billion in 2023, unchanged from 2022. BHA’s pre-tax earnings increased
17.7%, primarily due to earnings increases from the parts/service/repair and finance/service contract operations, as well as from
higher investment income and lower selling, general and administrative and other expenses, partially offset by lower vehicle
gross profit margin rates and higher floor plan interest expense. BHA’s comparative vehicle gross profit margin rates peaked
in mid-2022 and declined through 2023. Aggregate pre-tax earnings for the remainder of our retailing group declined $168
million (21.8%) in 2023 compared to 2022, primarily due to a 28.3% decrease in home furnishings businesses earnings and the
impact of a gain in 2022 from the divestiture of certain jewelry stores.


_Pilot Travel Centers_


Pilot Travel Centers (“Pilot”) operates travel centers, primarily under the names Pilot or Flying J, and fuel-only retail
locations. Pilot also operates large wholesale fuel and fuel marketing platforms in the U.S.


Through January 31, 2023, we owned a 38.6% interest in Pilot, which we accounted for under the equity method. Our
38.6% proportionate share of Pilot’s net earnings for the month ending January 31, 2023 was included in equity method earnings
in the accompanying Consolidated Statements of Earnings.


On January 31, 2023, we acquired an additional 41.4% interest in Pilot and owned an 80% controlling financial interest
as of that date. Thus, we began consolidating Pilot’s results of operations in our Consolidated Statements of Earnings on
February 1, 2023. We acquired the remaining 20% noncontrolling interest in Pilot on January 16, 2024.


Pilot’s earnings for the year ending December 31, 2024, the eleven months ending December 31, 2023 and the full year
of 2023 are summarized below (in millions). Revenues, costs and expenses for January 2023 were not included in our
Consolidated Financial Statements.


K-52


---

**Management’s Discussion and Analysis**


_**Manufacturing, Service and Retailing**_


2024 versus 2023


Pilot’s revenues declined $9.9 billion (17.4%) in 2024 compared to the full year 2023. The decline was primarily
attributable to lower average fuel prices and a decline in volumes from non-core fuel activities.


Pilot’s pre-tax earnings declined $442 million (41.9%) in 2024 compared to the full year 2023. Gross sales margins
declined 4.3% in 2024 compared to the full year 2023, attributable to lower diesel margins from lower price volatility. Selling,
general and administrative expenses increased 10.3% in 2024 compared to the full year 2023, reflecting increased depreciation
and amortization expenses, as well as labor, marketing and maintenance costs. Interest expense declined 30.9% in 2024
compared to the full year 2023, attributable to reduced borrowings and lower rates. In March 2024, Pilot borrowed $5.7 billion
from certain Berkshire insurance subsidiaries and repaid its third-party borrowings. Pilot subsequently repaid $1.0 billion of
the affiliate borrowings in 2024. The interest on Pilot’s borrowings from affiliates is included in insurance investment income
on page K-39.


_McLane_


McLane Company, Inc. (“McLane”) operates a wholesale distribution business that provides grocery and non-food
consumer products to retailers and convenience stores (“retail”) and to restaurants (“restaurant”). McLane also operates
businesses that are wholesale distributors of distilled spirits, wine and beer (“beverage”). The retail and restaurant businesses
generate high sales and very low profit margins. The retail business sales represented 63% of McLane’s consolidated sales in
2024 with the restaurant business generating most of the remainder. These businesses have several significant customers and a
reduction in purchasing by any of these customers could have an adverse impact on McLane’s revenues and earnings.


2024 versus 2023


Revenues declined 1.3% in 2024 compared to 2023, reflecting lower restaurant business sales (5.7%) and increased retail
business sales (1.0%) in 2024 compared to 2023. The decline in restaurant sales reflected lower unit sales attributable to
changing consumer preferences for dining at restaurants and quick-service restaurants versus meals-at-home, partially offset
by impacts of price inflation. Pre-tax earnings increased $179 million (39.3%) in 2024 compared to 2023 reflecting an increase
in gross sales margin rates, which more than offset the impacts of lower sales and higher selling, general and administrative
expenses.


2023 versus 2022


Revenues were $52.6 billion in 2023, a decline of $602 million (1.1%) compared to 2022. Revenues from the retail and
restaurant businesses declined 0.8% and 2.2%, respectively, while revenues from the beverage business increased 1.9%
compared to 2022. Retail and the restaurant business revenues were negatively affected in 2023 by lower unit volumes. Pretax earnings increased $184 million (67.9%) in 2023 compared to 2022. The increase reflected a slight increase in overall gross
sales margin rates, increased other income and lower fuel expenses, partly offset by higher personnel expenses.


_**Non-Controlled Businesses**_


After-tax earnings of our non-controlled businesses include our proportionate share of earnings from our investments in
Kraft Heinz, Occidental Petroleum (“Occidental”), Berkadia and Pilot through January 31, 2023. Earnings also included our
38.6% share of Pilot’s earnings for 2022 and for the month of January 2023.


After-tax earnings attributable to these businesses declined $231 million in 2024 compared to 2023, primarily due to
lower earnings from Kraft Heinz ($137 million) and the inclusion of Pilot in January 2023 ($83 million). Earnings of noncontrolled businesses increased $222 million in 2023 compared to 2022. The comparative increase was primarily due to
increased earnings from Occidental, on which we adopted the equity method on August 4, 2022, and Kraft Heinz ($240 million),
partially offset by decreased earnings from Pilot ($559 million). As of January 31, 2023, we discontinued using the equity
method for our pre-existing 38.6% interest in Pilot upon acquiring a controlling interest in Pilot. In each year, our earnings
from Kraft Heinz included the impacts of goodwill and intangible asset impairments recorded by Kraft Heinz.


K-53


---

**Management’s Discussion and Analysis**


_**Investment Gains (Losses)**_


A summary of investment gains (losses) follows (dollars in millions).


Unrealized gains and losses arising from changes in market prices of our investments in equity securities are included in
our reported earnings, which significantly increases the volatility of our periodic net earnings due to the magnitude of our
equity securities portfolio and the inherent volatility of equity securities prices. Unrealized gains and losses on our investments
in equity securities also include the effects of changes in foreign currency exchange rates on investments in non-U.S. issuers
that are held by our U.S.-based subsidiaries.


Pre-tax investment gains and losses included net unrealized gains of $49.3 billion in 2024 and $69.1 billion in 2023 and
net losses of $63.1 billion in 2022, attributable to changes in market prices during each year on equity securities we held at the
end of each year. We also recorded pre-tax gains and losses from market value changes during each year on equity securities
sold during the year, including net gains of $3.5 billion in 2024 and $2.7 billion in 2023 and net losses of $3.9 billion in 2022.
Taxable investment gains on equity securities sold, which is generally the difference between sales proceeds and the original
cost basis of the securities sold, were $101.1 billion in 2024, $5.0 billion in 2023 and $769 million in 2022. Investment gains
in 2023 included a non-cash pre-tax gain of approximately $3.0 billion related to the remeasurement of our pre-existing interest
in Pilot to fair value through the application of acquisition accounting upon attaining control of Pilot for financial reporting
purposes.


We believe that investment gains and losses, whether realized from sales or unrealized from changes in market prices,
are often meaningless in terms of understanding our reported consolidated earnings or evaluating our periodic economic
performance. We continue to believe the investment gains and losses recorded in earnings in any given period has little
analytical or predictive value.


_**Other**_


A summary of after-tax other earnings follows (in millions).


After-tax acquisition accounting expenses include charges arising from the application of the acquisition method in
connection with certain of Berkshire’s past business acquisitions. These charges arise primarily from the amortization of
intangible assets recorded in connection with those acquisitions.


Foreign currency exchange rate gains pertain to Berkshire’s and BHFC’s Euro, Great Britain Pound and Japanese Yen
denominated debt. Changes in foreign currency exchange rates produce gains and losses from the periodic revaluation of these
liabilities into U.S. Dollars. In each year, we recorded foreign currency exchange rate gains due to strengthening of the U.S.
Dollar, which reduced the U.S. Dollar carrying value of the debt. The gains and losses recorded in any given period can be
significant due to the magnitude of the borrowings and the inherent volatility in foreign currency exchange rates. Other earnings
consist primarily of Berkshire parent company investment income, intercompany interest income when the related expense is
included in earnings of the operating subsidiaries, corporate expenses and unallocated income taxes. Other earnings increased
by $484 million in 2024 compared to 2023 and $337 million in 2023 compared to 2022, primarily due to increased interest
income, including interest earned on intercompany loans to operating subsidiaries.


K-54


---

**Management’s Discussion and Analysis**


**Financial Condition**


Our Consolidated Balance Sheet continues to reflect significant liquidity and a very strong capital base. Berkshire’s
shareholders’ equity at December 31, 2024 was $649.4 billion, an increase of $88.1 billion since December 31, 2023. Net
earnings attributable to Berkshire shareholders were $89.0 billion for 2024 and included after-tax investment gains of
approximately $41.6 billion. Investment gains and losses from changes in the market prices of our investments in equity
securities usually produce significant volatility in our earnings.


Berkshire’s common stock repurchase program, as amended, permits Berkshire to repurchase its Class A and Class B
shares at prices below Berkshire’s intrinsic value, as conservatively determined by Warren Buffett, Berkshire’s Chairman of
the Board and Chief Executive Officer. We are not committed to a minimum or subject to a maximum repurchase amount. We
will not repurchase our stock if it reduces our consolidated cash, cash equivalents and U.S. Treasury Bills holdings to below
$30 billion. Financial strength and redundant liquidity will always be of paramount importance at Berkshire. Berkshire paid
$2.9 billion in 2024 to repurchase its common stock.


At December 31, 2024, our insurance and other businesses held cash, cash equivalents and U.S. Treasury Bills (net of
payables for unsettled purchases) of $318.0 billion. Investments in equity and fixed maturity securities, excluding our
investments in Kraft Heinz and Occidental common stock, were $287.0 billion. During 2024, we paid $9.2 billion to acquire
equity securities and we received $143.4 billion from sales of equity securities.


On January 16, 2024, we acquired the remaining 20% noncontrolling ownership interest in Pilot for $2.6 billion. On
September 30, 2024, BHE repurchased shares of its common stock held by certain noncontrolling BHE shareholders for $2.9
billion.


Our consolidated borrowings at December 31, 2024 were $124.8 billion, of which over 95% were issued by the Berkshire
parent company and BHFC, or by BNSF and BHE and its subsidiaries. Berkshire parent company debt outstanding at December
31, 2024 was $21.1 billion, an increase of $2.3 billion from December 31, 2023. At various dates in 2024, Berkshire issued
approximately ¥837.4 billion (approximately $5.5 billion) of senior note issuances and term loan agreements. The borrowings
have interest rates ranging from 0.974% to 2.625% and maturity dates ranging from 2027 to 2054. In 2024, senior note
maturities were $1.9 billion. Additionally, the carrying value of Berkshire parent company non-U.S. Dollar denominated debt
declined $1.4 billion in 2024 due to changes in foreign currency exchange rates.


Senior note borrowings of BHFC, a wholly-owned financing subsidiary, were approximately $17.9 billion at December
31, 2024, relatively unchanged from December 31, 2023. BHFC’s borrowings are used to fund a portion of loans originated
and acquired by Clayton Homes and equipment held for lease by our railcar leasing business. Berkshire guarantees BHFC’s
senior notes for the full and timely payment of principal and interest.


BNSF’s outstanding debt was $23.5 billion as of December 31, 2024, relatively unchanged from December 31, 2023. In
2024, BNSF issued $1.3 billion of 5.5% debentures due in 2055 and repaid approximately $1.3 billion of debentures. BHE’s
aggregate borrowings were approximately $56.4 billion at December 31, 2024, relatively unchanged from December 31, 2023.
In 2024, BHE subsidiaries issued $6.4 billion of term debt with a weighted average interest rate of 5.4% and maturity dates
ranging from 2029 to 2055 and BHE and its subsidiaries repaid term debt and short-term borrowings aggregating approximately
$5.9 billion. In 2025, BHE subsidiaries issued term debt of $1.5 billion, with maturities ranging from 2035 to 2055 and a
weighted average interest rate of 6.0%. Berkshire does not guarantee the repayment of debt issued by BNSF, BHE or any of
their subsidiaries or affiliates.


In 2024, our diverse group of businesses generated net operating cash flows of $30.6 billion, which was net of income
tax payments of $28.5 billion. Income tax payments in 2024 included significant U.S. Federal income tax payments derived
from taxable gains on sales of equity securities. The gross proceeds from such sales were included in cash flows from investing
activities.


Our consolidated capital expenditures for property, plant and equipment and equipment held for lease were $19.0 billion
in 2024, which included capital expenditures by BNSF and BHE of $12.7 billion. BNSF and BHE maintain very large
investments in capital assets (property, plant and equipment) and regularly make significant capital expenditures in the normal
course of business. BHE and BNSF forecast capital expenditures in 2025 of approximately $14.0 billion.


K-55


---

**Management’s Discussion and Analysis**


**Contractual Obligations**


We are party to other contracts associated with ongoing business activities, which will result in cash payments to
counterparties in future periods. Our annual debt maturities for the next five years are summarized in Note 19 to the
Consolidated Financial Statements. We also currently expect to pay interest on our debt ranging from $4.7 billion in 2025 to
$4.1 billion in 2029 based on borrowings outstanding at December 31, 2024. Certain other obligations are included in our
Consolidated Balance Sheets, such as operating lease liabilities and shared aircraft repurchase liabilities of NetJets. Estimated
payments of these liabilities in each of the next five years are as follows (in billions): $2.0 in 2025; $1.8 in 2026; $2.0 in 2027;
$2.2 in 2028; and $1.9 in 2029.


We are also obligated to pay claims arising from our property and casualty insurance companies. Such liabilities,
including amounts from retroactive reinsurance, were approximately $148 billion at December 31, 2024. We currently forecast
claim payments in 2025 of approximately $38 billion with respect to claims occurring prior to 2025. However, the timing and
amount of the payments under insurance and reinsurance contracts are contingent upon the outcome of future events and can
be highly uncertain. Actual payments will likely vary, perhaps materially, from forecasted payments. We anticipate that claims
payments will be funded by operating cash flows.


Other obligations pertaining to the acquisition of goods or services in the future, such as certain purchase obligations,
are not currently reflected in the Consolidated Financial Statements and will be recognized in future periods as the goods are
delivered or services are provided. As of December 31, 2024, the largest categories of our long-term contractual obligations
primarily related to fuel, capacity, transmission and maintenance contracts and capital expenditure commitments of BHE and
BNSF, aircraft purchase commitments of NetJets and purchase commitments of certain materials. We currently estimate future
payments associated with these contracts over the next five years will approximate $30 billion, including $12 billion in 2025.


**Critical Accounting Estimates**


Certain accounting policies require us to make estimates and judgments in determining the amounts reflected in our
Consolidated Financial Statements. Such estimates and judgments necessarily involve varying and significant degrees of
uncertainty. Accordingly, certain amounts currently recorded in our Consolidated Financial Statements will likely be adjusted
in the future based on new available information and changes in other facts and circumstances. A discussion of our principal
accounting policies that required the application of significant judgments as of December 31, 2024 follows.


_**Property and casualty insurance unpaid losses**_


We record liabilities for unpaid losses and loss adjustment expenses (also referred to as “gross unpaid losses” or “claim
liabilities”) based upon estimates of the ultimate amounts payable for loss events occurring on or before the balance sheet date.
The timing and amount of ultimate loss payments are contingent upon, among other things, the timing of claim reporting from
insureds and ceding companies and the final determination of the loss amount through the loss adjustment and settlement
process.


As of the balance sheet date, recorded claim liabilities include estimates for reported claims and for incurred-but-notreported (“IBNR”) claims. The period between the loss occurrence date and loss settlement date is the “claim-tail.” Property
claims typically have relatively short claim-tails, while casualty claims usually have longer claim-tails, occasionally extending
for decades. Casualty claims are more susceptible to litigation and the impact of changing contract interpretations. The legal
environment and judicial process further contribute to extending claim-tails.


Our consolidated claim liabilities, including liabilities from retroactive reinsurance contracts, as of December 31, 2024
were approximately $147.6 billion, of which 74% related to GEICO and the Berkshire Hathaway Reinsurance Group.
Additional information regarding significant uncertainties inherent in the processes and techniques for estimating unpaid losses
of these businesses follows.


K-56


---

**Management’s Discussion and Analysis**


**Critical Accounting Estimates**


_**Property and casualty insurance unpaid losses**_


_GEICO_


GEICO predominantly writes private passenger automobile insurance. As of December 31, 2024, GEICO’s gross claim
liabilities were $24.8 billion and were $23.9 billion, net of reinsurance. GEICO’s claim reserving methodologies produce
liability estimates based upon the individual claims. The key assumptions affecting our liability estimates include projections
of ultimate claim counts (“frequency”) and average loss per claim (“severity”). A combination of several actuarial estimation
methods, including Bornhuetter-Ferguson and chain-ladder methodologies.


Claim liability estimates for liability coverages (such as bodily injury (“BI”), uninsured motorists and personal injury
protection) are more uncertain due to the longer claim-tails, so we establish additional case development estimates. As of
December 31, 2024, case development liabilities averaged approximately 31% of reported reserves. Case development factors
are selected through analysis of the overall adequacy of historical case liabilities.


The adequacy of the aggregate claim liabilities is tested using one or more actuarial projections based on claim closure
models and paid and incurred loss triangles. Each type of projection analyzes loss occurrence data for claims occurring in a
given period and projects the ultimate cost.


The aggregate claim liability estimates recorded at the end of 2023 were reduced by $550 million during 2024, which
produced a corresponding increase to pre-tax earnings. The assumptions used to estimate liabilities at December 31, 2024
reflect the most recent frequency and severity estimates. Future development of recorded liabilities will depend on whether
actual frequency and severity of claims are more or less than anticipated.


With respect to liabilities for BI claims, we believe it is reasonably possible that average claims severities will change
by at least one percentage point from the projected severities used in establishing the recorded liabilities at December 31, 2024.
A one percentage point increase or decrease in BI severities could produce a $220 million increase or decrease in recorded
liabilities, with a corresponding decrease or increase in pre-tax earnings. Many of the economic forces that would likely cause
BI severity to differ from expectations would likely also cause severities for other injury coverages to differ in the same
direction.


_Berkshire Hathaway Reinsurance Group_


BHRG’s property and casualty claims arise from a diverse portfolio of reinsurance contracts underwritten across multiple
entities through the NICO, General Re and TransRe Groups. A summary of BHRG’s property and casualty unpaid losses and
loss adjustment expenses, other than retroactive reinsurance losses and loss adjustment expenses, as of December 31, 2024
follows (in millions).


Gross unpaid losses and loss adjustment expenses consist primarily of traditional property and casualty coverages written
under excess-of-loss and quota-share treaties. Under certain contracts, coverage can apply to multiple lines of business written
and the ceding company may not report loss data by such lines consistently, if at all. In those instances, we judgmentally
allocate losses to property and casualty coverages based on internal estimates.


The nature, extent, timing and perceived reliability of loss information received from ceding companies varies widely
depending on the type of coverage and the contractual reporting terms. Reinsurance contract (or policy) terms, conditions and
coverages also tend to lack standardization and may evolve more rapidly than primary insurance policies.


K-57


---

**Management’s Discussion and Analysis**


**Critical Accounting Estimates**


_**Property and casualty insurance unpaid losses**_


The loss information provided under many facultative (individual risk) or per occurrence excess-of-loss contracts may
be comparable to the information received under a primary insurance contract. However, loss information with respect to
aggregate excess-of-loss and quota-share contracts is often in a summary form rather than on an individual claim basis. Loss
data includes currently recoverable paid losses, as well as case loss estimates. Ceding companies infrequently provide reliable
IBNR loss estimates.


Loss reporting to reinsurers is typically slower than primary insurers. Client reporting of claims information is required
based on the terms of the contract at intervals ranging from 30 to 180 days after the end of the quarterly or annual period,
reporting practices can vary by jurisdiction. To the extent that reinsurers assume and cede underlying risks from other
reinsurers, further delays in claims reporting may occur. The relative impact of reporting delays depends on the type of
coverage, contractual reporting terms, or the magnitude of the claim relative to the attachment point of the reinsurance coverage.


The premium and loss data BHRG receives is at least one level removed from the underlying claimant, so there is a risk
that the loss data reported is incomplete, inaccurate or the claim is outside the coverage terms. We maintain internal procedures
to determine that the information is complete and in compliance with the contract terms. Generally, our reinsurance contracts
permit us to audit the ceding company’s records with respect to the subject business for compliance with the terms of the policy.
Disputes occasionally arise concerning whether claims are covered by our reinsurance policies, which are normally resolved
through negotiation. If disputes cannot be resolved, our contracts generally provide arbitration or alternative dispute resolution
processes. We believe there are no coverage disputes at this time for which an adverse resolution would likely have a material
impact on our consolidated results of operations or financial condition.


Establishing claim liability estimates for reinsurance requires evaluation of loss information received from our clients.
While we generally rely on the ceding companies’ reported case loss estimates, we may perform our own evaluations certain
reported case losses and if deemed appropriate, use our own case liability estimate. As of December 31, 2024, our case loss
estimates exceeded ceding company estimates by approximately $1.7 billion. We also periodically conduct detailed reviews of
individual client claims, which may cause us to adjust our case estimates.


Although liabilities for losses are initially determined based on pricing and underwriting analysis, we use a variety of
actuarial methodologies that place reliance on the extrapolation of historical data, loss development patterns, industry data and
other benchmarks. The estimate of the IBNR liabilities also requires judgment by actuaries and management to reflect the
impact of additional factors like change in business mix, volume, claim reporting and handling practices, inflation, social and
legal environment and the terms and conditions of the contracts. The methodologies generally fall into or are hybrids of one or
more of the following categories:


_Paid_ _and_ _incurred_ _loss_ _development_ _methods_ consider the expected case loss emergence and development patterns,
together with expected loss ratios by year. Factors affecting loss development analysis include, but are not limited to, changes
in the following: client claims reporting and settlement practices, the frequency of client company claim reviews, policy terms
and coverage (such as loss retention levels and occurrence and aggregate policy limits), loss trends and legal trends that result
in unanticipated losses. Collectively, these factors influence our selections of expected case loss emergence patterns.


_Incurred and paid loss Bornhuetter-Ferguson methods_ consider actual paid and incurred losses and expected reporting
patterns of paid and incurred losses, taking the initial expected ultimate losses into account to determine an estimate of the
expected unpaid or unreported losses.


K-58


---

**Management’s Discussion and Analysis**


**Critical Accounting Estimates**


_**Property and casualty insurance unpaid losses**_


_Frequency and severity methods_ commonly focus on a review of the number of anticipated claims and the anticipated
claims severity and may also rely on development patterns to derive such estimates. However, our processes and techniques
for estimating liabilities in such analyses generally rely more on a per-policy assessment of the ultimate cost associated with
the individual loss rather than with an analysis of historical development patterns of past losses.


_Additional_ _analysis_    - In some cases we have established reinsurance claim liabilities on a contract-by-contract basis,
determined from case loss estimates reported by the ceding company and IBNR liabilities that are primarily a function of an
anticipated loss ratio for the contract and the reported case loss estimate. Liabilities are adjusted upward or downward over
time to reflect case losses reported versus expected case losses, which we use to form revised judgment on the adequacy of the
expected loss ratio and the level of IBNR liabilities required for unreported claims. Anticipated loss ratios are also revised to
include estimates of known major catastrophe events.


Our claim liability estimation process for short-tail lines, primarily property exposures, utilizes a combination of the paid
and incurred loss development methods and the incurred and paid loss Bornhuetter-Ferguson methods. Certain property,
individual risk and aviation excess-of-loss contracts tend to generate low frequency/high severity losses. Our processes and
techniques for estimating liabilities under such contracts generally rely more on a per contract assessment of the ultimate cost
associated with the individual loss event rather than with an analysis of the historical development patterns of past losses.


For our long-tail lines, primarily casualty exposures, we may rely on different methods depending on the maturity of the
business, with estimates for the most recent years being based on priced loss expectations and more mature years reflecting the
paid or incurred development pattern indications.


In 2024, we reduced estimated ultimate pre-2024 accident years’ claim liabilities by $1.7 billion, of which $1.6 billion
was attributable to lower-than-expected reported property losses. In 2024, we also reduced estimated ultimate casualty claim
liabilities for pre-2024 accident years by approximately $100 million. These reductions produced corresponding increases in
pre-tax earnings.


The portfolios of contracts within the three BHRG Groups vary considerably, covering multiple lines of business within
diverse geographic areas and legal environments, which requires us to vary the application of actuarial methods and weighting
of assumptions to determine the appropriate ultimate claims estimates. Given the heterogeneity of the groups of contracts and
actuarial methods and assumptions applied, we believe it is not possible to reasonably quantify the impact of changes in any
single or limited group of assumptions to the entire portfolio. Moreover, changes in certain assumptions often create iterative
impacts on other actuarial assumptions. Accordingly, we believe it is impracticable to provide meaningful quantification of the
impact of changes to any limited number of chosen assumptions.


BHRG’s property and casualty unpaid loss and loss adjustment expenses could be materially higher or lower than the
liabilities as of December 31, 2024 due to the inherent uncertainty of determining ultimate claims costs for claims that have
occurred or will be deemed to have occurred as of the balance sheet date. We currently believe, however, that significant
upward revisions to claims estimates are more likely for casualty claims, given longer claims tails and evolving inflation, legal,
judicial and mass tort risks, including the manifestation of new forms of claims that were not contemplated when the policies
were written. We believe a five percent increase in BHRG’s casualty claim liabilities over time is reasonably possible, although
this should not be viewed as a worst-case scenario given the risks identified. An increase of this magnitude to our gross liabilities
for casualty claims at December 31, 2024 could produce an increase in casualty liabilities of $1.75 billion, with a corresponding
decrease to pre-tax earnings.


_Retroactive reinsurance_


Our retroactive reinsurance contracts indemnify insurance losses from events occurring before the contract inception
dates. Claim liabilities associated with these contracts predominately pertain to casualty or liability exposures and we expect
the claim-tails will be very long. At December 31, 2024, gross unpaid losses were $32.4 billion.


Our contracts are generally subject to maximum limits of indemnification and, as such, we currently expect that the
aggregate remaining losses payable under our policies will not exceed $47 billion. While ultimate claims will be affected by
judicial and legislative changes affecting asbestos, environmental or mass tort exposures, we currently believe it unlikely that
losses will increase to the maximum or decline by more than 15% of our estimated gross claims liability as of December 31,
2024.


K-59


---

**Management’s Discussion and Analysis**


**Critical Accounting Estimates**


_**Property and casualty insurance unpaid losses**_


We establish liability estimates by individual contract, considering exposure and development trends, historical aggregate
loss payment patterns and project expected ultimate losses under various scenarios. We apply judgmental probability factors
to these scenarios to determine an expected outcome. We also monitor subsequent loss payment activity and ceding company
reports and other available information. We re-estimate ultimate losses when significant events or significant deviations from
expectations are revealed.


Certain of our contracts include asbestos and environmental, as well as other mass tort exposures. Our estimated liabilities
for asbestos and environmental exposures were approximately $11.9 billion at December 31, 2024. Ceding companies do not
consistently provide reliable and detailed underlying claims data, particularly with respect to multi-line or aggregate excessof-loss policies. When possible, we conduct detailed analyses of the underlying loss data in making an estimate of ultimate
remaining claims liabilities. When detailed loss information is unavailable, we may apply recent industry trends and projections
to aggregate client data. Judgments in these areas necessarily consider the stability of the legal and regulatory environment
under which we expect claims will be adjudicated. Legal reform and legislation and judicial rulings could also have a significant
impact on our ultimate liabilities.


Deferred charges for retroactive reinsurance contracts, which at the inception dates of the contracts, represent the excess
of the estimated ultimate liability for unpaid losses over premiums received. Deferred charges are subsequently adjusted based
on the changes to expected ultimate liabilities and the timing of actual and expected future loss payments. Deferred charge
assets were $8.8 billion at December 31, 2024. We estimate that deferred charge assets will decline $830 million in 2025,
producing a corresponding charge to pre-tax earnings.


Overall, we increased estimated ultimate liabilities for prior year retroactive reinsurance contracts by $196 million in
2024, primarily for asbestos, environmental and other casualty exposures. This increase, net of the related changes in deferred
charge assets had an insignificant impact on underwriting results.


_**Other Critical Accounting Estimates**_


Our Consolidated Balance Sheet at December 31, 2024 includes goodwill of acquired businesses of $83.9 billion and
indefinite-lived other intangible assets of $18.9 billion. We evaluate these assets for impairment annually in the fourth quarter
and on an interim basis if the facts and circumstances lead us to believe that more likely than not there has been an impairment.


Goodwill and indefinite-lived intangible asset impairment reviews include determining the estimated fair values of our
reporting units and of indefinite-lived intangible assets. Several methods may be used to estimate fair values, including market
quotations, multiples of earnings and other valuation techniques, such as discounted projected future earnings or cash flow
methods. The key assumptions and inputs used in fair value determinations may include forecasting revenues and expenses,
cash flows and capital expenditures, as well as an appropriate discount rate and other inputs.


Significant judgment by management is required in estimating the fair value of a reporting unit and in performing
impairment reviews. Due to the inherent subjectivity and uncertainty in forecasting future cash flows and earnings over long
periods of time, actual results may differ materially from the forecasts. Reasonable estimates of the fair value of a business
enterprise may range widely.


If the carrying value of a reporting unit exceeds the estimated fair value of the reporting unit, then the excess, limited to
the carrying amount of goodwill, is charged to earnings as an impairment loss. If the carrying value of the indefinite-lived
intangible asset exceeds fair value, the excess is charged to earnings as an impairment loss.


As of December 31, 2024, we concluded that more-likely-than not, the goodwill recorded in our Consolidated Balance
Sheet was not impaired. However, the fair value estimates of the reporting units and assets are subject to change based on
market and economic conditions, as well as events affecting our businesses or the industries in which they operate, which we
cannot reliably predict. It is reasonably possible that adverse changes in such conditions or events could result in the recognition
of impairment losses in our Consolidated Financial Statements.


K-60


---

**Management’s Discussion and Analysis**


**Critical Accounting Estimates**


_**Other Critical Accounting Estimates**_


In connection with the annual goodwill impairment review conducted in the fourth quarter of 2024, our estimated fair
values of seven reporting units did not exceed our carrying values by at least 20%. These reporting units included PCC, as well
as three reporting units acquired in late 2022 and early 2023. Our estimated fair value of PCC’s equity exceeded the carrying
value of $28.5 billion, which included goodwill of approximately $7.5 billion, by nearly 20%. Of the three units acquired in
2022 and 2023, the largest was Pilot, which had an estimated fair value of approximately $20.3 billion and a carrying value of
$18.3 billion, including goodwill of $6.5 billion. The remaining five other reporting units had an aggregate estimated fair value
of approximately $11.7 billion, which exceeded our aggregate carrying value by approximately 12%. The carrying value of
these units included goodwill of approximately $4.6 billion.


**Market Risk Disclosures**


Our Consolidated Balance Sheets include substantial amounts of assets and liabilities whose fair values are subject to
market risks. Our significant market risks are primarily associated with equity prices, interest rates, foreign currency exchange
rates and commodity prices. The fair values of our investment portfolios remain subject to considerable volatility. The following
sections address the significant market risks associated with our business activities.


_**Equity Price Risk**_


Investments in equity securities represent the most significant portion of our consolidated investment portfolio.
Strategically, we strive to invest in businesses that possess excellent economics and management, and we prefer to invest a
meaningful amount in each company. Historically, our investments have been concentrated in relatively few issuers. At
December 31, 2024, approximately 71% of the aggregate fair value of our investments in equity securities was concentrated in
five companies.


We often hold our investments for long periods and short-term price volatility has occurred in the past and will occur in
the future. We also maintain significant levels of shareholder capital and ample liquidity to provide a margin of safety against
short-term price volatility.


The following table summarizes our investments in equity securities, excluding our investments in Kraft Heinz and
Occidental common stocks that are accounted for under the equity method, and the estimated effects of a hypothetical 30%
increase and a 30% decrease in market prices as December 31, 2024 and 2023. The selected 30% hypothetical increase and
decrease does not represent the best or worst case scenario. Indeed, results from declines could be far worse due both to the
nature of equity markets and the concentrations existing in our investment portfolio. Dollar amounts are in millions.


_(1)_ _The estimated increase (decrease) is after income taxes._


K-61


---

**Management’s Discussion and Analysis**


_**Interest Rate Risk**_


We also invest in bonds, loans or other interest rate sensitive instruments. Our strategy is to acquire or originate such
instruments at prices or with interest rates considered appropriate relative to the perceived credit risk. We also issue debt in the
ordinary course of business to fund business operations and for general purposes. We attempt to maintain high credit ratings to
minimize the cost of our debt. We generally do not utilize derivative products, such as interest rate swaps, to manage interest
rate risks and we do not attempt to match maturities of assets and liabilities.


The fair values of our fixed maturity investments, loans and finance receivables and notes payable and other borrowings
will fluctuate in response to changes in market interest rates. Increases and decreases in interest rates generally translate into
decreases and increases in fair values of these instruments. Additionally, fair values of interest rate sensitive instruments may
be affected by the perceived credit risk, prepayment options, liquidity and other factors, as well as general market conditions.


The following table summarizes the estimated effects of hypothetical changes in interest rates on our significant assets
and liabilities that are subject to significant interest rate risk. We assumed that the interest rate changes occur immediately and
uniformly to each category of instrument and that there were no significant changes to other factors used to determine the value
of the instrument. The hypothetical changes in interest rates do not reflect the best or worst case scenarios. Actual results may
differ from those reflected in the table. Dollars are in millions.


_* Includes Cumulative Perpetual Preferred Stocks_


_**Foreign Currency Risk**_


Certain of our subsidiaries operate in foreign jurisdictions and we transact business in foreign currencies. In addition, we
hold investments in common stocks of major multinational companies, who have significant foreign business and foreign
currency risk of their own. In most instances, we do not attempt to match assets and liabilities by currency or use derivative
contracts to manage foreign currency risks in a meaningful way.


K-62


---

**Management’s Discussion and Analysis**


_**Foreign Currency Risk**_


Our net assets subject to financial statement translation into U.S. Dollars are primarily in our insurance, utilities and
energy and certain manufacturing subsidiaries. A portion of our financial statement translation-related impact from changes in
foreign currency rates is recorded in other comprehensive income. In addition, we include gains or losses from changes in
foreign currency exchange rates in net earnings related to non-U.S. Dollar denominated assets and liabilities of Berkshire and
its U.S.-based subsidiaries. A summary of these gains (losses), after-tax, for each of the years ending December 31, 2024 and
2023 follows (in millions).


_**Commodity Price Risk**_


Our subsidiaries use commodities in various ways in manufacturing and providing services. As such, we are subject to
price risks related to various commodities. In most instances, we attempt to manage these risks through the pricing of our
products and services to customers. To the extent that we are unable to sustain price increases in response to commodity price
increases, our operating results will likely be adversely affected. We generally do not utilize derivative contracts to manage
commodity price risks to any significant degree.


**Item 7A. Quantitative and Qualitative Disclosures About Market Risk**


See “Market Risk Disclosures” contained in Item 7 “Management’s Discussion and Analysis of Financial Condition and
Results of Operations.”


**Management’s Report on Internal Control Over Financial Reporting**


Management of Berkshire Hathaway Inc. is responsible for establishing and maintaining adequate internal control over
financial reporting, as such term is defined in the Securities Exchange Act of 1934 Rule 13a-15(f). Under the supervision and
with the participation of our management, including our principal executive officer and principal financial officer, we
conducted an evaluation of the effectiveness of the Company’s internal control over financial reporting as of December 31,
2024, as required by the Securities Exchange Act of 1934 Rule 13a-15(c). In making this assessment, we used the criteria set
forth in the framework in _Internal_ _Control—Integrated_ _Framework_ (2013) issued by the Committee of Sponsoring
Organizations of the Treadway Commission. Based on our evaluation under the framework in _Internal_ _Control—Integrated_
_Framework_ (2013), our management concluded that our internal control over financial reporting was effective as of December
31, 2024.


The effectiveness of our internal control over financial reporting as of December 31, 2024 has been audited by Deloitte
& Touche LLP, an independent registered public accounting firm, as stated in their report which appears on page K-64.


Berkshire Hathaway Inc.
February 22, 2025


K-63


---

**Item 8. Financial Statements and Supplementary Data**


**REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM**


To the Shareholders and the Board of Directors of
Berkshire Hathaway Inc.


**Opinions on the Financial Statements and Internal Control over Financial Reporting**
We have audited the accompanying consolidated balance sheets of Berkshire Hathaway Inc. and subsidiaries (the “Company”)
as of December 31, 2024 and 2023, the related consolidated statements of earnings, comprehensive income, changes in
shareholders’ equity, and cash flows, for each of the three years in the period ended December 31, 2024, and the related notes
(collectively referred to as the “financial statements”). We also have audited the Company’s internal control over financial
reporting as of December 31, 2024, based on criteria established in Internal Control — Integrated Framework (2013) issued by
the Committee of Sponsoring Organizations of the Treadway Commission (COSO).


In our opinion, the financial statements referred to above present fairly, in all material respects, the financial position of the
Company as of December 31, 2024 and 2023, and the results of its operations and its cash flows for each of the three years in
the period ended December 31, 2024, in conformity with accounting principles generally accepted in the United States of
America. Also, in our opinion, the Company maintained, in all material respects, effective internal control over financial
reporting as of December 31, 2024, based on criteria established in Internal Control — Integrated Framework (2013) issued by
COSO.


**Basis for Opinions**
The Company’s management is responsible for these financial statements, for maintaining effective internal control over
financial reporting, and for its assessment of the effectiveness of internal control over financial reporting, included in the
accompanying Management’s Report on Internal Control Over Financial Reporting. Our responsibility is to express an opinion
on these financial statements and an opinion on the Company’s internal control over financial reporting based on our audits.
We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) (PCAOB)
and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the
applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.


We conducted our audits in accordance with the standards of the PCAOB. Those standards require that we plan and perform
the audits to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due
to error or fraud, and whether effective internal control over financial reporting was maintained in all material respects.


Our audits of the financial statements included performing procedures to assess the risks of material misstatement of the
financial statements, whether due to error or fraud, and performing procedures to respond to those risks. Such procedures
included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audits also
included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the
overall presentation of the financial statements. Our audit of internal control over financial reporting included obtaining an
understanding of internal control over financial reporting, assessing the risk that a material weakness exists, and testing and
evaluating the design and operating effectiveness of internal control based on the assessed risk. Our audits also included
performing such other procedures as we considered necessary in the circumstances. We believe that our audits provide a
reasonable basis for our opinions.


**Definition and Limitations of Internal Control over Financial Reporting**
A company’s internal control over financial reporting is a process designed to provide reasonable assurance regarding the
reliability of financial reporting and the preparation of financial statements for external purposes in accordance with generally
accepted accounting principles. A company’s internal control over financial reporting includes those policies and procedures
that (1) pertain to the maintenance of records that, in reasonable detail, accurately and fairly reflect the transactions and
dispositions of the assets of the company; (2) provide reasonable assurance that transactions are recorded as necessary to permit
preparation of financial statements in accordance with generally accepted accounting principles, and that receipts and
expenditures of the company are being made only in accordance with authorizations of management and directors of the
company; and (3) provide reasonable assurance regarding prevention or timely detection of unauthorized acquisition, use, or
disposition of the company’s assets that could have a material effect on the financial statements.


Because of its inherent limitations, internal control over financial reporting may not prevent or detect misstatements. Also,
projections of any evaluation of effectiveness to future periods are subject to the risk that controls may become inadequate
because of changes in conditions, or that the degree of compliance with the policies or procedures may deteriorate.


K-64


---

**REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM (Continued)**


**Critical Audit Matters**
The critical audit matters communicated below are matters arising from the current-period audit of the financial statements that
were communicated or required to be communicated to the audit committee and that (1) relate to accounts or disclosures that
are material to the financial statements and (2) involved our especially challenging, subjective, or complex judgments. The
communication of critical audit matters does not alter in any way our opinion on the financial statements, taken as a whole, and
we are not, by communicating the critical audit matters below, providing separate opinions on the critical audit matters or on
the accounts or disclosures to which they relate.


_**Unpaid Losses and Loss Adjustment Expenses — Refer to Notes 1 and 16 to the financial statements**_


_Critical Audit Matter Description_
The Company’s unpaid losses and loss adjustment expenses (“claim liabilities”) include short duration property and casualty
insurance and reinsurance contracts. Key assumptions affecting certain of these claim liabilities include anticipated claims and
their severity, expected loss ratios, and expected patterns of paid and incurred losses.


Given the subjectivity of estimating these key assumptions, performing audit procedures to evaluate whether certain of these
claim liabilities were appropriately recorded as of December 31, 2024 required a high degree of auditor judgment and an
increased extent of effort, including the need to involve our actuarial specialists.


_How the Critical Audit Matter Was Addressed in the Audit_
Our audit procedures related to the key assumptions affecting certain of these claim liabilities included the following, among
others:


- We tested the operating effectiveness of controls over claim liabilities, including those over the key assumptions.

- We tested the underlying data that served as the basis for the actuarial analysis to evaluate that the inputs to the actuarial
estimate were accurate and complete.

- With the assistance of our actuarial specialists:

  - We developed independent estimates of the claim liabilities, including loss data and industry claim development
factors as needed, and compared our estimates to management’s estimates.

  - We compared prior year estimates of expected incurred losses to actual experience during the most recent year to
identify potential bias in management’s determination of the claim liabilities.


_**Unpaid**_ _**Losses**_ _**and**_ _**Loss**_ _**Adjustment**_ _**Expenses**_ _**—**_ _**Retroactive**_ _**Reinsurance**_ _**Contracts**_ _**—**_ _**Refer**_ _**to**_ _**Notes**_ _**1**_ _**and**_ _**17**_ _**to**_ _**the**_
_**financial statements**_


_Critical Audit Matter Description_
The Company’s unpaid losses and loss adjustment expenses under retroactive reinsurance contracts (“retroactive claim
liabilities”) include property and casualty retroactive reinsurance contracts. Key assumptions affecting certain of these
retroactive claim liabilities include anticipated claims and their severity, expected loss ratios, and expected patterns of paid and
incurred losses.


Given the subjectivity of estimating these key assumptions, performing audit procedures to evaluate whether certain of these
claim liabilities were appropriately recorded as of December 31, 2024, required a high degree of auditor judgment and an
increased extent of effort, including the need to involve our actuarial specialists.


_How the Critical Audit Matter Was Addressed in the Audit_
Our audit procedures related to the key assumptions affecting claim liabilities included the following, among others:


- We tested the operating effectiveness of controls over claim liabilities, including those over the key assumptions.

- We tested the underlying data that served as the basis for the actuarial analysis, including historical claims, to test that the
inputs to the actuarial estimate were accurate and complete.

- With the assistance of our actuarial specialists:

  - We developed independent claim liability estimates for certain retroactive reinsurance contracts and compared our
estimates to management’s estimates. For other retroactive reinsurance contracts, we evaluated the process used by
management to develop the estimated claim liabilities.

  - We compared prior year estimates of expected incurred losses to actual experience during the most recent year to
identify potential bias in management’s determination of the claim liabilities.


/s/ Deloitte & Touche LLP
Omaha, Nebraska
February 22, 2025


We have served as the Company’s auditor since 1985.


K-65


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED BALANCE SHEETS**
_(dollars in millions)_


_* Includes U.S. Treasury Bills with maturities of three months or less when purchased of $14.4 billion at December 31, 2024_
_and $4.8 billion at December 31, 2023._


_See accompanying Notes to Consolidated Financial Statements_


K-66


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED BALANCE SHEETS**
_(dollars in millions)_


_See accompanying Notes to Consolidated Financial Statements_


K-67


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED STATEMENTS OF EARNINGS**
_(dollars in millions except per share amounts)_


_* Net earnings (loss) per average equivalent Class B share outstanding are equal to one-fifteen-hundredth of the equivalent_
_Class A amount. See Note 22._


_See accompanying Notes to Consolidated Financial Statements_


K-68


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED STATEMENTS OF COMPREHENSIVE INCOME**
_(dollars in millions)_


**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED STATEMENTS OF CHANGES IN SHAREHOLDERS’ EQUITY**
_(dollars in millions)_


_See accompanying Notes to Consolidated Financial Statements_


K-69


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**CONSOLIDATED STATEMENTS OF CASH FLOWS**
_(dollars in millions)_


_See accompanying Notes to Consolidated Financial Statements_


K-70


---

**BERKSHIRE HATHAWAY INC.**
**and Subsidiaries**
**NOTES TO CONSOLIDATED FINANCIAL STATEMENTS**
**December 31, 2024**


**(1)** **Significant accounting policies and practices**


_(a)_ _Nature of operations and basis of consolidation_


Berkshire Hathaway Inc. (“Berkshire”) is a holding company owning subsidiaries engaged in numerous diverse
business activities, including insurance and reinsurance, freight rail transportation, utilities and energy, manufacturing,
service and retailing. In these notes the terms “us,” “we,” or “our” refer to Berkshire and its consolidated subsidiaries.
Further information regarding our reportable business segments is contained in Note 26. Information concerning
significant business acquisitions completed over the past three years appears in Note 2.


The accompanying Consolidated Financial Statements include the accounts of Berkshire consolidated with the
accounts of all subsidiaries and affiliates in which we hold a controlling financial interest as of the financial statement
date. Normally a controlling financial interest reflects ownership of a majority of the voting interests. We consolidate
variable interest entities (“VIE”) when we possess both the power to direct the activities of the VIE that most significantly
affect its economic performance, and we (a) are obligated to absorb the losses that could be significant to the VIE or (b)
hold the right to receive benefits from the VIE that could be significant to the VIE. Intercompany accounts and
transactions have been eliminated.


Certain balances in the accompanying Consolidated Financial Statements for 2023 have been reclassified to
conform to current year presentations. We reclassified the asset, liability, revenue and expense balances in 2023
associated with Pilot Travel Centers LLC (“Pilot”) from the Railroad, Utilities and Energy sections of the Balance Sheet,
Statement of Earnings and Statement of Cash Flows to the Insurance and Other sections of those statements. We also
reclassified the balances within the affected Notes to the Consolidated Financial Statements. These reclassifications
conform presentations for comparability to presentations in 2024. These reclassifications had no effect on consolidated
total assets, liabilities, shareholders’ equity, revenues, expenses, or on net earnings or cash flows from the amounts
previously reported. See Note 1(y) for a summary of the reclassifications.


We continue to believe that reporting the railroad, utilities and energy subsidiaries separately in our Consolidated
Balance Sheets and Consolidated Statements of Earnings is appropriate, given relative significance of property, plant
and equipment, capital expenditures and debt. Further, these subsidiaries are not supported by Berkshire debt guarantees
or other financial commitments.


_(b)_ _Use of estimates in preparation of financial statements_


We prepare our Consolidated Financial Statements in conformity with accounting principles generally accepted in
the United States (“GAAP”), which requires us to make estimates and assumptions that affect the reported amounts of
certain assets and liabilities at the balance sheet date and the reported amounts of certain revenues and expenses during
the period. Our estimates of unpaid losses and loss adjustment expenses for property and casualty insurance claims are
subject to considerable estimation error due to the inherent uncertainty in projecting ultimate claim costs. In addition,
estimates and assumptions associated with determinations of deferred charges on retroactive reinsurance contracts, fair
values of certain financial instruments and evaluations of goodwill and indefinite-lived intangible assets for impairment
require considerable judgment. Additionally, significant estimates may be required in the evaluation of certain other
long-lived assets for impairments and the recognition of expected credit losses on amounts owed to us. Estimates may
be subject to significant adjustments in future periods due to ongoing macroeconomic and geopolitical events, as well as
changes in industry or company-specific factors or events. Actual results may differ from the estimates used in preparing
our Consolidated Financial Statements.


_(c)_ _Cash and cash equivalents and short-term investments in U.S. Treasury Bills_


Cash equivalents consist of demand deposit and money market accounts and investments with maturities of three
months or less when purchased. Short-term investments in U.S. Treasury Bills have maturities exceeding three months
and less than one year at the time of purchase.


K-71


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(d)_ _Investments in fixed maturity securities_


We classify investments in fixed maturity securities on the acquisition date and at each balance sheet date.
Securities classified as held-to-maturity are carried at amortized cost, reflecting the ability and intent to hold the securities
to maturity. Securities classified as trading are acquired with the intent to sell in the near term and are carried at fair value
with changes in fair value reported in earnings. All other securities are classified as available-for-sale and are carried at
fair value. Our investments in fixed maturity securities are classified as available-for-sale. We amortize the difference
between the original cost and maturity value of a fixed maturity security to earnings using the interest method.


We record investment gains and losses on available-for-sale fixed maturity securities in earnings when the
securities are sold. For securities in an unrealized loss position, we recognize a loss in earnings for the excess of amortized
cost over fair value if we intend to sell before the price recovers. As of the balance sheet date, we evaluate unrealized
losses, considering the severity of the decline in value, creditworthiness of the issuer and other relevant factors. We
record an allowance for credit losses, limited to the excess of amortized cost over fair value, with a corresponding charge
to earnings if the present value of estimated expected cash flows is less than the present value of contractual cash flows.
The allowance may be subsequently increased or decreased based on the prevailing facts and circumstances. The portion
of the unrealized loss that is not related to a credit loss is recognized in other comprehensive income.


_(e)_ _Investments in equity securities_


We carry investments in equity securities at fair value and record the changes in fair values in the Consolidated
Statements of Earnings as a component of investment gains and losses.


_(f)_ _Investments under the equity method_


We utilize the equity method to account for investments when we possess the ability to exercise significant
influence, but not control, over the operating and financial policies of the investee. The ability to exercise significant
influence is presumed when the investor possesses more than 20% of the voting interests of the investee. This
presumption may be overcome based on specific facts and circumstances that demonstrate that the ability to exercise
significant influence is restricted. We apply the equity method to investments in common stock and other investments
when such investments possess substantially identical subordinated interests to common stock, and do not apply the
equity method to investments that are not in-substance common stock as defined by GAAP.


In applying the equity method, we increase or decrease the carrying amount of the investment by our proportionate
share of the net earnings or losses and other comprehensive income of the investee. We record additional investments at
cost and equity distributions received as reductions in the carrying value of the investment. If net losses reduce our
carrying amount to zero, additional net losses may be recorded if other investments in the investee are at-risk, even if we
have not committed to provide financial support to the investee.


_(g)_ _Loans and finance receivables_


Loans and finance receivables are primarily manufactured home loans, and to a lesser extent, commercial loans
and site-built home loans. We carry substantially all loans and finance receivables at amortized cost, net of allowances
for expected credit losses, based on our ability and intent to hold such loans to maturity. Acquisition costs and loan
origination and commitment costs paid and fees received, as well as acquisition premiums or discounts, are capitalized
and accrued to investment income as yield adjustments over the lives of the loans.


Measurements of expected credit losses include provisions for non-collection, whether the risk is probable or
remote. Expected credit losses on manufactured home loans are based on the net present value of future principal
payments less estimated expenses related to the charge-off and foreclosure of expected uncollectible loans and include
provisions for loans that are not in foreclosure. Our principal credit quality indicator is whether the loans are performing.
Expected credit loss estimates consider historical default rates, collateral recovery rates, historical runoff rates, interest
rates, reductions of future cash flows for modified loans and the historical time elapsed from last payment until
foreclosure, among other factors. In addition, our estimates consider current conditions and reasonable and supportable
forecasts.


K-72


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(g)_ _Loans and finance receivables_


Loans are considered delinquent when payments are more than 30 days past due. We place loans over 90 days past
due on nonaccrual status and accrued but uncollected interest is reversed. Subsequent collections on the loans are first
applied to the principal and interest owed for the most delinquent amount. We resume interest income accrual once a
loan is less than 90 days delinquent.


Loans are considered non-performing when the foreclosure process has started. Once a loan is in the process of
foreclosure, interest income is not recognized until the foreclosure is cured or the loan is modified. Once a modification
is complete, interest income is recognized based on the terms of the new loan. Foreclosed loans are charged off when the
collateral is sold. Loans not in foreclosure are evaluated for charge-off based on individual circumstances concerning the
future collectability of the loan and the condition of the collateral securing the loan.


_(h)_ _Other receivables_


Other receivables include balances due from customers, insurance premiums receivable and reinsurance losses
recoverable, as well as other receivables. Trade receivables, insurance premiums receivables and other receivables are
primarily short-term in nature with stated collection terms of less than one year from the date of origination. Reinsurance
recoverables are comprised of amounts ceded under reinsurance contracts or pursuant to mandatory governmentsponsored insurance programs. Reinsurance recoverables arise from unpaid losses and loss adjustment expenses on
property and casualty claims and benefits under life and health contracts. Receivables are stated net of estimated
allowances for uncollectible balances.


We measure expected credit losses primarily utilizing credit loss history. In addition, our credit loss estimates
consider current conditions and reasonable and supportable forecasts. In evaluating expected credit losses of reinsurance
recoverables on unpaid losses, we review the credit quality of the counterparty and consider right-of-offset provisions
within reinsurance contracts and other forms of credit enhancement including collateral, guarantees and other available
information. We charge off receivables against the allowances after reasonable collection efforts are exhausted.


_(i)_ _Derivatives_


We carry assets and liabilities arising from derivative contracts at fair value in other assets and accounts payable,
accruals and other liabilities in our Consolidated Balance Sheets. Balances are net of reductions permitted under master
netting agreements with counterparties. We record the changes in fair value of derivative contracts that do not qualify as
hedging instruments for financial reporting purposes in earnings or if such contracts involve our regulated utilities
subsidiaries, as regulatory assets or liabilities when inclusion in regulated rates is probable.


_(j)_ _Fair value measurements_


Fair value is defined as the price that would be received to sell an asset or paid to transfer a liability between
market participants in the principal market or in the most advantageous market when no principal market exists.
Adjustments to transaction prices or quoted market prices may be required in illiquid or disorderly markets when
estimating fair value. In such circumstances, alternative valuation techniques may be appropriate to determine the value
that would be received to sell an asset or paid to transfer a liability in an orderly transaction. Market participants are
assumed to be independent, knowledgeable, and able and willing to transact an exchange and not acting under duress.
Our nonperformance or credit risk is considered in determining the fair value of liabilities. Considerable judgment may
be required in interpreting market data used to develop the estimates of fair value. Accordingly, estimates of fair value
presented herein are not necessarily indicative of the amounts that could be realized in a current or future market
exchange.


_(k)_ _Inventories_


Inventories consist of manufactured products, goods or products acquired for resale, materials and supplies and
homes constructed for sale. Manufactured inventory costs include materials, direct and indirect labor and factory
overhead. At December 31, 2024, we used the last-in-first-out (“LIFO”) method to value 32% of consolidated inventories
with the remainder primarily determined under first-in-first-out and average cost methods. Non-LIFO inventories are
stated at the lower of cost or net realizable value. The excess of current or replacement costs over costs determined under
LIFO was approximately $2.3 billion as of December 31, 2024 and December 31, 2023.


K-73


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(l)_ _Property, plant and equipment and equipment held for lease_


We use property, plant and equipment in our operations. We also own equipment that we lease to others under
lease contracts. We record additions, improvements and betterments to such properties at cost. With respect to
constructed assets, all materials, direct labor and contract services as well as certain indirect costs, including interest over
the construction period, are capitalized. With respect to constructed assets that are subject to authoritative guidance for
regulated operations, capitalized costs also include an allowance for funds used during construction, which represents
the cost of equity funds used to finance the construction of the regulated facilities. Normal repairs and maintenance and
other costs that do not improve the property, extend its useful life or otherwise do not meet capitalization criteria are
charged to expense as incurred.


Depreciation expense of our regulated utilities and railroad is generally determined using group depreciation
methods where rates are based on periodic depreciation studies approved by the applicable regulator. Under group
depreciation, a composite rate is applied to the gross investment in a particular class of property, despite differences in
the service life or salvage value of individual property units within the same class. When such assets are retired or sold,
no gain or loss is recognized. Gains or losses on disposals of all other assets are recorded through earnings. Ranges of
estimated useful lives of depreciable assets unique to our railroad business are as follows: track structure and other
roadway – 10 to 100 years and locomotives, freight cars and other equipment – 6 to 45 years. Ranges of estimated useful
lives of assets unique to our utilities and energy businesses are as follows: utility generation, transmission and distribution
systems    - 5 to 80 years, interstate natural gas pipeline assets    - 3 to 80 years and independent power plants and other
assets – 2 to 50 years.


We depreciate property, plant and equipment used in operations by our other businesses to the estimated salvage
value primarily using the straight-line method over estimated service lives. Ranges of estimated service lives of
depreciable assets used in our other businesses are as follows: buildings and improvements – 5 to 50 years, machinery
and equipment   - 3 to 30 years and furniture, fixtures and other   - 4 to 15 years. We depreciate the equipment held for
lease to estimated salvage value primarily using the straight-line method over estimated useful lives ranging from 3 to
35 years. We use declining balance depreciation methods for assets when the revenue-earning power of the asset is
greater during the earlier years of its life.


We evaluate property, plant and equipment and equipment held for lease for impairment when events or changes
in circumstances indicate that the carrying value of such assets may not be recoverable or when the assets are held for
sale. Upon the occurrence of a triggering event, we assess whether the estimated undiscounted cash flows expected from
the use of the asset and the residual value from the ultimate disposal of the asset exceeds the carrying value. If the
carrying value exceeds the estimated recoverable amounts, we reduce the carrying value to fair value and record an
impairment loss in earnings, except with respect to impairment of assets of our regulated utility and energy subsidiaries
where the impacts of regulation are considered in evaluating the carrying value.


_(m)_ _Leases_


We are party to contracts where we lease property from others. When we lease assets from others, we record rightof-use assets and lease liabilities. Right-of-use assets represent our right to use an underlying asset for the lease term and
lease liabilities represent our obligation to make lease payments arising from the lease. In this regard, lease payments
include fixed payments and variable payments that depend on an index or rate. The lease term is considered the noncancellable lease period. Certain lease contracts contain renewal options or other terms that provide variable payments
based on performance or usage. Options are not included in determining right-of-use assets or lease liabilities unless it
is reasonably certain that options will be exercised. Generally, incremental borrowing rates are used in measuring lease
liabilities. Right-of-use assets are subject to review for impairment. As permitted under GAAP, for some leases we do
not separate lease components from non-lease components by class of asset and we do not record assets or liabilities for
leases with terms of one year or less.


K-74


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(n)_ _Goodwill and other intangible assets_


Goodwill represents the excess of the acquisition price of a business over the acquisition date values of identified
net assets of that business. We evaluate goodwill for impairment at least annually. When evaluating goodwill for
impairment, we estimate the fair value of the reporting unit. Several methods may be used to estimate a reporting unit’s
fair value, including market quotations, asset and liability fair values and other valuation techniques, including, but not
limited to, discounted projected future net earnings or net cash flows and multiples of earnings. When the carrying
amount of a reporting unit, including goodwill, exceeds the estimated fair value, the excess up to the balance of goodwill
is charged to earnings as an impairment loss.


Other intangible assets with indefinite lives are also tested for impairment at least annually and when events or
changes in circumstances indicate that, more likely-than-not, the asset is impaired. When the asset carrying value exceeds
fair value, the excess is charged to earnings as an impairment loss. Significant judgment is required in estimating fair
values and evaluating goodwill and indefinite-lived intangible assets for impairment. We amortize intangible assets with
finite lives in a pattern that reflects the expected consumption of related economic benefits or on a straight-line basis
over the estimated economic useful lives. Intangible assets with finite lives are reviewed for impairment when events or
changes in circumstances indicate that the carrying amount may not be recoverable.


_(o)_ _Revenue recognition_


We earn insurance premiums on prospective property/casualty insurance and reinsurance contracts over the loss
exposure or coverage period in proportion to the level of protection provided. We earn such premiums, in most cases
ratably, over the term of the contract with unearned premiums computed on a monthly or daily pro-rata basis. Premiums
on retroactive property/casualty reinsurance contracts are normally received in full and are fully earned at the inception
of the contracts, as all underlying loss events covered by the policies occurred prior to contract inception. Premiums for
life reinsurance and periodic payment annuity contracts are earned when due. Premiums for periodic payment annuity
contracts are received in full and fully earned at the inception of the contracts. Premiums earned are stated net of amounts
ceded to reinsurers. Premiums earned on contracts with experience-rating provisions reflect estimated loss experience
under such contracts.


Sales and service revenues are recognized when goods or services are transferred to a customer. A good or service
is transferred when (or as) the customer obtains control of that good or service. Revenues are based on the consideration
we expect to receive in connection with our promises to deliver goods and services to our customers.


We manufacture and/or distribute a wide variety of industrial, building and consumer products. We also sell fuels,
including diesel, gasoline and related products, on a retail and wholesale basis.


Our sales contracts provide customers with products directly or through wholesale and retail channels in exchange
for consideration specified under the contracts. Contracts generally represent customer orders for individual products at
stated prices. Sales contracts may contain either single or multiple performance obligations. In instances where contracts
contain multiple performance obligations, we allocate the revenue to each obligation based on the relative stand-alone
selling prices of each product or service.


Sales revenues reflect reductions for returns, allowances, late delivery penalties, volume discounts and other
incentives, some of which may be contingent on future events. In certain customer contracts, sales revenues include
certain state and local excise taxes billed to customers on specified products when those taxes are levied directly upon
us by the taxing authorities. Sales revenues exclude sales taxes and value-added taxes collected on behalf of taxing
authorities. Sales revenues include consideration for shipping and other fulfillment activities performed prior to the
customer obtaining control of the goods. We also elect to treat consideration for such services that are performed after
control has passed to the customer as sales revenue.


Product sales revenues are generally recognized at a point in time when control of the product transfers to the
customer, which coincides with customer pickup or product delivery or acceptance, depending on terms of the
arrangement. We recognize sales revenues and related costs over time with respect to certain contracts, including certain
bridge and structural steel, castings, forgings and aerostructures contracts. Control of the product units under these
contracts transfers continuously to the customer as the product is manufactured. These products generally have no
alternative use and the contract requires the customer to provide reasonable compensation if terminated for reasons other
than breach of contract.


K-75


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(o)_ _Revenue recognition_


The primary performance obligation under our freight rail transportation service contracts is to move freight from
a point of origin to a point of destination. The performance obligations are represented by bills of lading which create a
series of distinct services that have a similar pattern of transfer to the customer. The revenues for each performance
obligation are based on various factors including the product being shipped, the origin and destination pair and contract
incentives, which are outlined in various private rate agreements, common carrier public tariffs, interline foreign road
agreements and pricing quotes. The transaction price is generally a per car/unit amount to transport railcars from a
specified origin to a specified destination. Freight revenues are recognized over time as the service is performed because
the customer simultaneously receives and consumes the benefits of the service. Revenues recognized represent the
portion of the service completed as of the balance sheet date. Invoices for freight transportation services are generally
issued to customers and paid within 30 days or less. Customer incentives, which are primarily provided for shipping a
specified cumulative volume or shipping to/from specific locations, are recorded as a reduction to revenue on a pro-rata
basis based on actual or projected future customer shipments.


Utilities and energy revenues derive primarily from regulated electricity and natural gas sales. Regulated electricity
and natural gas revenues are primarily tariff-based sales arrangements approved by various regulatory commissions.
These tariff-based revenues are mainly comprised of energy, transmission, distribution and natural gas and have
performance obligations to deliver energy products and services to customers which are satisfied over time as energy is
delivered or services are provided. Such revenues are equivalent to the amounts we have the right to invoice and
correspond directly with the value to the customer of the performance to date and include billed and unbilled amounts.
Payments from customers are generally due within 30 days of billing. Rates charged for regulated energy products and
services are established by regulators or contractual arrangements that establish the transaction price, as well as the
allocation of price among the separate performance obligations. When preliminary regulated rates are permitted to be
billed prior to final approval by the applicable regulator, certain revenue collected may be subject to refund and a liability
for estimated refunds is accrued.


Other service revenues derive from contracts with customers in which performance obligations are satisfied over
time, where customers receive and consume benefits as we perform the services or at a point in time when the services
are completed. Other service revenues primarily derive from real estate brokerage, construction management and
consulting, automotive repair, aircraft management, aviation training, franchising activities and news distribution.


Leasing revenue is generally recognized ratably over the term of the lease or based on usage, if applicable under
the terms of the contract. A substantial portion of our lessor contracts are classified as operating leases.


_(p)_ _Losses and loss adjustment expenses_


We record liabilities for unpaid losses and loss adjustment expenses under property and casualty insurance and
reinsurance contracts for loss events that have occurred on or before the balance sheet date. Such liabilities represent the
undiscounted estimated ultimate payment amounts.


We base liability estimates on (1) loss reports from policyholders and cedents, (2) individual case estimates and
(3) estimates of incurred but not reported losses. Losses and loss adjustment expenses in the Consolidated Statements of
Earnings include paid claims, claim settlement costs and changes in estimated claim liabilities. Losses and loss
adjustment expenses in the Consolidated Statements of Earnings are stated net of amounts recovered and estimates of
amounts recoverable ceded under reinsurance contracts. Reinsurance contracts do not relieve the ceding company of its
obligations to indemnify policyholders with respect to the underlying insurance and reinsurance contracts.


_(q)_ _Retroactive reinsurance contracts_


We record liabilities for unpaid losses and loss adjustment expenses under short-duration retroactive reinsurance
contracts consistent with property and casualty contracts described in Note 1(p). With respect to retroactive reinsurance
contracts, we also record deferred charge assets at the inception of the contracts, representing the excess, if any, of the
estimated ultimate claim liabilities over the premiums earned. We subsequently adjust deferred charge assets as of the
balance sheet date based on changes in the estimated timing and amount of ultimate loss payments, with retrospective
application to the inception of the contract using the interest method. The resulting changes in deferred charge assets are
included as a component of insurance losses and loss adjustment expenses in the Consolidated Statements of Earnings.


K-76


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(r)_ _Insurance policy acquisition costs_


Deferred policy acquisition costs are included in other assets and were approximately $4.6 billion at December 31,
2024 and 2023, of which $3.9 billion in each year related to property and casualty insurance contracts. We capitalize the
direct incremental costs that relate to the successful sale of insurance contracts, subject to ultimate recoverability. Direct
incremental acquisition costs include commissions, premium taxes and certain other costs associated with successful
efforts. We expense all other underwriting costs as incurred. For short-duration property and casualty insurance contracts,
deferred policy acquisition costs are reflected in expenses over the contract term as the related premiums are earned. For
long-duration life contracts, we expense deferred policy acquisition costs at a constant level based on the expected
amount of insurance in-force and the expected term of the contract using the assumptions consistent with those used in
determining related insurance liabilities.


_(s)_ _Life, annuity and health insurance benefits_


Liabilities for life, annuity and health insurance benefits under long-duration insurance contracts represent the
present value of expected future cash outflows from future benefit payments and certain non-acquisition costs, less the
present value of expected future “net premiums,” which is the portion of gross premiums required to provide for all
expected future benefits and variable expenses. Periodic payment and annuity reinsurance contracts are regarded as
limited payment contracts. Such liabilities include the present value of expected future payments based on the discount
rates used to measure benefit liabilities and deferred profit liabilities, which are based on the excess of gross premiums
received over the net premiums established at the inception of the contract.


In estimating future cash flows, we consider the timing and amount of future claims, premiums and expenses,
which require estimates of expected mortality, morbidity and lapse rates. Cash flow assumptions are reviewed at least
annually, with the effects of assumption changes recorded in earnings. The discount rate assumptions used to measure
benefit liabilities are revised each reporting period based on the prevailing upper-medium-grade corporate bond yields
(generally single-A rated credit ratings) that reflect the duration and currency attributes of the liabilities. In measuring
benefit liabilities, we generally group contracts by contract issue year. The effects of changes in discount rates are
recorded in accumulated other comprehensive income.


_(t)_ _Regulated utilities and energy businesses_


Certain regulated utility and energy subsidiaries prepare their financial statements in accordance with authoritative
guidance for regulated operations, reflecting the economic effects of regulation from the ability to recover certain costs
from customers and the requirement to return revenues to customers in the future through the regulated rate-setting
process. Accordingly, certain costs are deferred as regulatory assets and certain income is accrued as regulatory liabilities.


Regulatory assets and liabilities are subsequently amortized into operating expenses and revenues over various
future periods. Regulatory assets and liabilities are continually assessed for probable future inclusion in regulatory rates
by considering factors such as applicable regulatory or legislative changes and recent rate orders received by other
regulated entities. If future inclusion in regulatory rates ceases to be probable, the amount no longer probable of inclusion
in regulatory rates is charged or credited to earnings (or other comprehensive income, if applicable) or returned to
customers.


_(u)_ _Foreign currency_


The accounts of certain subsidiaries are measured using functional currencies other than the U.S. Dollar. Revenues
and expenses in the financial statements of these subsidiaries are translated into U.S. Dollars at the average exchange
rate for the period and assets and liabilities are translated at the exchange rate as of the end of the reporting period. The
net effects of translating the financial statements of these subsidiaries are included in shareholders’ equity as a component
of accumulated other comprehensive income. Gains and losses arising from transactions denominated in a currency other
than the functional currency of the entity, including gains and losses from the remeasurement of assets and liabilities due
to changes in currency exchange rates, are included in earnings.


K-77


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(v)_ _Income taxes_


Berkshire files a consolidated federal income tax return in the U.S. with eligible subsidiaries. In addition, we file
income tax returns in U.S. state and local and foreign jurisdictions. Provisions for current income tax liabilities are
calculated and accrued on income and expense amounts expected to be included in the income tax returns for the current
year. Income taxes reported in earnings also include deferred income tax provisions.


Deferred income tax assets and liabilities are computed on differences between the financial statement bases and
tax bases of assets and liabilities at the enacted tax rates. Changes in deferred income tax assets and liabilities associated
with components of other comprehensive income are charged or credited directly to other comprehensive income.
Otherwise, changes in deferred income tax assets and liabilities are included as a component of income tax expense. The
effect on deferred income tax assets and liabilities attributable to changes in enacted tax rates are charged or credited to
income tax expense in the period of enactment. Valuation allowances are established for certain deferred income tax
assets when realization is deemed to be unlikely.


Liabilities are established for uncertain tax positions taken or positions expected to be taken in income tax returns
when such positions, in our judgment, do not meet a more-likely-than-not threshold based on the technical merits of the
positions. Estimated interest and penalties related to uncertain tax positions are included as a component of income tax
expense.


_(w)_ _Accounting pronouncements adopted in 2024_


We adopted the Financial Accounting Standards Board (“FASB”) Accounting Standards Update 2023-02,
“Accounting for Investments in Tax Credit Structures Using the Proportional Amortization Method” (“ASU 2023-02”).
ASU 2023-02 permits reporting entities to elect to account for tax equity investments from which the income tax credits
are received using the proportional amortization method at the program level if certain conditions are met. We elected to
apply the proportional accounting method to eligible affordable housing tax credit investments using the modified
retrospective method. We recorded a charge to retained earnings of $127 million, representing the cumulative effect of
applying the proportional method to these investments as of January 1, 2024.


We adopted FASB Accounting Standards Update 2023-07, “Improvements to Reportable Segment Disclosures”
(“ASU 2023-07”) beginning December 31, 2024. ASU 2023-07 requires disclosures of significant expenses by segment
and interim disclosure of items that were previously required only on an annual basis. We adopted ASU 2023-07
retrospectively with such disclosures included in Note 26 to the accompanying Consolidated Financial Statements.


_(x)_ _Accounting pronouncements to be adopted subsequent to December 31, 2024_


In December 2023, the FASB issued Accounting Standards Update 2023-09, “Improvements to Income Tax
Disclosures” (“ASU 2023-09”), which provides for additional income tax rate reconciliation and income taxes paid
disclosures. ASU 2023-09 may be adopted on a prospective or retrospective basis and is effective for fiscal years
beginning after December 15, 2024, with early adoption permitted.


In November 2024, the FASB issued Accounting Standards Update 2024-03, “Disaggregation of Income
Statement Expenses” (“ASU 2024-03”), which requires detailed disclosure in the notes to the financial statements of
specific categories underlying certain expense captions on the income statement. ASU 2024-03 may be adopted on a
prospective or retrospective basis and is effective for fiscal years beginning after December 15, 2027, with early adoption
permitted.


On March 6, 2024, the U.S. Securities Exchange Commission (“SEC”) issued Release No. 33-11275 and No. 3499678 “The Enhancement and Standardization of Climate-Related Disclosures for Investors” (“Climate Disclosure
Rules”). Among its provisions, the Climate Disclosure Rules will require certain disclosures related to severe weather
events and other natural conditions, and other disclosures about climate-related risks that materially impacted or are
reasonably likely to materially impact the business strategy, results of operations or financial condition of the registrant.
The Climate Disclosure Rules were to become effective for large-accelerated SEC filers in annual reports for years
beginning on or after January 1, 2025. However, on April 4, 2024, the SEC stayed implementation of the Climate
Disclosure Rules, which remains in place pending the completion of an ongoing judicial review.


K-78


---

**Notes to Consolidated Financial Statements**


**(1)** **Significant accounting policies and practices**


_(y)_ _Reclassifications of certain balances in 2023_


A summary of reclassifications to the amounts previously reported in our Consolidated Balance Sheet and
Statement of Earnings as of and for the year ended December 31, 2023 associated with Pilot’s balance sheet, revenue
and expense accounts are summarized below. We also reclassified the December 31, 2023 amounts in the applicable
Notes to the Consolidated Financial Statements. The reclassifications to the Consolidated Statement of Cash Flows for
the year ended December 31, 2023 were immaterial. These reclassifications conform presentations of balances in 2023
for comparability to current year presentations. Amounts are in millions.


K-79


---

**Notes to Consolidated Financial Statements**


**(2)** **Significant business acquisitions and other transactions**


Our long-held acquisition strategy is to acquire businesses that have consistent earning power, good returns on equity
and able and honest management. Financial results attributable to business acquisitions are included in our Consolidated
Financial Statements beginning on their respective acquisition dates.


On January 31, 2023, we acquired an additional 41.4% interest in Pilot Travel Centers, LLC (“Pilot”) for approximately
$8.2 billion. The acquisition increased our interest to 80%, representing a controlling interest in Pilot for financial reporting
purposes as of that date. Accordingly, we began consolidating Pilot’s financial statements in our Consolidated Financial
Statements on February 1, 2023. Prior to that date, we accounted for our 38.6% interest in Pilot under the equity method.


Pilot operates travel centers and fuel-only retail locations across the U.S. and in five Canadian provinces, primarily under
the names Pilot or Flying J, as well as large wholesale fuel and fuel marketing businesses in the U.S. Pilot also sells diesel fuel
at other locations in the U.S. and Canada through various arrangements with third party travel centers and operates a water
disposal business in the oil fields sector.


In applying the acquisition method of accounting, we remeasured our previously held 38.6% investment in Pilot to fair
value as of the acquisition date. We recognized a one-time, non-cash remeasurement gain of approximately $3.0 billion in the
first quarter of 2023, representing the excess of the fair value of that interest over the carrying value under the equity method.


In January 2024, we acquired the remaining noncontrolling interests in Pilot for $2.6 billion, increasing our ownership
of Pilot to 100%. The acquisition of a noncontrolling interest represents an equity transaction and we recorded an increase of
$517 million to capital in excess of par value for the excess of the carrying value of the noncontrolling interest acquired over
the consideration paid, net of deferred income tax liabilities arising from the transaction.


A summary of the values of Pilot’s assets acquired, liabilities assumed and noncontrolling interests as of January 31,
2023 follows (in millions).


——————

_* Goodwill from this acquisition is expected to be deductible for income tax purposes._


On October 19, 2022, Berkshire acquired all of the outstanding common stock of Alleghany Corporation (“Alleghany”)
for $11.5 billion, which operates property and casualty insurance and reinsurance businesses. Acquired assets were $35.6
billion, including cash and investments of $19.7 billion and goodwill of $3.9 billion, which is not expected to be deductible for
income tax purposes. Liabilities were $24.1 billion, including unpaid losses and loss adjustment expenses of $15.1 billion.


Certain unaudited pro forma revenue and consolidated earnings (loss) data for the year ended December 31, 2022 as if
the Alleghany and Pilot acquisitions were completed on the same terms at the beginning of 2022 follows (in millions, except
per share amounts).


On September 30, 2024, Berkshire Hathaway Energy Company (“BHE”) repurchased 5.85% of its outstanding common
stock held by certain noncontrolling BHE shareholders for $2.9 billion. We recorded the difference between the value of the
consideration paid for the noncontrolling interests acquired and the carrying value in capital in excess of par value.


Additionally, in September and October 2024, Berkshire acquired the remaining 2.12% of BHE’s outstanding common
stock held by noncontrolling shareholders in exchange for 2,291,631 shares of Berkshire Class B common stock valued at
$1.045 billion. After these transactions, BHE became a wholly-owned subsidiary of Berkshire.


K-80


---

**Notes to Consolidated Financial Statements**


**(2)** **Significant business acquisitions and other transactions**


On September 1, 2023, a BHE subsidiary acquired an additional 50% limited partner interest in Cove Point LNG, LP
(“Cove Point”) for $3.3 billion, which increased our economic interest from 25% to 75%. Prior to the transaction, we also held
100% of the general partner interest and we consolidated Cove Point for financial reporting purposes. Accordingly, the interest
acquired was an acquisition of a noncontrolling interest. We recorded a charge of $667 million in 2023 to our capital in excess
of par for the excess of the consideration paid over the carrying value of the noncontrolling interest acquired and deferred
income tax assets arising from the transaction.


**(3)** **Investments in fixed maturity securities**


Investments in fixed maturity securities are summarized by type below (in millions).


As of December 31, 2024, approximately 94% of our foreign government holdings were rated AA or higher by at least
one of the major rating agencies. The amortized cost and estimated fair value of fixed maturity securities at December 31, 2024
are summarized below by contractual maturity dates (in millions). Actual maturities may differ from contractual maturities due
to prepayment rights held by issuers.


**(4)** **Investments in equity securities**


Investments in equity securities are summarized as follows (in millions).


K-81


---

**Notes to Consolidated Financial Statements**


**(4)** **Investments in equity securities**


Our investments in equity securities over the years have been concentrated in relatively few companies. The fair value
of our five largest holdings at December 31, 2024 and 2023 represented 71% and 79%, respectively, of the aggregate fair value
of our equity securities shown in the preceding tables. The five largest holdings at each date were American Express Company,
Apple Inc., Bank of America Corporation, The Coca-Cola Company and Chevron Corporation.


Since 2019, we have also owned non-voting Cumulative Perpetual Preferred Stock of Occidental Petroleum Corporation
(“Occidental”) and Occidental common stock warrants. Our investments in the Occidental preferred stock and Occidental
common stock warrants are recorded at fair value and included as equity securities in our Consolidated Balance Sheets, as such
investments are not in-substance common stock under GAAP and are not eligible for the equity method. We account for our
investment in Occidental common stock under the equity method. See Note 5.


The Occidental preferred stock accrues dividends at 8% per annum and is redeemable at the option of Occidental
commencing in 2029 at a redemption price equal to 105% of the liquidation value. As of December 31, 2024, our investment
in Occidental preferred stock had an aggregate liquidation value of approximately $8.5 billion. During 2023, Occidental issued
mandatory redemption notifications for approximately $1.5 billion of the aggregate liquidation value due to excess distributions
by Occidental to its common stockholders, as defined under the terms of the Occidental preferred stock certificate of
designations.


The Occidental common stock warrants allow us to purchase up to 83.86 million shares of Occidental common stock at
an exercise price of $59.62 per share. The warrants are exercisable in whole or in part until one year after the date the preferred
stock is fully redeemed.


As of December 31, 2024, we owned 151.6 million shares of American Express Company (“American Express”)
common stock representing 21.6% of the outstanding common stock of American Express. Since 1995, we have been party to
an agreement with American Express whereby we agreed to vote a significant portion of our shares in accordance with the
recommendations of the American Express Board of Directors. We have also agreed to passivity commitments as requested by
the Board of Governors of the Federal Reserve System, which collectively, in our judgment, restrict our ability to exercise
significant influence over the operating and financial policies of American Express. Accordingly, we do not use the equity
method with respect to our investment in American Express common stock and we continue to record our investment at fair
value.


**(5)** **Equity method investments**


Berkshire and its subsidiaries hold investments in certain businesses that are accounted for pursuant to the equity method.
The most significant of these are our investments in the common stock of The Kraft Heinz Company (“Kraft Heinz”) and
Occidental. We began acquiring common stock of Occidental in 2022 and our aggregate voting interest in Occidental common
stock exceeded 20% on August 4, 2022. We adopted the equity method as of that date. As of December 31, 2024, we owned
27.2% of the Kraft Heinz outstanding common stock and 28.2% of the outstanding Occidental common stock which excludes
the potential effect of the exercise of Occidental’s outstanding common stock warrants.


Kraft Heinz manufactures and markets food and beverage products, including condiments and sauces, cheese and dairy,
meals, meats, refreshment beverages, coffee and other grocery products. Occidental is an international energy company, whose
activities include oil and natural gas exploration, development and production, and chemicals manufacturing businesses.


We also own a 50% interest in Berkadia Commercial Mortgage LLC (“Berkadia”), which is included in other in the
following table. Jefferies Financial Group Inc. (“Jefferies”) owns the other 50% interest. Berkadia engages in mortgage
banking, investment sales and servicing commercial/multi-family real estate loans. Berkadia’s commercial paper borrowing
capacity (limited to $1.5 billion) is supported by a surety policy issued by a Berkshire insurance subsidiary. Jefferies is obligated
to indemnify us for one-half of any losses incurred under the policy.


The fair values and carrying values of these investments are included in the following table (in millions).


K-82


---

**Notes to Consolidated Financial Statements**


**(5)** **Equity method investments**


Kraft Heinz and Occidental common stocks are publicly traded. As of December 31, 2024, the excess of our carrying
value over the fair value of each of these investments based on their respective market prices was approximately 25% of the
carrying value. We evaluated these investments for other-than-temporary impairment as of December 31, 2024. For each
investment, we considered our ability and intent to hold the investment until the fair value exceeds carrying value, the
magnitude and duration of the decline in fair value, the operating results of the company, as well as other factors. Based on the
prevailing facts and circumstances, we concluded the recognition of an impairment charge in earnings was not required.


As of December 31, 2024, the carrying values of our investments in Kraft Heinz and Berkadia approximated our share
of shareowners’ equity of each of these entities. The carrying value of our investment in Occidental common stock exceeded
our share of its shareholders’ equity as of September 30, 2024 by approximately $9.9 billion. Based upon the limited
information available to us, we concluded the excess represents goodwill.


As described in Note 2, we ceased accounting for Pilot under the equity method as of February 1, 2023. Equity method
earnings attributable to Pilot were $105 million for the month ending January 31, 2023 and are reported in other in the following
table. Occidental’s financial information is not available in time for concurrent reporting in our Consolidated Financial
Statements. Therefore, we report the equity method effects for Occidental on a one-quarter lag. Our earnings and distributions
received from equity method investments are summarized in the following table (in millions).


Summarized consolidated financial information of Kraft Heinz follows (in millions).


Summarized consolidated financial information of Occidental follows (in millions).


K-83


---

**Notes to Consolidated Financial Statements**


**(6)** **Investment gains (losses)**


Investment gains (losses) for each of the three years ending December 31, 2024 are summarized as follows (in millions).


Equity securities gains and losses include unrealized gains and losses from changes in fair values during the year on
equity securities we still own, as well as gains and losses on securities we sold during the year. As shown in the Consolidated
Statements of Cash Flows, our proceeds from sales of equity securities were approximately $143.4 billion in 2024, $40.6 billion
in 2023 and $33.7 billion in 2022. In the preceding table, investment gains and losses on equity securities sold during the year
represent the difference between the sales proceeds and the fair value of the equity securities sold at the beginning of the
applicable year or, if later, the purchase date. Our taxable gains and losses on equity securities sold are generally the difference
between the proceeds from sales and cost at the acquisition date. Equity securities sold produced taxable gains of $101.1 billion
in 2024, $5.0 billion in 2023 and $769.0 million in 2022. Other investment gains included approximately $3.0 billion in 2023
from the remeasurement of our pre-existing 38.6% interest in Pilot through the application of acquisition accounting under
GAAP.


**(7)** **Loans and finance receivables**


Loans and finance receivables are summarized as follows (in millions).


Loans and finance receivables are principally manufactured home loans, and to a lesser extent, commercial loans and
site-built home loans. Reconciliations of the allowance for credit losses on loans and finance receivables for each of the three
years ending December 31, 2024 follow (in millions).


K-84


---

**Notes to Consolidated Financial Statements**


**(7)** **Loans and finance receivables**


At December 31, 2024, substantially all manufactured and site-built home loan balances were evaluated collectively for
impairment, and we considered approximately 96% of these loans to be current as to payment status. A summary of performing
and non-performing home loans, before discounts and credit loss allowances, by year of loan origination as of December 31,
2024 follows (in millions).


**(8)** **Other receivables**


Other receivables are comprised of the following (in millions).


Aggregate provisions for credit losses with respect to receivables in the preceding table were $469 million in 2024, $513
million in 2023 and $409 million in 2022. Charge-offs, net of recoveries, were $498 million in 2024, $474 million in 2023 and
$432 million in 2022.


**(9)** **Inventories**


Inventories of our insurance and other businesses are comprised of the following (in millions).


Inventories, materials and supplies of our railroad, utilities and energy businesses are included in other assets and were
approximately $3.0 billion at December 31, 2024 and $2.5 billion at December 31, 2023.


K-85


---

**Notes to Consolidated Financial Statements**


**(10)** **Property, plant and equipment**


A summary of property, plant and equipment of our insurance and other businesses follows (in millions).


A summary of property, plant and equipment of our railroad and utilities and energy businesses follows (in millions).
The utility generation, transmission and distribution systems and interstate natural gas pipeline assets are owned by regulated
public utility and natural gas pipeline subsidiaries.


Depreciation expense for each of the three years ending December 31, 2024 is summarized below (in millions).


K-86


---

**Notes to Consolidated Financial Statements**


**(11)** **Equipment held for lease**


Equipment held for lease includes railcars, aircraft, and other equipment, including over-the-road trailers, intermodal
tank containers, cranes, storage units and furniture. Equipment held for lease is summarized below (in millions).


Depreciation expense for equipment held for lease was $1,429 million in 2024, $1,266 million in 2023 and $1,209 million
in 2022. Operating lease revenues for each of the three years ending December 31, 2024 are summarized below (in millions).


A summary of future operating lease receipts as of December 31, 2024 follows (in millions).


**2025** **2026** **2027** **2028** **2029** **Thereafter** **Total**
$ 4,263 $ 3,455 $ 2,596 $ 1,724 $ 769 $ 339 $ 13,146


**(12)** **Leases**


We are party to contracts where we lease property from others under contracts classified as operating leases. We primarily
lease buildings, offices, facilities and equipment. Operating lease right-of-use assets are included in other assets and operating
lease liabilities are included in accounts payable, accruals and other liabilities. Information related to our operating leases
follows (dollars in millions).


A summary of our remaining future operating lease payments reconciled to lease liabilities as of December 31, 2024 and
December 31, 2023 follows (in millions).


Components of operating lease expense for each of the three years ending December 31, 2024 are summarized as follows
(in millions).


K-87


---

**Notes to Consolidated Financial Statements**


**(13)** **Goodwill and other intangible assets**


Reconciliations of the changes in the carrying value of goodwill during 2024 and 2023 follow (in millions).


_* Net of accumulated goodwill impairments of $11.5 billion as of December 31, 2024, $11.1 billion as of December 31, 2023_
_and $11.0 billion as of December 31, 2022._


Other intangible assets are summarized below (in millions).


Intangible assets of the railroad, utilities and energy businesses are included in other assets in our Consolidated Balance
Sheets.


Intangible assets with indefinite lives were $18.9 billion as of December 31, 2024 and December 31, 2023 and primarily
related to certain customer relationships and trademarks and trade names. Intangible asset amortization expense was $1.8 billion
in 2024 and 2023 and $1.2 billion in 2022. Estimated amortization expense over the next five years follows (in billions): 2025

- $1.7; 2026 – $1.6; 2027 – $1.4; 2028 – $1.4 and 2029 – $1.3.


**(14)** **Supplemental cash flow information**


A summary of supplemental cash flow information follows (in millions).


K-88


---

**Notes to Consolidated Financial Statements**


**(15)** **Dividend restrictions – Insurance subsidiaries**


Payments of dividends by our insurance subsidiaries are restricted by insurance statutes and regulations. Without prior
regulatory approval, our principal insurance subsidiaries may declare up to approximately $31 billion as ordinary dividends
during 2025. Investments in fixed maturity and equity securities and short-term investments on deposit with U.S. state insurance
authorities in accordance with state insurance regulations were approximately $5.6 billion at December 31, 2024 and $5.2
billion at December 31, 2023.


Combined shareholders’ equity of U.S.-based insurance subsidiaries determined pursuant to statutory accounting rules
(Surplus as Regards Policyholders) was approximately $310 billion at December 31, 2024 and $303 billion at December 31,
2023. Statutory surplus differs from the corresponding amount based on GAAP due to differences in accounting for certain
assets and liabilities. For instance, the recognition of deferred charges on retroactive reinsurance, life, annuity and health
insurance benefits liabilities, deferred policy acquisition costs, unrealized gains on certain investments and deferred income
taxes under GAAP differs from recognition under U.S. statutory reporting. In addition, the carrying values of certain assets,
such as goodwill and non-insurance entities owned by our insurance subsidiaries, are not fully recognized for statutory reporting
purposes.


**(16)** **Unpaid losses and loss adjustment expenses**


Reconciliations of the changes in unpaid losses and loss adjustment expenses (“claim liabilities”), excluding liabilities
under retroactive reinsurance contracts (see Note 17), for each of the three years ended December 31, 2024 follow (in millions).
Net liabilities of acquired businesses in 2022 related to the acquisition of Alleghany’s insurance companies in October 2022.


Our claim liabilities under property and casualty insurance and reinsurance contracts are based upon estimates of the
ultimate claim costs associated with claim events that have occurred as of the balance sheet date and include estimates for
incurred-but-not-reported (“IBNR”) claims. Losses and loss adjustment expenses incurred shown in the preceding table related
to events occurring in the current year (“current accident year”) and events occurring in all prior years (“prior accident years”).
Losses and loss adjustment expenses incurred and paid are net of reinsurance recoveries. Current accident year incurred losses
included losses from significant catastrophe events (losses exceeding $150 million per event) of approximately $1.5 billion in
2024, $925 million in 2023 and $3.1 billion in 2022. Current accident year incurred losses for private passenger auto insurance
declined in 2024 compared to 2023, reflecting lower claims frequencies and higher average claims severities. Current accident
year incurred losses in 2023 also reflected a decline in private passenger auto insurance losses and the impact of the Alleghany
acquisition compared to 2022.


K-89


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


We recorded net reductions of estimated ultimate liabilities for prior accident years of $2.3 billion in 2024, $3.5 billion
in 2023 and $2.7 billion in 2022, which produced corresponding reductions in losses and loss adjustment expenses incurred in
those periods. These reductions, as percentages of the net liabilities at the beginning of each year, were 2.2% in 2024, 3.5% in
2023 and 3.2% in 2022.


Estimated ultimate liabilities for prior accident years of our primary insurance businesses declined $602 million in 2024,
$2.1 billion in 2023 and $1.1 billion in 2022. The decline in estimated liabilities in 2024 reflected lower-than-expected private
passenger auto, medical professional liability and property losses, partially offset by increased casualty losses. The estimated
liability reductions in 2023 and 2022 were primarily from private passenger auto, medical professional liability and property
coverages. Estimated ultimate liabilities for prior accident years of our reinsurance businesses were reduced $1.7 billion in
2024, $1.4 billion in 2023 and $1.6 billion in 2022. The reductions in 2024 and 2023 were primarily attributable to lower-thanexpected property losses, while the reductions in 2022 were attributable to both property and casualty losses.


Estimated net claim liabilities for environmental and asbestos exposures, excluding liabilities under retroactive
reinsurance contracts, were approximately $1.9 billion at December 31, 2024 and $2.0 billion at December 31, 2023. These
liabilities are subject to change due to changes in the legal and regulatory environment, among other factors. We are unable to
reliably estimate additional losses or a range of losses that are reasonably possible to arise from these factors.


Disaggregated information concerning our claim liabilities is provided below and in the pages that follow for GEICO,
Berkshire Hathaway Primary Group (“BH Primary”) and Berkshire Hathaway Reinsurance Group (“BHRG”). In this
discussion, “claim-tail” refers to the period between the claim occurrence date and claim settlement or payment date. A
reconciliation of the disaggregated net unpaid losses and allocated loss adjustment expenses (the latter referred to as “ALAE”)
to our consolidated claim liabilities as of December 31, 2024 follows (in millions).


_GEICO_


GEICO’s claim liabilities predominantly relate to various types of private passenger auto liability and physical damage
claims. For such claims, we establish and evaluate unpaid claim liabilities using standard actuarial loss development methods
and techniques. The actuarial methods utilize historical claims data, adjusted when deemed appropriate to reflect perceived
changes in loss patterns. Claim liabilities include average, case, case development and IBNR estimates.


Average liabilities are based on expected severities for newly reported physical damage and liability claims prior to
establishing individual case reserves when insufficient time or information is available for specific claim estimates and for
large volumes of minor physical damage claims that are quickly settled. Case loss estimates for liability claims, including
estimates for loss adjustment expenses, are based on the facts and merits of the claim.


Claim estimates for liability coverages normally reflect greater uncertainty than for physical damage coverages, primarily
due to the longer claim-tails, the greater chance of litigation and the time needed to evaluate facts at the time the case estimate
is first established. Consequently, additional case development liabilities are established, which are usually percentages of the
case liabilities. For unreported claims, IBNR claim liabilities are estimated by projecting the ultimate number of claims
expected (reported and unreported) for each significant coverage based on historical data, from which reported claims are
deducted to produce the estimated number of unreported claims. The product of the average cost per unreported claim and the
number of unreported claims produces the IBNR liability estimate. We may record supplemental IBNR liabilities in certain
situations when actuarial techniques are difficult to apply.


K-90


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


GEICO’s net auto physical damage and liability losses and ALAE incurred and paid are summarized by accident year
below. IBNR and case development liabilities are as of December 31, 2024 and are net of estimated salvage and subrogation
recoveries. Claim counts are established when accidents that could result in a liability are reported and are based on policy
coverage. Each claim event may generate claims under multiple coverages and may result in multiple counts. The “Cumulative
Number of Reported Claims” includes the combined number of reported claims for all auto policy coverages. Dollars are in
millions.


Physical Damage


Auto Liability


_* Unaudited required supplemental information_


K-91


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


_BH Primary_


BH Primary’s liabilities for unpaid losses and loss adjustment expenses primarily derive from medical professional
liability and workers’ compensation and other casualty insurance, which includes commercial auto and general liability
insurance. Net losses and ALAE incurred and paid are summarized by accident year in the following tables, disaggregated by
medical professional liability and workers’ compensation and other casualty coverages. IBNR and case development liabilities
are as of December 31, 2024. The cumulative number of reported claims reflects the number of individual claimants and
includes claims that ultimately resulted in no liability or payment. Dollars are in millions.


Medical Professional Liability


Estimates of the ultimate expected losses and loss adjustment expenses incurred for medical professional claim liabilities
are based on a variety of commonly accepted actuarial methodologies, such as the paid and incurred development method and
Bornhuetter-Ferguson based methods, as well as other techniques that consider insured loss exposures and historical and
expected loss trends, among other factors. These methodologies produce loss estimates from which we determine our best
estimate. In addition, we study developments in older accident years and adjust initial loss estimates to reflect recent
developments based upon claim age, coverage and litigation experience.


_* Unaudited required supplemental information_


K-92


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


Workers’ Compensation and Other Casualty


We evaluate ultimate loss and loss adjustment expense estimates for workers’ compensation and other casualty claims
using a combination of commonly accepted actuarial methodologies such as the Bornhuetter-Ferguson and chain-ladder
approaches using paid and incurred loss data. Paid and incurred loss data is segregated and analyzed by state due to the different
state regulatory frameworks that may impact the duration and amount of loss payments. We also separately study the various
components of liabilities, such as employee lost wages, medical expenses and the costs of claims investigations and
administration. We establish case liabilities for reported claims based upon the facts and circumstances of the claim. The excess
of the ultimate projected losses, including the case development estimates over the case-basis liabilities, is included in IBNR
liabilities.


_* Unaudited required supplemental information_


_BHRG_


We use a variety of methodologies to establish BHRG’s estimates for property and casualty claim liabilities. These
methodologies include paid and incurred loss development techniques, incurred and paid loss Bornhuetter-Ferguson techniques
and frequency and severity techniques, as well as ground-up techniques when appropriate.


K-93


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


Our claim liabilities are principally a function of reported losses from ceding companies, case development and IBNR
liability estimates. Case loss estimates are reported either individually or in bulk as provided under the terms of the contracts.
We may independently evaluate case losses reported by the ceding company, and if deemed appropriate, establish additional
case liabilities based on our estimates.


Estimated IBNR liabilities are affected by expected case loss emergence patterns and expected loss ratios, which are
evaluated as groups of contracts with similar exposures or on a contract-by-contract basis. Estimated case and IBNR liabilities
for major catastrophe events are generally based on a per-contract assessment of the ultimate cost associated with the individual
loss event. Claim count data is not provided consistently by ceding companies under our contracts or is otherwise considered
unreliable.


BHRG’s net losses and ALAE incurred and paid are disaggregated and summarized by accident year based on losses
that are expected to have shorter claim-tails (property) and losses expected to have longer claim-tails (casualty). Under certain
contracts, the coverage can apply to multiple lines of business written by the ceding company, whether property, casualty or
combined, and the ceding company may not report loss data by such lines consistently, if at all. In those instances, we allocated
losses to property and casualty coverages based on internal estimates. IBNR and case development liabilities are as of December
31, 2024. Dollars are in millions.


Property


_* Unaudited required supplemental information_


K-94


---

**Notes to Consolidated Financial Statements**


**(16)** **Unpaid losses and loss adjustment expenses**


Casualty


_* Unaudited required supplemental information_


Required supplemental unaudited average historical claims duration information based on the net losses and ALAE
incurred and paid accident year data in the preceding tables follows. The percentages show the average portions of net losses
and ALAE paid by each succeeding year, with year 1 representing the current accident year.


K-95


---

**Notes to Consolidated Financial Statements**


**(17)** **Retroactive reinsurance contracts**


Retroactive reinsurance policies provide indemnification of losses and loss adjustment expenses of short-duration
insurance contracts with respect to underlying loss events that occurred prior to the contract inception date. Exposures may
include significant asbestos, environmental and other mass tort claims. Retroactive reinsurance contracts are generally subject
to aggregate policy limits and thus, our exposure to such claims under these contracts is likewise limited. Reconciliations of
the changes in estimated liabilities for retroactive reinsurance unpaid losses and loss adjustment expenses for each of the three
years ended December 31, 2024 follow (in millions).


We classify incurred and paid losses and loss adjustment expenses based on the inception dates of the contracts, which
reflect when our exposure to losses began. We believe that analysis of losses incurred and paid by the accident year of the
underlying event is irrelevant given that our exposure to losses incepted when the contract incepted. We also believe that the
classification of reported claims and case development liabilities has little or no practical analytical value. Substantially all of
the losses and loss adjustment expenses incurred and paid related to contracts written in prior years.


Losses and loss adjustment expenses incurred include changes in estimated ultimate liabilities and related adjustments
to deferred charge assets arising from the changes in the estimated timing and amount of loss payments. In 2023, we increased
estimated ultimate liabilities under certain contracts by $1.1 billion, primarily attributable to revised estimates for asbestos,
environmental and other casualty claims. Including the adjustments to related deferred charge assets, the increase in ultimate
liabilities produced a net expense of approximately $650 million in 2023. Deferred charge assets on retroactive reinsurance
contracts were $8.8 billion at December 31, 2024 and $9.5 billion at December 31, 2023.


In establishing retroactive reinsurance claim liabilities, we analyze historical aggregate loss payment patterns and project
losses under various probability-weighted scenarios. We expect the claim-tails for many contracts to be very long, with some
lasting several decades. We monitor claim payment activity and review ceding company reports and other information
concerning the underlying losses. We revise the expected timing and amounts of ultimate losses periodically or when significant
events occur.


We monitor evolving case law and its effect on asbestos, environmental and other mass tort claims. Changing laws or
government regulations, as well as newly identified toxins and injury events, newly reported claims, new theories of liability,
new contract interpretations and other factors could result in increases in these liabilities, which could be material to our results
of operations. We are unable to reliably estimate the amount of additional net loss or the range of net loss that is reasonably
possible. Our estimates of ultimate liabilities for asbestos and environmental exposures under our contracts were approximately
$11.9 billion at December 31, 2024 and $12.2 billion at December 31, 2023.


K-96


---

**Notes to Consolidated Financial Statements**


**(18)** **Long-duration insurance contracts**


A summary of our long-duration life, annuity and health insurance benefits liabilities disaggregated by our two principal
product categories, periodic payment annuity (“annuities”) and life and health insurance, follows (in millions). Other liabilities
include IBNR claims and claims in the course of settlement.


Reconciliations of the liabilities for each of our principal product categories for each of the two years ended December
31, 2024 follow. This information reflects the changes in discounted present values of expected future policy benefits and
expected future net premiums before reinsurance ceded. Net premiums represent the portion of expected gross premiums that
are required to provide for future policy benefits and variable expenses. Amounts are in millions.


Liabilities for future policy benefits and reinsurance recoverables declined in 2024 primarily attributable to the
commutations of certain life reinsurance contracts. The impacts of these contract commutations on expected future policy
benefits and future net premiums were included in the effects of actual versus expected experience.


K-97


---

**Notes to Consolidated Financial Statements**


**(18)** **Long-duration insurance contracts**


Other information relating to our long-duration insurance liabilities as of December 31, 2024 and 2023 follows (dollars
in millions).


Gross premiums earned and interest expense before reinsurance ceded for each of the two years ended December 31,
2024 follows (in millions).


**(19)** **Notes payable and other borrowings**


Notes payable and other borrowings of our insurance and other businesses are summarized below (dollars in millions).
The weighted average interest rates and maturity date ranges are based on borrowings as of December 31, 2024.


Berkshire parent company borrowings consist of senior unsecured debt. In 2024, Berkshire repaid approximately $1.9
billion of maturing senior notes. At various dates in 2024, Berkshire borrowed approximately ¥837.4 billion (approximately
$5.5 billion) under senior note issuances and term loan agreements. The borrowings have interest rates ranging from 0.974%
to 2.625% and maturity dates ranging from 2027 to 2054.


K-98


---

**Notes to Consolidated Financial Statements**


**(19)** **Notes payable and other borrowings**


Borrowings of BHFC, a wholly-owned finance subsidiary of Berkshire, consist of senior unsecured notes used to fund
manufactured housing loans originated or acquired and equipment held for lease of certain subsidiaries. BHFC borrowings are
fully and unconditionally guaranteed by Berkshire. Berkshire also guarantees certain debt of other subsidiaries, aggregating
approximately $2.7 billion at December 31, 2024. Generally, Berkshire’s guarantee of a subsidiary’s debt obligation is an
absolute, unconditional and irrevocable guarantee of the full and prompt payment when due of all payment obligations.


Pilot’s borrowings at December 31, 2023 were primarily secured syndicated loans. In 2024, Pilot borrowed $5.7 billion
from certain Berkshire insurance subsidiaries, which Pilot used to repay its then outstanding third-party borrowings.


The carrying values of Berkshire and BHFC non-U.S. Dollar denominated senior notes (€5.85 billion, £1.75 billion and
¥1,988 billion par at December 31, 2024) reflect the applicable exchange rates as of each balance sheet date. The effects of
changes in foreign currency exchange rates during the period on our borrowings are recorded in earnings as a component of
selling, general and administrative expenses. Changes in the exchange rates produced pre-tax gains of $1.5 billion in 2024,
$217 million in 2023 and $1.7 billion in 2022.


Notes payable and other borrowings of our railroad, utilities and energy businesses are summarized below (dollars in
millions). The weighted average interest rates and maturity date ranges are based on borrowings as of December 31, 2024.


BHE subsidiary debt represents amounts issued pursuant to separate financing agreements. Substantially all of the assets
of certain BHE subsidiaries are, or may be, pledged or encumbered to support or otherwise secure such debt. These borrowing
arrangements generally contain various covenants, including covenants which pertain to leverage ratios, interest coverage ratios
and/or debt service coverage ratios. In 2024, BHE subsidiaries issued $6.4 billion of term debt with a weighted average interest
rate of 5.4% and maturity dates ranging from 2029 to 2055 and BHE and its subsidiaries repaid term debt and short-term
borrowings aggregating approximately $5.9 billion. In 2025, BHE subsidiaries issued term debt of $1.5 billion, with maturities
ranging from 2035 to 2055 and a weighted average interest rate of 6.0%.


BNSF’s borrowings are primarily senior unsecured debentures. In 2024, BNSF issued $1.3 billion of 5.5% debentures
due in 2055 and repaid $1.3 billion of debentures. As of December 31, 2024, BHE, BNSF and their subsidiaries were in
compliance with all applicable debt covenants. Berkshire does not guarantee any debt, borrowings or lines of credit of BHE,
BNSF or their subsidiaries.


Unused and available lines of credit and commercial paper capacity to support operations and provide additional liquidity
for our subsidiaries were approximately $11.4 billion at December 31, 2024, of which approximately $10.1 billion related to
BHE and its subsidiaries.


Debt principal repayments expected during each of the next five years are as follows (in millions). Amounts in 2025
include short-term borrowings.


K-99


---

**Notes to Consolidated Financial Statements**


**(20)** **Income taxes**


Our liabilities for income taxes are as follows (in millions).


Our deferred income tax assets and liabilities summarized by type of temporary difference are as follows (in millions).


We have not established deferred income taxes on accumulated undistributed earnings of certain foreign subsidiaries,
which are expected to be reinvested indefinitely. Repatriation of all accumulated earnings of foreign subsidiaries would be
impracticable to the extent that such earnings represent capital to support ongoing business operations. Generally, no U.S.
federal income taxes will be imposed on future distributions of foreign earnings under current law. However, distributions to
the U.S. or other foreign jurisdictions could be subject to withholding and other local taxes.


Income tax expense (benefit) for each of the three years ending December 31, 2024 is summarized as follows (in
millions).


K-100


---

**Notes to Consolidated Financial Statements**


**(20)** **Income taxes**


Income tax expense (benefit) is reconciled to hypothetical amounts computed at the U.S. federal statutory rate for each
of the three years ending December 31, 2024 in the table below (dollars in millions).


_* U.S. income tax credits derive primarily from production tax credits associated with wind-energy generation of BHE and tax_
_credits arising from affordable housing investments._


We file income tax returns in the U.S. and in state, local and foreign jurisdictions. We have settled income tax liabilities
with the U.S. federal taxing authority (“IRS”) for tax years through 2013, and the IRS is currently auditing tax years 2014
through 2019. We are also under audit or subject to audit with respect to income taxes in various state and foreign jurisdictions.
It is reasonably possible that certain of these income tax examinations will be settled in 2025. We currently do not believe that
the outcome of unresolved issues or claims will be material to our Consolidated Financial Statements.


At December 31, 2024 and 2023, net unrecognized tax benefits were $501 million and $480 million, respectively.
Included in the balance at December 31, 2024, were $448 million of tax positions that, if recognized, would impact the effective
tax rate. We do not expect material increases to the estimated amount of unrecognized tax benefits during 2025.


The Organization for Economic Co-operation and Development has issued Pillar Two model rules introducing a new
global minimum tax of 15% intended to be effective on January 1, 2024. While the U.S. has not yet adopted Pillar Two rules,
various other governments around the world are enacting legislation to adopt the rules. As currently designed, Pillar Two would
apply to our worldwide operations. We do not currently have material operations in jurisdictions with tax rates lower than the
Pillar Two minimum tax rate, and we do not currently expect these rules will materially increase our global tax costs. There
remains uncertainty as to the final Pillar Two model rules.


K-101


---

**Notes to Consolidated Financial Statements**


**(21)** **Fair value measurements**


Our financial assets and liabilities are summarized below, with fair values shown according to the fair value hierarchy
(in millions). The carrying values of cash and cash equivalents, U.S. Treasury Bills, other receivables and accounts payable,
accruals and other liabilities are considered to be reasonable estimates of or otherwise approximate the fair values.


_(1)_ _Assets are included in other assets, and liabilities are included in accounts payable, accruals and other liabilities._


K-102


---

**Notes to Consolidated Financial Statements**


**(21)** **Fair value measurements**


The fair values of substantially all of our financial instruments were measured using market or income approaches. The
hierarchy for measuring fair value consists of Levels 1 through 3, which are described below.


Level 1 – Inputs represent unadjusted quoted prices for identical assets or liabilities exchanged in active markets.


Level 2 – Inputs include directly or indirectly observable inputs (other than Level 1 inputs) such as quoted prices
for similar assets or liabilities exchanged in active or inactive markets; quoted prices for identical assets or liabilities
exchanged in inactive markets; other inputs that may be considered in fair value determinations of the assets or liabilities,
such as interest rates and yield curves, volatilities, prepayment speeds, loss severities, credit risks and default rates; and
inputs that are derived principally from or corroborated by observable market data by correlation or other means. Pricing
evaluations generally reflect discounted expected future cash flows, which incorporate yield curves for instruments with
similar characteristics, such as credit ratings, estimated durations and yields for other instruments of the issuer or entities
in the same industry sector.


Level 3      - Inputs include unobservable inputs used in the measurement of assets and liabilities. Management is
required to use its own assumptions regarding unobservable inputs because there is little, if any, market activity in the
assets or liabilities and it may be unable to corroborate the related observable inputs. Unobservable inputs require
management to make certain projections and assumptions about the information that would be used by market
participants in valuing assets or liabilities.


Reconciliations of significant assets and liabilities measured and carried at fair value on a recurring basis with the use of
significant unobservable inputs (Level 3) for each of the three years ending December 31, 2024 follow (in millions).


Quantitative information as of December 31, 2024 for the significant assets measured and carried at fair value on a
recurring basis with the use of significant unobservable inputs (Level 3) follows (dollars in millions).


Investments in equity securities in the preceding table include our investments in certain preferred and common stock
warrants that do not have readily determinable market values as defined under GAAP. These investments are private placements
and are not traded in securities markets. We applied discounted cash flow techniques in valuing the preferred stock and we
made assumptions regarding the expected duration of the investment and the effects of illiquidity and subordination in
liquidation. In valuing the common stock warrants, we used a warrant valuation model. While most of the inputs to the warrant
model are observable, we made assumptions regarding the expected duration and volatility.


K-103


---

**Notes to Consolidated Financial Statements**


**(22)** **Common stock**


The changes in Berkshire’s issued, treasury and outstanding common stock for each of the three years ending December
31, 2024 are shown in the table below. In addition, one million shares of preferred stock are authorized, but none are issued.


|Class B, $0.0033 Par Value<br>(3.225 billion shares authorized)|Col2|Col3|
|---|---|---|
|**Issued**|**Treasury**<br>**Outstanding**<br> (197,818,349) 1,290,474,503<br>—<br>21,676,500<br>(9,896,927)<br>(9,896,927<br> (207,715,276) 1,302,254,076<br>—<br>18,183,000<br>(9,875,568)<br>(9,875,568<br> (217,590,844) 1,310,561,508<br>—<br>23,139,000<br>—<br>—<br>2,291,631<br>2,291,631<br> (215,299,213) 1,335,992,139|**Treasury**<br>**Outstanding**<br> (197,818,349) 1,290,474,503<br>—<br>21,676,500<br>(9,896,927)<br>(9,896,927<br> (207,715,276) 1,302,254,076<br>—<br>18,183,000<br>(9,875,568)<br>(9,875,568<br> (217,590,844) 1,310,561,508<br>—<br>23,139,000<br>—<br>—<br>2,291,631<br>2,291,631<br> (215,299,213) 1,335,992,139|
|1,488,292,852 <br>21,676,500<br>—|1,488,292,852 <br>21,676,500<br>—|1,290,474,503<br>21,676,500<br>(9,896,927|
|1,509,969,352 <br>18,183,000<br>—|1,509,969,352 <br>18,183,000<br>—|1,302,254,076<br>18,183,000<br>(9,875,568|
|1,528,152,352 <br>23,139,000<br>—<br>—|1,528,152,352 <br>23,139,000<br>—<br>—|1,310,561,508<br>23,139,000<br>—<br>2,291,631|
|1,551,291,352|1,551,291,352|1,335,992,139|


Each Class A common share is entitled to one vote per share. Class B common stock possesses dividend and distribution
rights equal to one-fifteen-hundredth (1/1,500) of such rights of Class A common stock. Each Class B common share possesses
voting rights equal to one-ten-thousandth (1/10,000) of the voting rights of a Class A share. Unless otherwise required under
Delaware General Corporation Law, Class A and Class B common shares vote as a single class. Each share of Class A common
stock is convertible, at the option of the holder, into 1,500 shares of Class B common stock. Class B common stock is not
convertible into Class A common stock. On an equivalent Class A common stock basis, there were 1,438,223 shares outstanding
as of December 31, 2024 and 1,441,483 shares outstanding as of December 31, 2023.


Since we have two classes of common stock, we provide earnings per share data on the Consolidated Statements of
Earnings for average equivalent Class A shares outstanding and average equivalent Class B shares outstanding. Class B shares
are economically equivalent to one-fifteen-hundredth (1/1,500) of a Class A share. Average equivalent Class A shares
outstanding represents average Class A shares outstanding plus one-fifteen-hundredth (1/1,500) of the average Class B shares
outstanding. Average equivalent Class B shares outstanding represents average Class B shares outstanding plus 1,500 times
average Class A shares outstanding.


Berkshire’s common stock repurchase program, as amended, permits Berkshire to repurchase shares any time that
Warren Buffett, Berkshire’s Chairman of the Board and Chief Executive Officer, believes that the repurchase price is below
Berkshire’s intrinsic value, conservatively determined. The program continues to allow share repurchases in the open market
or through privately negotiated transactions and does not specify a maximum number of shares to be repurchased. However,
repurchases will not be made if they would reduce the total value of Berkshire’s consolidated cash, cash equivalents and U.S.
Treasury Bill holdings below $30 billion. The repurchase program does not obligate Berkshire to repurchase any specific dollar
amount or number of Class A or Class B shares and there is no expiration date to the program.


K-104


---

**Notes to Consolidated Financial Statements**


**(23)** **Revenues from contracts with customers**


The following table summarizes customer contract revenues disaggregated by reportable segment and the source of the
revenue for each of the three years ended December 31, 2024 (in millions). Other revenues, which are not considered to be
revenues from contracts with customers under GAAP, are primarily insurance premiums earned, interest, dividend and other
investment income and leasing revenues.


——————

_*_ _Revenues from Pilot are principally fuel sales and revenues in 2023 are for the eleven months ending December 31._


K-105


---

**Notes to Consolidated Financial Statements**


**(23)** **Revenues from contracts with customers**


A summary of the transaction price allocated to the significant unsatisfied remaining performance obligations related to
contracts with expected durations exceeding one year as of December 31, 2024 and the timing of when the performance
obligations are expected to be satisfied follows (in millions).


**(24)** **Pension plans**


Certain Berkshire subsidiaries sponsor defined benefit pension plans. Plan benefits are generally based on years of service
and compensation or fixed benefit rates. Plan sponsors may make contributions to the plans to meet regulatory requirements or
may make discretionary contributions. Benefits under qualified U.S. and certain non-U.S. defined benefit pension plans are
funded with assets held in trusts. Certain other non-qualified retirement plans are unfunded. Our net periodic pension expense
for each of the three years ending December 31, 2024 was as follows (in millions).


The accumulated benefit obligation (“ABO”) is the actuarial present value of benefits earned based on service and
compensation prior to the valuation date. The ABO was $11.2 billion at December 31, 2024 and $12.3 billion at December 31,
2023. The projected benefit obligation (“PBO”) is the actuarial present value of benefits earned based upon service and
compensation prior to the valuation date and, if applicable, includes assumptions regarding future compensation levels.


Reconciliations of the changes in plan assets and PBOs for each of the two years ending December 31, 2024 and the
asset and liability balances reflected in the Consolidated Balance Sheets at year end 2024 and 2023 follow (in millions).


Liabilities include benefit obligations of unfunded plans of $1.0 billion at December 31, 2024 and 2023, respectively.


K-106


---

**Notes to Consolidated Financial Statements**


**(24)** **Pension plans**


Weighted average assumptions used in determining PBOs and net periodic pension expense follow.


Expected benefit payments over the next ten years are (in millions): 2025   - $893; 2026   - $873; 2027   - $875; 2028   $884; 2029 - $883; and 2030 through 2034 - $4,379. Our subsidiaries expect to make contributions of $114 million to the
pension plans in 2025.


Fair value measurements of plan assets as of December 31, 2024 and 2023 follow (in millions).


Plan assets are generally invested with the long-term objective of producing earnings to adequately cover expected
benefit obligations. The expected rates of return on plan assets reflect subjective assessments of expected long-term investment
returns. Generally, past investment returns are not given significant consideration when establishing assumptions for expected
long-term rates of return on plan assets. Actual experience will differ from the assumed rates of return.


K-107


---

**Notes to Consolidated Financial Statements**


**(24)** **Pension plans**


A reconciliation of the pre-tax accumulated other comprehensive income (loss) of our defined benefit pension plans for
each of the two years ending December 31, 2024 follows (in millions).


Our subsidiaries may also sponsor defined contribution retirement plans, such as 401(k) or profit-sharing plans.
Employee contributions are subject to regulatory limitations and specific plan provisions. Several of these plans provide for
employer matching contributions as specified in the plans and may provide for additional discretionary employer contributions.
Our defined contribution plan expense was approximately $1.3 billion in 2024, $1.1 billion in 2023 and $0.8 billion in 2022.


**(25)** **Accumulated other comprehensive income**


A summary of the net changes in after-tax accumulated other comprehensive income attributable to Berkshire
shareholders for each of the three years ending December 31, 2024 follows (in millions).


**(26)** **Business segment data**


Berkshire’s numerous and diverse businesses are managed on an unusually decentralized basis. These businesses are
aggregated into operating segments in a manner that reflects how Berkshire views the business activities. Berkshire’s chief
operating decision maker consists of the Chairman and Chief Executive Officer, the Vice Chairman of Insurance Operations
and the Vice Chairman of Non-Insurance Operations. This group participates in and is ultimately responsible for significant
capital allocation decisions, evaluating operating performance and selecting the chief executive to head each of the operating
segments. Investing decisions are the responsibility of Berkshire’s Chairman and Chief Executive Officer and Berkshire’s
corporate investment managers. Certain operating segments are aggregated into reportable business segments based upon
similar products or product lines, marketing strategies, and selling and distribution characteristics.


K-108


---

**Notes to Consolidated Financial Statements**


**(26)** **Business segment data**


Berkshire’s reportable business segments are as follows.


**Business Segment** **Principal Business Activities**
Insurance:


GEICO Underwriting private passenger automobile insurance mainly by direct
response methods


Berkshire Hathaway Primary Group Underwriting multiple lines of property and casualty insurance policies for
primarily commercial accounts


Berkshire Hathaway Reinsurance Group Underwriting excess-of-loss, quota-share and facultative reinsurance
worldwide


Burlington Northern Santa Fe (“BNSF”) Operator of one of the largest railroad systems in North America


Berkshire Hathaway Energy (“BHE”) Regulated electric and gas utility, including power generation and
distribution activities and real estate brokerage activities


Manufacturing Manufacturers of numerous products including industrial, consumer and
building products, including home building and related financial services


Pilot Travel Centers (“Pilot”) _[(1)]_ Operator of travel centers in North America and a marketer of wholesale fuel


McLane Company (“McLane”) Wholesale distribution of food and non-food items to retailers and restaurants


Service and retailing Providers of numerous services including shared aircraft ownership
programs, aviation pilot training, electronic components distribution, various
retailing businesses, including automobile dealerships and over-the-road
trailer and furniture leasing
——————

_(1) Pilot’s statement of earnings and capital expenditure segment data in 2023 is for the eleven months ending December 31,_
_2023._ _Our_ _earnings_ _from_ _Pilot_ _in_ _2022_ _and_ _for_ _the_ _month_ _of_ _January_ _2023_ _were_ _determined_ _under_ _the_ _equity_ _method_ _and_
_included in earnings from non-controlled businesses._


The tabular information that follows shows data of Berkshire’s business segments reconciled to amounts reflected in our
Consolidated Financial Statements. Intersegment transactions are not eliminated from segment results when those transactions
are considered in assessing the results of the respective segments and are not considered to be material. Furthermore, investment
gains and losses, goodwill and indefinite-lived intangible asset impairments and amortization of certain acquisition accounting
adjustments or certain other corporate income and expense items are not considered in assessing the financial performance of
operating businesses. Collectively, these items are included in corporate, eliminations and other to reconcile segment totals to
consolidated amounts.


The cost and expense information provided is based on the information regularly provided to the chief operating decision
maker. Given the number and diversity of Berkshire’s operating segments and the differences in revenue streams and cost
structures, there are wide variances in the form, content and levels of such expense information significant to the business.
Expenses considered significant for one operating segment may not be significant in others.


With respect to insurance underwriting, the chief operating decision maker considers pre-tax underwriting earnings to
allocate resources and capital, together with perceived risks and opportunities in the insurance markets that affect rates and
risks of loss. Typically, there are no budgeted or forecasted premiums or underwriting results.


For most non-insurance businesses, pre-tax earnings are considered in allocating resources and capital, although income
taxes are also considered at BHE, given the magnitude of production tax credits associated with wind-powered electricity
generation investments and the related impacts from regulation. The chief operating decision maker generally considers actual
operating results versus budgets or forecasts, as well as unique perceived risks and opportunities associated with the individual
operating businesses.


K-109


---

**Notes to Consolidated Financial Statements**


**(26)** **Business segment data**


We view our insurance segment as possessing two distinct activities   - underwriting and investing. Underwriting
decisions are the responsibility of the underwriting managers, while investment decisions are the responsibility of Berkshire’s
CEO and other corporate investment managers. Accordingly, performance of underwriting operations is evaluated without any
allocation of investment income. As such, the insurance net investment income is presented in the aggregate as a separate
component of insurance segment operating earnings. Earnings data of our business segments for each of the three years ended
December 31, 2024 are shown in the following tables (in millions).


Insurance other segment items include commissions and brokerage expenses and other insurance underwriting expenses.


BNSF other segment items include purchased services, equipment rents and materials expenses.


K-110


---

**Notes to Consolidated Financial Statements**


**(26)** **Business segment data**


BHE other segment items primarily consist of property taxes and other expenses. Energy operations and maintenance
includes losses associated with the 2020 and 2022 Wildfires. See Note 27.


Other segment items of manufacturing, services and retailing segments primarily consist of selling, general and
administrative expenses.


Pilot other segment items primarily consist of store operating, interest and general and administrative expenses. McLane
other segment items include general and administrative expenses.


Reconciliations of revenues and earnings (loss) before income taxes of our business segments to the consolidated
amounts for each of the three years ended December 31, 2024 follows (in millions).


K-111


---

**Notes to Consolidated Financial Statements**


**(26)** **Business segment data**


Additional segment data for each of the three most recent years follows (in millions).


K-112


---

**Notes to Consolidated Financial Statements**


**(26)** **Business segment data**


Property/casualty and life/health insurance premiums written and earned are summarized below (in millions).


Insurance premiums written by geographic region (based upon the domicile of the insured or reinsured) are summarized
below (in millions).


of such amounts. The remainder of sales, service and leasing revenues were primarily in Europe, the Asia-Pacific region and
Canada. Railroad, utilities and energy revenues were $49.8 billion in 2024 and 2023 and $52.1 billion in 2022. Railroad, utilities
and energy revenues attributable to the United States were 95% in 2024 and 96% in 2023 and 2022. At December 31, 2024,
approximately 91% of our consolidated net property, plant and equipment and equipment held for lease was located in the
United States with the remainder primarily in the United Kingdom and Canada.


**(27)** **Contingencies and commitments**


We are parties in a variety of legal actions that routinely arise out of the normal course of business, including legal actions
seeking to establish liability directly through insurance contracts or indirectly through reinsurance contracts issued by Berkshire
subsidiaries. Plaintiffs occasionally seek punitive or exemplary damages. We do not believe that such normal and routine
litigation will have a material effect on our financial condition or results of operations.


PacifiCorp, a wholly-owned subsidiary of Berkshire Hathaway Energy Company (“BHE”), operates as a regulated
electric utility in Utah, Oregon, Wyoming and other Western states. HomeServices of America, Inc. (“HomeServices”) is also
a wholly-owned subsidiary of BHE. Certain legal matters related to these entities are described below.


PacifiCorp


In September 2020, a severe weather event resulting in high winds, low humidity and warm temperatures, contributed to
several major wildfires, which resulted in real and personal property and natural resource damage, personal injuries, loss of life
and widespread power outages in Oregon and Northern California. These wildfires spread across certain parts of PacifiCorp’s
service territory and surrounding areas across multiple counties in Oregon and California, including Siskiyou County,
California; Jackson County, Oregon; Douglas County, Oregon; Marion County, Oregon; Lincoln County, Oregon; and Klamath
County, Oregon, burning over 500,000 acres in aggregate. Third-party reports for these wildfires (the “2020 Wildfires”)
indicate over 2,000 structures destroyed, including residences; several other structures damaged; multiple individuals injured;
and several fatalities. Investigations into the cause and origin of each of the 2020 Wildfires are complex and ongoing and have
been or are being conducted by various entities, including the U.S. Forest Service, the California Public Utilities Commission,
the Oregon Department of Forestry, the Oregon Department of Justice, PacifiCorp and various experts engaged by PacifiCorp.


K-113


---

**Notes to Consolidated Financial Statements**


**(27)** **Contingencies and commitments**


According to the California Department of Forestry and Fire Protection, a wildfire began on July 29, 2022, in the Oak
Knoll Ranger District of the Klamath National Forest in Siskiyou County, California located in PacifiCorp’s service territory
(the “2022 Wildfire”) burning over 60,000 acres. Third-party reports indicate that the 2022 Wildfire resulted in 11 structures
damaged, 185 structures destroyed, 12 injuries and four fatalities. The U.S. Forest Service issued a Wildland Fire Origin and
Cause Supplemental Incident Report. The report concluded that a tree coming in contact with a power line is the probable cause
of the 2022 Wildfire. The 2020 Wildfires and 2022 Wildfire, together, are referred to as the “Wildfires.”


As of the date of this filing, a significant number of complaints and demands alleging similar claims related to the
Wildfires have been filed in Oregon and California, including a class action complaint in Oregon associated with the 2020
Wildfires for which certain jury verdicts were issued as described below. The plaintiffs seek damages for economic losses,
noneconomic losses, including mental suffering, emotional distress, personal injury and loss of life, as well as punitive
damages, other damages and attorneys’ fees. Several insurance carriers have filed subrogation complaints in Oregon and
California with allegations similar to those made in the aforementioned complaints.


Additionally, PacifiCorp received correspondence from the U.S. and Oregon Departments of Justice regarding the
potential recovery of certain costs and damages alleged to have occurred on federal and state lands in connection with certain
of the Oregon 2020 Wildfires. In December 2024, the United States of America filed a complaint against PacifiCorp in
conjunction with the correspondence from the U.S. Department of Justice. The civil cover sheet accompanying the complaint
demands damages estimated to exceed $900 million. PacifiCorp is actively cooperating with the U.S. and Oregon Departments
of Justice on resolving these alleged claims.


Amounts sought in outstanding complaints and demands filed in Oregon and in certain demands in California
approximate $3 billion, excluding any doubling or trebling of damages included in the complaints and the mass complaints
described below that seek $48 billion. Generally, the complaints filed in California do not specify damages sought and are
excluded from this amount.


Based on available information to date, we believe it is probable that losses will be incurred associated with the Wildfires.
Final determinations of liability will only be made following the completion of comprehensive investigations, litigation and
similar processes.


On September 30, 2020, a class action complaint against PacifiCorp was filed captioned Jeanyne James et al. v.
PacifiCorp et al. (the “James case”), in Oregon Circuit Court in Multnomah County, Oregon (the “Multnomah Court”) in
connection with the 2020 Wildfires. In April 2023, a jury trial for the James case with respect to 17 named plaintiffs began in
Multnomah Court. In June 2023, the jury issued its verdict finding PacifiCorp liable to the 17 named plaintiffs and to the class
with respect to four wildfires. The jury found PacifiCorp’s conduct grossly negligent, reckless and willful as to each plaintiff
and the entire class. The jury awarded the 17 named plaintiffs $90 million of damages, including $4 million of economic
damages, $68 million of noneconomic damages and $18 million of punitive damages based on a 0.25 multiplier of the economic
and noneconomic damages.


In September 2023, the Multnomah Court ordered trial dates for three damages phase trials for the James case, wherein
plaintiffs in each of the three damages phase trials would present evidence regarding their damages.


In January 2024, the Multnomah Court entered a limited judgment and money award for the June 2023 James case verdict
of $92 million based on the amounts awarded by the jury, as well as doubling of the economic damages and offsetting of
insurance proceeds received by plaintiffs. In January 2024, PacifiCorp filed a notice of appeal associated with the June 2023
verdict in the James case, including whether the case can proceed as a class action, and filed a motion to stay further damages
phase trials. On February 14, 2024, the Oregon Court of Appeals denied PacifiCorp’s request to stay the damages phase trials.
On February 13, 2024, the 17 named plaintiffs filed a notice of cross-appeal as to the January 2024 limited judgment and money
award. The appeals process and further actions could take several years.


In January 2024, the jury for the first James case damages phase trial awarded nine plaintiffs $62 million of damages,
including $6 million of economic damages and $56 million of noneconomic damages. Subsequently, the Multnomah Court
increased the economic damages by $6 million and added $16 million of punitive damages, bringing the aggregate damages
awarded to $84 million. In March 2024, the Multnomah Court granted in large part PacifiCorp’s request to offset the damage
awards by deducting insurance proceeds received by any of the nine plaintiffs. In April 2024, the Multnomah Court entered a
limited judgment and money award of $80 million for the January 2024 James verdict, based on the aggregate damages
awarded, offset by insurance proceeds received by plaintiffs.


K-114


---

**Notes to Consolidated Financial Statements**


**(27)** **Contingencies and commitments**


In March 2024, the jury for the second James case damages phase trial awarded ten plaintiffs $42 million of damages,
including $12 million of doubled economic damages and $30 million of noneconomic and punitive damages. In May 2024, the
Multnomah Court granted PacifiCorp’s request to offset the damage awards by deducting insurance proceeds received by any
of the ten plaintiffs. In June 2024, the Multnomah Court entered a limited judgment and money award of $38 million for the
March 2024 James verdict, based on the aggregate amounts awarded, offset by insurance proceeds received by plaintiffs.


The January, April and June 2024 limited judgments created liens against PacifiCorp, attaching a debt for the money
awards. In each instance, PacifiCorp posted a supersedeas bond, which stays any effort to seek payment of the judgment
pending final resolution of any appeals. Under ORS 82.010, interest at a rate of 9% per annum will accrue on the judgment
commencing at the date the judgment was entered until the entire money award is paid, amended or reversed by an appellate
court. PacifiCorp amended its January 2024 appeal of the June 2023 James verdict to include the January 2024 jury verdict and
further amended its appeal of the June 2023 verdict to include the March 2024 jury verdict. PacifiCorp’s opening brief is due
to be filed with the Oregon Court of Appeals on or before February 25, 2025, in connection with its appeal of the June 2023
James verdict and the January and March 2024 verdicts for the first two James damages phase trials.


In February 2025, the jury for the third James case damages phase trial awarded seven plaintiffs $32 million of
noneconomic damages in addition to $4 million of economic damages stipulated for eight plaintiffs prior to the trial. In
accordance with Oregon law, plaintiffs asked the court to double the economic damages to $8 million after the verdict.
PacifiCorp expects the court will award the doubling of economic damages and also increase the award for $9 million in
punitive damages by applying the 0.25 multiplier of economic and noneconomic damages consistent with the June 2023 James
verdict. As a result, PacifiCorp expects the total award for the eight plaintiffs to be approximately $49 million. PacifiCorp filed
post-trial motions with the Multnomah Court requesting the court offset the damage awards by deducting insurance proceeds
received by any of the eight plaintiffs. PacifiCorp intends to appeal the jury’s damage awards associated with the February
2025 jury verdict once judgment is entered.


In March 2024, settlement was reached with five commercial timber plaintiffs in the James case, and the jury trial
scheduled for April 2024 was cancelled.


Between April 2024 and January 2025, six separate mass complaints against PacifiCorp naming 1,591 individual class
members were filed in the Multnomah Court referencing the James case as the lead case. Complaints for five of the plaintiffs
in the mass complaints were subsequently dismissed. These James case mass complaints make damages-only allegations
seeking economic, noneconomic and punitive damages, as well as doubling of economic damages. In December 2024, two
additional complaints were filed in Multnomah Court on behalf of eight plaintiffs also referencing the James case as the lead
case. PacifiCorp believes the magnitude of damages sought by the class members in the James case mass complaints and
additional two complaints to be of remote likelihood of being awarded based on the amounts awarded in the jury verdicts
described above that are being appealed.


In October 2024, the Multnomah Court issued a case management order, which sets forth nine additional damages phase
trials with up to ten plaintiffs per trial. The trials are scheduled to occur throughout 2025, with the verdict for the first trial
received in February 2025, as described above.


A provision for a loss contingency is recorded when it is probable a liability has been incurred and the amount of loss
can be reasonably estimated. PacifiCorp evaluates the related range of reasonably estimated losses and records a loss based on
its best estimate within that range or the lower end of the range if there is no better estimate.


Estimated probable losses associated with the Wildfires were based on the information available to the date of this filing,
including (i) ongoing cause and origin investigations; (ii) ongoing settlement and mediation discussions; (iii) other litigation
matters and upcoming legal proceedings; and (iv) the status of the James case. Wildfire estimated losses include estimates for
fire suppression costs, real and personal property damages, natural resource damages and noneconomic damages such as
personal injury damages and loss of life damages that are considered probable of being incurred and that it is able to reasonably
estimate at this time, and which is subject to change as additional relevant information becomes available.


Through December 31, 2024, PacifiCorp recorded cumulative estimated probable Wildfire losses, before taxes and
expected related insurance recoveries, of approximately $2.75 billion. Wildfire loss accruals were $346 million in 2024, $1.9
billion in 2023 and $225 million in 2022. Insurance recoveries recorded to date in connection with the Wildfires were $530
million, including $253 million in 2023 and $161 million in 2022. No further insurance recoveries are expected to become
available. Cumulative Wildfire loss payments through December 31, 2024 were approximately $1.2 billion, of which $533
million was paid in 2024. Estimated unpaid liabilities for the Wildfires were approximately $1.54 billion at December 31, 2024.


K-115


---

**Notes to Consolidated Financial Statements**


**(27)** **Contingencies and commitments**


It is reasonably possible PacifiCorp will incur significant additional Wildfire losses beyond the amounts currently
accrued; however, it is currently unable to reasonably estimate the range of possible additional losses that could be incurred
due to the number of properties and parties involved, including claimants in the class to the James case and the 2022 Wildfire,
the variation in the types of properties and damages and the ultimate outcome of legal actions, including mediation, settlement
negotiations, jury verdicts and the appeals process.


HomeServices of America, Inc.


HomeServices is currently defending against several antitrust cases, all in federal district courts. In each case, plaintiffs
claim HomeServices and certain of its subsidiaries (and in one case BHE) conspired with co-defendants to artificially inflate
real estate commissions by following and enforcing multiple listing service (“MLS”) rules that require listing agents to offer a
commission split to cooperating agents in order for the property to appear on the MLS (“Cooperative Compensation Rule”).
None of the complaints specify damages sought. However, two cases also allege Texas state law deceptive trade practices
claims, for which plaintiffs have asserted damages totaling approximately $9 billion by separate written notice as required by
Texas law.


In one of these cases, Burnett (formerly Sitzer) et al. v. HomeServices of America, Inc. et al. (the “Burnett case”), a jury
trial in the U.S. District Court for the Western District of Missouri commenced on October 16, 2023, and the jury returned a
verdict for the plaintiffs on October 31, 2023, finding that the named defendants participated in a conspiracy to follow and
enforce the Cooperative Compensation Rule, which conspiracy had the purpose or effect of raising, inflating, or stabilizing
broker commission rates paid by home sellers. The jury further found that the class plaintiffs had proved damages in the amount
of $1.8 billion. Joint and several liability applies for the co-defendants. Federal law authorizes trebling of damages and the
award of pre-judgment interest and attorney fees. To date, all co-defendants have reached settlements with the plaintiffs. The
U.S District Court approved certain of these settlements in May 2024, which has been appealed to the U.S. Court of Appeals
for the Eighth Circuit.


In April 2024, HomeServices agreed to terms with the plaintiffs to settle all claims asserted against HomeServices and
certain of its subsidiaries in the Burnett case to effectuate a nationwide class settlement. The final settlement agreement includes
scheduled payments over the next four years aggregating $250 million. HomeServices received final court approval on
November 27, 2024, which has been appealed to the U.S. Court of Appeals for the Eighth Circuit. If the settlement is not
affirmed by the U.S. Court of Appeals for the Eighth Circuit, HomeServices intends to vigorously appeal on multiple grounds
the jury’s findings and damage award in the Burnett case, including whether the case can proceed as a class action. The appeals
process and further actions could take several years.


Other legal matters


In September 2024, National Indemnity Company (“NICO”) recorded a pre-tax charge of $490 million in connection
with a settlement agreement reached concerning certain non-insurance affiliates that filed voluntary petitions under Chapter 11
of bankruptcy code in the United States Bankruptcy Court for the District of New Jersey (the “Court”) in 2023. Under the terms
of the settlement agreement, NICO has agreed to pay $535 million to the bankruptcy estate in consideration of a release of all
estate causes of action against NICO and its affiliates. The settlement agreement, which is opposed by certain creditors, is
subject to approval by the Court. NICO also accrued a recoverable of $45 million from a third party that is covered under the
release, which was received in the fourth quarter.


Berkshire and certain of its subsidiaries are also involved in other kinds of legal actions, some of which assert or may
assert claims or seek to impose fines and penalties. We currently believe that liabilities that may arise as a result of such other
pending legal actions will not have a material effect on our consolidated financial condition or results of operations.


Commitments


Our subsidiaries regularly make commitments in the ordinary course of business to purchase goods and services in the
future, which are not yet reflected in our Consolidated Financial Statements. The most significant of our long-term
commitments relate to our railroad, utilities and energy businesses, our shared aircraft ownership and leasing business and
certain materials purchase commitments. As of December 31, 2024, estimated future payments under those arrangements over
the next five years were as follows: $12 billion in 2025, $6 billion in 2026, $5 billion in 2027, $4 billion in 2028, $3 billion in
2029, and thereafter $28 billion.


K-116


---

**Item 9. Changes in and Disagreements with Accountants on Accounting and Financial Disclosure**
None


**Item 9A. Controls and Procedures**
At the end of the period covered by this Annual Report on Form 10-K, the Corporation carried out an evaluation, under
the supervision and with the participation of the Corporation’s management, including the Chairman (Chief Executive Officer)
and the Senior Vice President (Chief Financial Officer), of the effectiveness of the design and operation of the Corporation’s
disclosure controls and procedures pursuant to Exchange Act Rule 13a-15. Based upon that evaluation, the Chairman (Chief
Executive Officer) and the Senior Vice President (Chief Financial Officer) concluded that the Corporation’s disclosure controls
and procedures are effective in timely alerting them to material information relating to the Corporation (including its
consolidated subsidiaries) required to be included in the Corporation’s periodic SEC filings. The report called for by Item
308(a) of Regulation S-K is incorporated herein by reference to Management’s Report on Internal Control Over Financial
Reporting, included on page K-63 of this report. The attestation report called for by Item 308(b) of Regulation S-K is
incorporated herein by reference to the Report of Independent Registered Public Accounting Firm, included on page K-64 of
this report. There has been no change in the Corporation’s internal control over financial reporting during the quarter ended
December 31, 2024 that has materially affected, or is reasonably likely to materially affect, the Corporation’s internal control
over financial reporting.


**Item 9B. Other Information**
Berkshire has not adopted a Rule 10b5-1 trading arrangement (as defined in Item 408(a)(1)(i) of Regulation S-K) and no
directors or executive officers adopted or terminated a Rule 10b5-1 trading arrangement or a non-Rule 10b5-1 trading
arrangement (as defined in Item 408(c) of Regulation S-K) during the fourth quarter of 2024.


**Item 9C. Disclosure Regarding Foreign Jurisdictions that Prevent Inspection**
Not applicable.


**Part III**
Except for the information set forth under the caption “Executive Officers of the Registrant” in Part I hereof, information
required by this Part (Items 10, 11, 12, 13 and 14) is incorporated by reference from the Registrant’s definitive proxy statement,
filed pursuant to Regulation 14A, for the Annual Meeting of Shareholders of the Registrant to be held on May 3, 2025, which
will involve the election of directors.


**Part IV**
**Item 15. Exhibits and Financial Statement Schedules**


(a) 1. _Financial Statements_
The following Consolidated Financial Statements, as well as the Report of Independent Registered Public Accounting
Firm, are included in Part II Item 8 of this report:
**PAGE**
Report of Independent Registered Public Accounting Firm (PCAOB ID No. 34) ....................................................... K-64
Consolidated Balance Sheets—
December 31, 2024 and December 31, 2023 ...................................................................................................... K-66
Consolidated Statements of Earnings—
Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 ............................................. K-68
Consolidated Statements of Comprehensive Income—
Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 ............................................. K-69
Consolidated Statements of Changes in Shareholders’ Equity—
Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 ............................................. K-69
Consolidated Statements of Cash Flows—
Years Ended December 31, 2024, December 31, 2023, and December 31, 2022 ............................................. K-70
Notes to Consolidated Financial Statements ................................................................................................................. K-71
2. _Financial Statement Schedule_
Report of Independent Registered Public Accounting Firm ......................................................................................... K-118
Schedule I—Parent Company Condensed Financial Information
Balance Sheets as of December 31, 2024 and 2023, Statements of Earnings and Comprehensive Income and
Cash Flows for the years ended December 31, 2024, December 31, 2023, and December 31, 2022 and Note
to Condensed Financial Information .................................................................................................................. K-119
Other schedules are omitted because they are not required, information therein is not applicable, or is
reflected in the Consolidated Financial Statements or notes thereto.


.............................................


.............................................


.............................................


.............................................
.................................................................................................................


.........................................................................................


..................................................................................................................


(b) _Exhibits_
See the “Exhibit Index” at page K-121.


K-117


---

**REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM**


To the Shareholders and the Board of Directors of
Berkshire Hathaway Inc.


**Opinion on the Financial Statement Schedule**
We have audited the consolidated financial statements of Berkshire Hathaway Inc. and subsidiaries (the “Company”) as of
December 31, 2024 and 2023, and for each of the three years in the period ended December 31, 2024, and the Company’s
internal control over financial reporting as of December 31, 2024, and have issued our report thereon dated February 22, 2025;
such consolidated financial statements and report are included elsewhere in this Form 10-K. Our audits also included the
financial statement schedule of the Company listed in the Index at Item 15. This financial statement schedule is the
responsibility of the Company’s management. Our responsibility is to express an opinion on the Company’s financial statement
schedule based on our audits. In our opinion, such financial statement schedule, when considered in relation to the financial
statements taken as a whole, presents fairly, in all material respects, the information set forth therein.


/s/ Deloitte & Touche LLP
Omaha, Nebraska
February 22, 2025


K-118


---

**BERKSHIRE HATHAWAY INC. (Parent Company)**
**Condensed Financial Information**
**(Dollars in millions)**
**Schedule I**
**Balance Sheets**


**Statements of Earnings and Comprehensive Income**


_See Note to Condensed Financial Information_


K-119


---

**BERKSHIRE HATHAWAY INC. (Parent Company)**
**Condensed Financial Information**
**(Dollars in millions)**
**Schedule I (continued)**
**Statements of Cash Flows**


——————


_* Includes discount accretion on investments and foreign currency exchange (gains) losses._


**Note to Condensed Financial Information**


As of December 31, 2024, Berkshire owned 27.2% of the outstanding shares of The Kraft Heinz Company common
stock, which is accounted for pursuant to the equity method. See Note 5 to the Consolidated Financial Statements.


In September and October 2024, Berkshire acquired the remaining 2.12% of Berkshire Hathaway Energy’s (“BHE”)
outstanding common stock held by noncontrolling shareholders in exchange for 2,291,631 shares of Berkshire Class B common
stock valued at $1.045 billion. On October 19, 2022, Berkshire acquired all of the outstanding common stock of Alleghany
Corporation for $11.5 billion. See Note 2 to the Consolidated Financial Statements.


During 2024, the Parent Company repaid approximately $1.9 billion of maturing senior notes. At various dates in 2024,
Berkshire borrowed approximately ¥837.4 billion (approximately $5.5 billion) under senior note issuances and term loan
agreements. The borrowings have interest rates ranging from 0.974% to 2.625% and maturity dates ranging from 2027 to 2054.
As of December 31, 2024, the Parent Company’s non-U.S. Dollar denominated borrowings included €4.6 billion and ¥1,988
billion par value senior notes. The gains and losses from the periodic remeasurement of these non-U.S. Dollar denominated
notes due to changes in foreign currency exchange rates are included in earnings.


Parent Company debt maturities in each of the next five years are as follows: 2025—$1.9 billion; 2026—$4.2 billion;
2027—$4.0 billion; 2028—$2.2 billion and 2029—$2.6 billion. The Parent Company guarantees certain debt of subsidiaries,
which aggregated approximately $20.8 billion at December 31, 2024 and primarily consisted of debt issued by Berkshire
Hathaway Finance Corporation. Such guarantees are an absolute, unconditional and irrevocable guarantee for the full and
prompt payment when due of all present and future payment obligations. The Parent Company has also provided guarantees in
connection with certain retroactive reinsurance contracts issued by subsidiaries. The amounts of subsidiary payments under
these contracts, if any, are contingent upon the outcome of future events.


K-120


---

**EXHIBIT INDEX**


**Exhibit No.**
2(i) Agreement and Plan of Merger dated as of June 19, 1998 between Berkshire and General Re Corporation.
Incorporated by reference to Annex I to Registration Statement No. 333-61129 filed on Form S-4.


2(ii) Agreement and Plan of Merger dated as of November 2, 2009 by and among Berkshire, R Acquisition
Company, LLC and BNSF. Incorporated by reference to Annex A to Registration Statement No. 333-163343
on Form S-4.


2(iii) Agreement and Plan of Merger dated August 8, 2015, by and among Berkshire, NW Merger Sub Inc. and
Precision Castparts Corporation (“PCC”) Incorporated by reference to Exhibit 2.1 to PCC’s Current Report on
Form 8-K filed on August 10, 2015 (SEC File No. 001-10348)


3(i) Restated Certificate of Incorporation Incorporated by reference to Exhibit 3(i) to Form 10-K filed on March 2,
2015.


3(ii) Amended and Restated By-Laws Incorporated by reference to Exhibit 3(ii) to Form 8-K filed on May 10, 2023.


4.1 Indenture, dated as of December 22, 2003, between Berkshire Hathaway Finance Corporation, Berkshire
Hathaway Inc. and The Bank of New York Mellon Trust Company, N.A. (as successor to J.P. Morgan Trust
Company, National Association), as trustee. Incorporated by reference to Exhibit 4.1 on Form S-4 of Berkshire
Hathaway Finance Corporation and Berkshire Hathaway Inc. filed on February 4, 2004. SEC File No. 333112486


4.2 Indenture, dated as of February 1, 2010, among Berkshire Hathaway Inc., Berkshire Hathaway Finance
Corporation and The Bank of New York Mellon Trust Company, N.A., as trustee. Incorporated by reference to
Exhibit 4.1 to Berkshire’s Registration Statement on Form S-3 filed on February 1, 2010. SEC File No. 333164611


4.3 Indenture, dated as of January 26, 2016, by and among Berkshire Hathaway Inc., Berkshire Hathaway Finance
Corporation and The Bank of New York Mellon Trust Company, N.A., as trustee. Incorporated by reference to
Exhibit 4.1 to Berkshire’s Registration Statement on Form S-3 filed on January 26, 2016. SEC File No. 333209122


4.4 Indenture, dated as of December 1, 1995, between BNSF and The First National Bank of Chicago, as trustee.
Incorporated by reference to Exhibit 4 on Form S-3 of BNSF filed on February 8, 1999.


4.5 Indenture, dated as of October 4, 2002, by and between MidAmerican Energy Holdings Company and The
Bank of New York, Trustee. Incorporated by reference to Exhibit 4.1 to the Berkshire Hathaway Energy
Company Registration Statement No. 333-101699 dated December 6, 2002.


4.6 Indenture, dated as of January 28, 2022, by and among Berkshire Hathaway Inc., as an issuer and a guarantor of
the debt securities issued by Berkshire Hathaway Finance Corporation, Berkshire Hathaway Finance
Corporation, as an issuer, and The Bank of New York Mellon Trust Company, N.A., as trustee. Incorporated by
reference to Exhibit 4.1 to Berkshire’s Registration Statement on Form S-3 filed on January 28, 2022. SEC File
No 333-262384.


4.7 Indenture, dated as of January 31, 2025, by and among Berkshire Hathaway Inc., as an issuer and a guarantor of
the debt securities issued by Berkshire Hathaway Finance Corporation, Berkshire Hathaway Finance
Corporation, as an issuer, and The Bank of New York Mellon Trust Company, N.A., as trustee. Incorporated by
reference to Exhibit 4.1 to Berkshire’s Registration Statement on Form S-3 filed on January 31, 2025. SEC File
No 333-284622.


**Other instruments defining the rights of holders of long-term debt of Registrant and its subsidiaries are**
**not being filed since the total amount of securities authorized by all other such instruments does not**
**exceed 10% of the total assets of the Registrant and its subsidiaries on a consolidated basis as of**
**December 31, 2024. The Registrant hereby agrees to furnish to the Commission upon request a copy of**
**any such debt instrument to which it is a party.**


10.1 Equity Commitment Letter of Berkshire Hathaway Inc. with Hawk Acquisition Holding Corporation dated
February 13, 2013. Incorporated by reference to Exhibit 10.1 on Form 8-K of Berkshire Hathaway Inc. filed on
February 14, 2013.


K-121


---

**Exhibit No.**
14 Code of Ethics
Berkshire’s Code of Business Conduct and Ethics is posted on its Internet website at
_www.berkshirehathaway.com_


19 Insider Trading Policies and Procedures


21 Subsidiaries of Registrant


23 Consent of Independent Registered Public Accounting Firm


31.1 Rule 13a—14(a)/15d-14(a) Certification


31.2 Rule 13a—14(a)/15d-14(a) Certification


32.1 Section 1350 Certification


32.2 Section 1350 Certification


95 Mine Safety Disclosures


97 Policy Relating to Recovery of Erroneously Awarded Compensation


101 The following financial information from Berkshire Hathaway Inc.’s Annual Report on Form 10-K for the year
ended December 31, 2024, formatted in iXBRL (Inline Extensible Business Reporting Language) includes: (i)
the Cover Page (ii) the Consolidated Balance Sheets, (iii) the Consolidated Statements of Earnings, (iv) the
Consolidated Statements of Comprehensive Income, (v) the Consolidated Statements of Changes in
Shareholders’ Equity, (vi) the Consolidated Statements of Cash Flows, and (vii) the Notes to Consolidated
Financial Statements and Schedule I, tagged in summary and detail.


104 Cover Page Interactive Data File (formatted as iXBRL and contained in Exhibit 101)


K-122


---

**SIGNATURES**


Pursuant to the requirements of Section 13 or 15(d) of the Securities Exchange Act of 1934, the Registrant has duly
caused this report to be signed on its behalf by the undersigned thereunto duly authorized.


BERKSHIRE HATHAWAY INC.


Date: February 22, 2025 /S/ MARC D. HAMBURG
**Marc D. Hamburg**
**Senior Vice President and**
**Principal Financial Officer**


Pursuant to the requirements of the Securities Exchange Act of 1934, this report has been signed below by the following
persons on behalf of the Registrant and in the capacities and on the dates indicated.


/S/ WARREN E. BUFFETT


**Warren E. Buffett**


/S/ GREGORY E. ABEL


**Gregory E. Abel**


/S/ HOWARD G. BUFFETT


**Howard G. Buffett**


/S/ SUSAN A. BUFFETT


**Susan A. Buffett**


/S/ STEPHEN B. BURKE


**Stephen B. Burke**


/S/ KENNETH I. CHENAULT


**Kenneth I. Chenault**


/S/ CHRISTOPHER C. DAVIS


**Christopher C. Davis**


/S/ SUSAN L. DECKER


**Susan L. Decker**


/S/ CHARLOTTE GUYMAN


**Charlotte Guyman**


/S/ AJIT JAIN


**Ajit Jain**


/S/ THOMAS S. MURPHY, JR.


**Thomas S. Murphy, Jr.**


/S/ RONALD L. OLSON


**Ronald L. Olson**


/S/ WALLACE R. WEITZ


**Wallace R. Weitz**


/S/ MERYL B. WITMER


**Meryl B. Witmer**


/S/ MARC D. HAMBURG


**Marc D. Hamburg**


/S/ DANIEL J. JAKSICH


**Daniel J. Jaksich**


Chairman of the Board of February 22, 2025
Directors—Chief Executive Officer Date


Director—Vice Chairman—Non-Insurance Operations February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director—Vice Chairman—Insurance Operations February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Director February 22, 2025
Date


Senior Vice President—Principal Financial Officer February 22, 2025
Date


Vice President—Principal Accounting Officer February 22, 2025
Date


K-123


---

**BERKSHIRE HATHAWAY INC.**
**OPERATING COMPANIES**


_**INSURANCE:**_ **Employees**


**GEICO** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 28,247
**Berkshire Hathaway Reinsurance Group** . . . 901
**General Re** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,226
**Berkshire Hathaway Direct** . . . . . . . . . . . . . . . 982
**Berkshire Hathaway Homestate Companies** . . 1,203
**Berkshire Hathaway Specialty** . . . . . . . . . . . . 1,782
**GUARD Insurance Companies** . . . . . . . . . . . . 1,174
**MedPro Group** . . . . . . . . . . . . . . . . . . . . . . . . . 1,275
**MLMIC Insurance Companies** . . . . . . . . . . . . 235
**National Indemnity Primary Group** . . . . . . . . 848
**RSUI and CapSpecialty** . . . . . . . . . . . . . . . . . . 705
**TransRe Group** . . . . . . . . . . . . . . . . . . . . . . . . . 679
**United States Liability Insurance Companies** . . 1,216
**Central States Indemnity** . . . . . . . . . . . . . . . . . 20


41,493


_**MANUFACTURING:**_


**Acme** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 1,839
**Benjamin Moore** . . . . . . . . . . . . . . . . . . . . . . . . 2,006
**Brooks Sports** . . . . . . . . . . . . . . . . . . . . . . . . . . 1,326
**Clayton Homes** . . . . . . . . . . . . . . . . . . . . . . . . . 20,645
**CTB** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,511
**Duracell** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 3,153
**Fechheimer** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 424
**Forest River** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 11,425
**Fruit of the Loom** . . . . . . . . . . . . . . . . . . . . . . . 17,258
**Garan** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,677
**H. H. Brown Shoe Group** . . . . . . . . . . . . . . . . . 1,126
**IMC International Metalworking Companies** . . 14,333
**Jazwares** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 1,551
**Johns Manville** . . . . . . . . . . . . . . . . . . . . . . . . . 7,984
**Larson-Juhl** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 525
**LiquidPower Specialty Products** . . . . . . . . . . . 497
**Lubrizol** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 7,922
**Marmon** **[(1)]** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 30,019
**MiTek** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 6,003
**Precision Castparts** . . . . . . . . . . . . . . . . . . . . . . 24,594
**Richline** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,044
**Shaw Industries** . . . . . . . . . . . . . . . . . . . . . . . . . 17,689
**W&W|AFCO Steel** . . . . . . . . . . . . . . . . . . . . . . 2,561


180,112


_**RAILROAD, UTILITIES AND ENERGY:**_ **Employees**


**BNSF** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 36,620
**Berkshire Hathaway Energy Company:**
**Corporate Office** . . . . . . . . . . . . . . . . 34
**PacifiCorp** . . . . . . . . . . . . . . . . . . . . . 5,168
**MidAmerican Energy** . . . . . . . . . . . . 3,539
**NV Energy** . . . . . . . . . . . . . . . . . . . . . 2,651
**Northern Powergrid** . . . . . . . . . . . . . 3,016
**BHE Pipeline Group** . . . . . . . . . . . . . 2,769
**BHE Transmission** . . . . . . . . . . . . . . 754
**BHE Renewables** . . . . . . . . . . . . . . . . 497
**HomeServices of America** . . . . . . . . . 5,411


60,459


_**SERVICE AND RETAILING:**_


**Affordable Housing Partners** . . . . . . . . . . . . . . 32
**Ben Bridge Jeweler** . . . . . . . . . . . . . . . . . . . . . . . 464
**Berkshire Hathaway Automotive** . . . . . . . . . . . 10,130
**Borsheims** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 144
**Business Wire** . . . . . . . . . . . . . . . . . . . . . . . . . . . 345
**Charter Brokerage** . . . . . . . . . . . . . . . . . . . . . . . 167
**CORT** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,235
**Dairy Queen** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 547
**Detlev Louis** . . . . . . . . . . . . . . . . . . . . . . . . . . . . 1,508
**FlightSafety** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 4,660
**Helzberg Diamonds** . . . . . . . . . . . . . . . . . . . . . . 1,519
**IPS** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 3,386
**Jordan’s Furniture** . . . . . . . . . . . . . . . . . . . . . . . 1,046
**McLane Company** . . . . . . . . . . . . . . . . . . . . . . . 24,815
**Nebraska Furniture Mart** . . . . . . . . . . . . . . . . . 4,671
**NetJets** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 9,106
**Oriental Trading** . . . . . . . . . . . . . . . . . . . . . . . . 1,100
**Pampered Chef** . . . . . . . . . . . . . . . . . . . . . . . . . . 300
**Pilot Travel Centers** . . . . . . . . . . . . . . . . . . . . . . 29,202
**R.C. Willey Home Furnishings** . . . . . . . . . . . . . 2,184
**See’s Candies** . . . . . . . . . . . . . . . . . . . . . . . . . . . 2,564
**Star Furniture** . . . . . . . . . . . . . . . . . . . . . . . . . . . 264
**TTI** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 9,341
**WPLG** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 190
**XTRA** . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 385


110,305


**Berkshire Hathaway Corporate Headquarters** . . 27


392,396


(1) Marmon Holding, Inc. (“Marmon”) is a holding company that conducts operations through more than 100
manufacturing and service businesses organized into eleven business groups.


A-1


---

**BERKSHIRE HATHAWAY INC.**
**STOCK TRANSFER AGENT**


EQ Shareowner Services (“EQ”), a division of Equiniti Trust Company., P. O. Box 64854, St. Paul, MN
55164-0854 serves as Transfer Agent and Registrar for the Company’s common stock. Correspondence may be
directed to EQ at the address indicated or at _www.shareowneronline.com._ Telephone inquiries should be directed
to the Shareowner Relations Department at 1-877-602-7411 between 7:00 A.M. and 7:00 P.M. Central Time.
Certificates for re-issue or transfer should be directed to the Transfer Department at the address indicated.


Berkshire has two classes of common stock designated Class A common stock and Class B common stock.
Each share of Class A common stock is convertible, at the option of the holder, into 1,500 shares of Class B
common stock. Shares of Class B common stock are not convertible into shares of Class A common stock.


Registered owner’s holding Berkshire stock in certificate form or through EQ’s direct registration system,
may contact EQ directly for instructions regarding changes in registration, including shareowner’s mailing
address or conversion of Class A shares to Class B shares. Correspondence may be directed to EQ at the address
indicated above or at _www.shareowneronline.com_ . Telephone inquiries should be directed to the Shareowner
Relations Department at 1-877-602-7411 between 7:00 A.M. and 7:00 P.M. Central Time. Certificates for
re-issue or transfer should be directed to the Transfer Department at the address indicated above. Shareowners
can also view account information at the EQ website _www.shareowneronline.com_ .


If a shareowner has lost or misplaced stock certificates, he or she should contact EQ to arrange for
replacements. Transfer agent’s, including EQ, will require the shareowner to provide an indemnification bond
based on the value of the share certificate being replaced. Shareholders are encouraged to contact EQ periodically
to verify the mailing address of record to assure that Company communications are delivered. We encourage you
to vote on shareholder proposals contained in our annual proxy solicitation. Contact with EQ is established
automatically through the voting process.


Shareholders of record wishing to convert Class A common stock into Class B common stock may contact
EQ in writing. Along with the underlying stock certificate, shareholders should provide EQ with specific written
instructions regarding the number of shares to be converted and the manner in which the Class B shares are to be
registered. We recommend that you use certified or registered mail addressed to EQ Shareowner Services, 1110
Centre Pointe Curve, Suite 101, Mendota Heights, MN 55120 when delivering the stock certificates and written
instructions.


Owners holding Berkshire common stock in street name (in a bank, broker or other nominee account)
should contact the bank, broker or nominee for changes in registration. If Class A shares are held in “street
name,” shareholders wishing to convert all or a portion of their holding to Class B should contact their broker or
bank nominee. It will be necessary for the nominee to make the request for conversion.


A-2


---

**BERKSHIRE HATHAWAY INC.**


**DIRECTORS** **OFFICERS**


**WARREN E. BUFFETT,**
_Chairman and CEO of Berkshire_


**GREGORY E. ABEL,**
_Vice Chairman of Berkshire - Non-Insurance Operations_


**AJIT JAIN,**
_Vice Chairman of Berkshire - Insurance Operations_


**HOWARD G. BUFFETT,**
_Chairman and Chief Executive Officer of the Howard G._
_Buffett Foundation, a charitable foundation that directs_
_funding for humanitarian and conservation related issues._


**SUSAN A. BUFFETT,**
_Chairman of The Susan Thompson Buffett Foundation and_
_of The Sherwood Foundation, each of which is a grant-_
_making foundation._


**STEPHEN B. BURKE,**
_Former Chairman and CEO of NBCUniversal, a media and_
_entertainment company._


**KENNETH I. CHENAULT,**
_Chairman and Managing Director of General Catalyst, a_
_venture capital firm and Former Chairman and CEO of_
_American Express Company._


**CHRISTOPHER C. DAVIS,**
_Chairman of Davis Advisors, an investment management_
_firm._


**SUSAN L. DECKER,**
_Founder and CEO of Raftr, a community experience_
_platform._


**CHARLOTTE GUYMAN,**
_Independent Director of a start-up entity, Landings_
_Holdings._


**THOMAS S. MURPHY, JR.,**
_Co-Founder, Crestview Partners, a private equity firm._


**RONALD L. OLSON,**
_Partner of the law firm of Munger, Tolles & Olson LLP._


**WALLACE R. WEITZ,**
_Co-Chair of Board of Weitz Investment Management, an_
_investment management firm._


**MERYL B. WITMER,**
_Managing member of the General Partner of Eagle Capital_
_Partners L.P., an investment partnership._


**WARREN E. BUFFETT,** _Chairman and CEO_


**GREGORY E. ABEL,** _Vice Chairman - Non-Insurance Operations_


**AJIT JAIN,** _Vice Chairman - Insurance Operations_


**MARC D. HAMBURG,** _Senior Vice President and CFO_


**DANIEL J. JAKSICH,** _Vice President, Controller_


**MARK D. MILLARD,** _Vice President_


**JO ELLEN RIECK,** _Vice President_


**KERBY S. HAM,** _Treasurer_


**REBECCA K. AMICK,** _Director of Internal Auditing_


Letters from Annual Reports (1977 through 2024), quarterly reports, press releases and other information about Berkshire
may be obtained on the Internet at www.berkshirehathaway.com.


---

### **BERKSHIRE HATHAWAY INC.**

_Executive Offices_ _—_ _3555_ _Farnam_ _Street,_ _Omaha,_ _Nebraska_ _68131_

---
*Conversion confidence: 100% (150 pages)*